/**
 * Copyright (c) 2024 Gitpod GmbH. All rights reserved.
 * Licensed under the GNU Affero General Public License (AGPL).
 * See License.AGPL.txt in the project root for license information.
 */
import { Message, proto3, Timestamp } from "@bufbuild/protobuf";
import { Pagination } from "./pagination_pb.js";
/**
 * @generated from message gitpod.experimental.v1.Project
 */
export class Project extends Message {
    constructor(data) {
        super();
        /**
         * ID is the unique identifier for the project.
         * Read only.
         *
         * @generated from field: string id = 1;
         */
        this.id = "";
        /**
         * Team ID is the Team this Project belongs to.
         * team_id will be empty if the Project belongs to a User, in which case user_id will be set.
         *
         * @generated from field: string team_id = 2;
         */
        this.teamId = "";
        /**
         * Name is the name of the Project.
         * Required.
         *
         * @generated from field: string name = 4;
         */
        this.name = "";
        /**
         * Clone URL is the clone URL on which this Project is based.
         * Required.
         *
         * @generated from field: string clone_url = 6;
         */
        this.cloneUrl = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new Project().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new Project().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new Project().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(Project, a, b);
    }
}
Project.runtime = proto3;
Project.typeName = "gitpod.experimental.v1.Project";
Project.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "team_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 4, name: "name", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 6, name: "clone_url", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 7, name: "creation_time", kind: "message", T: Timestamp },
    { no: 8, name: "settings", kind: "message", T: ProjectSettings },
]);
/**
 * @generated from message gitpod.experimental.v1.ProjectSettings
 */
export class ProjectSettings extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new ProjectSettings().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new ProjectSettings().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new ProjectSettings().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(ProjectSettings, a, b);
    }
}
ProjectSettings.runtime = proto3;
ProjectSettings.typeName = "gitpod.experimental.v1.ProjectSettings";
ProjectSettings.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "prebuild", kind: "message", T: PrebuildSettings },
    { no: 2, name: "workspace", kind: "message", T: WorkspaceSettings },
]);
/**
 * @generated from message gitpod.experimental.v1.PrebuildSettings
 */
export class PrebuildSettings extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new PrebuildSettings().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new PrebuildSettings().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new PrebuildSettings().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(PrebuildSettings, a, b);
    }
}
PrebuildSettings.runtime = proto3;
PrebuildSettings.typeName = "gitpod.experimental.v1.PrebuildSettings";
PrebuildSettings.fields = proto3.util.newFieldList(() => [
    { no: 5, name: "enable_prebuilds", kind: "scalar", T: 8 /* ScalarType.BOOL */, opt: true },
    { no: 7, name: "branch_matching_pattern", kind: "scalar", T: 9 /* ScalarType.STRING */, opt: true },
    { no: 8, name: "branch_strategy", kind: "scalar", T: 9 /* ScalarType.STRING */, opt: true },
    { no: 9, name: "prebuild_interval", kind: "scalar", T: 5 /* ScalarType.INT32 */, opt: true },
    { no: 10, name: "workspace_class", kind: "scalar", T: 9 /* ScalarType.STRING */, opt: true },
]);
/**
 * @generated from message gitpod.experimental.v1.WorkspaceSettings
 */
export class WorkspaceSettings extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: bool enable_persistent_volume_claim = 1;
         */
        this.enablePersistentVolumeClaim = false;
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceSettings().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceSettings().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceSettings().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceSettings, a, b);
    }
}
WorkspaceSettings.runtime = proto3;
WorkspaceSettings.typeName = "gitpod.experimental.v1.WorkspaceSettings";
WorkspaceSettings.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "enable_persistent_volume_claim", kind: "scalar", T: 8 /* ScalarType.BOOL */ },
    { no: 2, name: "workspace_class", kind: "message", T: WorkspaceClassSettings },
]);
/**
 * @generated from message gitpod.experimental.v1.WorkspaceClassSettings
 */
export class WorkspaceClassSettings extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string regular = 1;
         */
        this.regular = "";
        /**
         * @generated from field: string prebuild = 2;
         */
        this.prebuild = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceClassSettings().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceClassSettings().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceClassSettings().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceClassSettings, a, b);
    }
}
WorkspaceClassSettings.runtime = proto3;
WorkspaceClassSettings.typeName = "gitpod.experimental.v1.WorkspaceClassSettings";
WorkspaceClassSettings.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "regular", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "prebuild", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.experimental.v1.CreateProjectRequest
 */
export class CreateProjectRequest extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new CreateProjectRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new CreateProjectRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new CreateProjectRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(CreateProjectRequest, a, b);
    }
}
CreateProjectRequest.runtime = proto3;
CreateProjectRequest.typeName = "gitpod.experimental.v1.CreateProjectRequest";
CreateProjectRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "project", kind: "message", T: Project },
]);
/**
 * @generated from message gitpod.experimental.v1.CreateProjectResponse
 */
export class CreateProjectResponse extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new CreateProjectResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new CreateProjectResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new CreateProjectResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(CreateProjectResponse, a, b);
    }
}
CreateProjectResponse.runtime = proto3;
CreateProjectResponse.typeName = "gitpod.experimental.v1.CreateProjectResponse";
CreateProjectResponse.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "project", kind: "message", T: Project },
]);
/**
 * @generated from message gitpod.experimental.v1.GetProjectRequest
 */
export class GetProjectRequest extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string project_id = 1;
         */
        this.projectId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new GetProjectRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new GetProjectRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new GetProjectRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(GetProjectRequest, a, b);
    }
}
GetProjectRequest.runtime = proto3;
GetProjectRequest.typeName = "gitpod.experimental.v1.GetProjectRequest";
GetProjectRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "project_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.experimental.v1.GetProjectResponse
 */
export class GetProjectResponse extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new GetProjectResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new GetProjectResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new GetProjectResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(GetProjectResponse, a, b);
    }
}
GetProjectResponse.runtime = proto3;
GetProjectResponse.typeName = "gitpod.experimental.v1.GetProjectResponse";
GetProjectResponse.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "project", kind: "message", T: Project },
]);
/**
 * @generated from message gitpod.experimental.v1.ListProjectsRequest
 */
export class ListProjectsRequest extends Message {
    constructor(data) {
        super();
        /**
         * Team ID filters Projects owned by team_id
         *
         * @generated from field: string team_id = 2;
         */
        this.teamId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new ListProjectsRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new ListProjectsRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new ListProjectsRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(ListProjectsRequest, a, b);
    }
}
ListProjectsRequest.runtime = proto3;
ListProjectsRequest.typeName = "gitpod.experimental.v1.ListProjectsRequest";
ListProjectsRequest.fields = proto3.util.newFieldList(() => [
    { no: 2, name: "team_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 3, name: "pagination", kind: "message", T: Pagination },
]);
/**
 * @generated from message gitpod.experimental.v1.ListProjectsResponse
 */
export class ListProjectsResponse extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: repeated gitpod.experimental.v1.Project projects = 1;
         */
        this.projects = [];
        /**
         * @generated from field: int32 total_results = 2;
         */
        this.totalResults = 0;
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new ListProjectsResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new ListProjectsResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new ListProjectsResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(ListProjectsResponse, a, b);
    }
}
ListProjectsResponse.runtime = proto3;
ListProjectsResponse.typeName = "gitpod.experimental.v1.ListProjectsResponse";
ListProjectsResponse.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "projects", kind: "message", T: Project, repeated: true },
    { no: 2, name: "total_results", kind: "scalar", T: 5 /* ScalarType.INT32 */ },
]);
/**
 * @generated from message gitpod.experimental.v1.DeleteProjectRequest
 */
export class DeleteProjectRequest extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string project_id = 1;
         */
        this.projectId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new DeleteProjectRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new DeleteProjectRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new DeleteProjectRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(DeleteProjectRequest, a, b);
    }
}
DeleteProjectRequest.runtime = proto3;
DeleteProjectRequest.typeName = "gitpod.experimental.v1.DeleteProjectRequest";
DeleteProjectRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "project_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.experimental.v1.DeleteProjectResponse
 */
export class DeleteProjectResponse extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new DeleteProjectResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new DeleteProjectResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new DeleteProjectResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(DeleteProjectResponse, a, b);
    }
}
DeleteProjectResponse.runtime = proto3;
DeleteProjectResponse.typeName = "gitpod.experimental.v1.DeleteProjectResponse";
DeleteProjectResponse.fields = proto3.util.newFieldList(() => []);
//# sourceMappingURL=projects_pb.js.map