/**
 * Copyright (c) 2024 Gitpod GmbH. All rights reserved.
 * Licensed under the GNU Affero General Public License (AGPL).
 * See License.AGPL.txt in the project root for license information.
 */
import { FieldMask, Message, proto3, protoInt64, Timestamp } from "@bufbuild/protobuf";
import { Pagination } from "./pagination_pb.js";
/**
 * PortPolicy defines the accssbility policy of a workspace port is guarded by an authentication in the proxy
 *
 * @generated from enum gitpod.experimental.v1.PortPolicy
 */
export var PortPolicy;
(function (PortPolicy) {
    /**
     * @generated from enum value: PORT_POLICY_UNSPECIFIED = 0;
     */
    PortPolicy[PortPolicy["UNSPECIFIED"] = 0] = "UNSPECIFIED";
    /**
     * Private means the port is accessible by the workspace owner only using the workspace port URL
     *
     * @generated from enum value: PORT_POLICY_PRIVATE = 1;
     */
    PortPolicy[PortPolicy["PRIVATE"] = 1] = "PRIVATE";
    /**
     * Public means the port is accessible by everybody using the workspace port URL
     *
     * @generated from enum value: PORT_POLICY_PUBLIC = 2;
     */
    PortPolicy[PortPolicy["PUBLIC"] = 2] = "PUBLIC";
})(PortPolicy || (PortPolicy = {}));
// Retrieve enum metadata with: proto3.getEnumType(PortPolicy)
proto3.util.setEnumType(PortPolicy, "gitpod.experimental.v1.PortPolicy", [
    { no: 0, name: "PORT_POLICY_UNSPECIFIED" },
    { no: 1, name: "PORT_POLICY_PRIVATE" },
    { no: 2, name: "PORT_POLICY_PUBLIC" },
]);
/**
 * PortProtocol defines the backend protocol of port
 *
 * @generated from enum gitpod.experimental.v1.PortProtocol
 */
export var PortProtocol;
(function (PortProtocol) {
    /**
     * @generated from enum value: PORT_PROTOCOL_UNSPECIFIED = 0;
     */
    PortProtocol[PortProtocol["UNSPECIFIED"] = 0] = "UNSPECIFIED";
    /**
     * Http means the port backend is http
     *
     * @generated from enum value: PORT_PROTOCOL_HTTP = 1;
     */
    PortProtocol[PortProtocol["HTTP"] = 1] = "HTTP";
    /**
     * Https means the port backend is https
     *
     * @generated from enum value: PORT_PROTOCOL_HTTPS = 2;
     */
    PortProtocol[PortProtocol["HTTPS"] = 2] = "HTTPS";
})(PortProtocol || (PortProtocol = {}));
// Retrieve enum metadata with: proto3.getEnumType(PortProtocol)
proto3.util.setEnumType(PortProtocol, "gitpod.experimental.v1.PortProtocol", [
    { no: 0, name: "PORT_PROTOCOL_UNSPECIFIED" },
    { no: 1, name: "PORT_PROTOCOL_HTTP" },
    { no: 2, name: "PORT_PROTOCOL_HTTPS" },
]);
/**
 * Admission level describes who can access a workspace instance and its ports.
 *
 * @generated from enum gitpod.experimental.v1.AdmissionLevel
 */
export var AdmissionLevel;
(function (AdmissionLevel) {
    /**
     * @generated from enum value: ADMISSION_LEVEL_UNSPECIFIED = 0;
     */
    AdmissionLevel[AdmissionLevel["UNSPECIFIED"] = 0] = "UNSPECIFIED";
    /**
     * ADMISSION_LEVEL_OWNER_ONLY means the workspace can only be accessed using the owner token
     *
     * @generated from enum value: ADMISSION_LEVEL_OWNER_ONLY = 1;
     */
    AdmissionLevel[AdmissionLevel["OWNER_ONLY"] = 1] = "OWNER_ONLY";
    /**
     * ADMISSION_LEVEL_EVERYONE means the workspace (including ports) can be accessed by everyone.
     *
     * @generated from enum value: ADMISSION_LEVEL_EVERYONE = 2;
     */
    AdmissionLevel[AdmissionLevel["EVERYONE"] = 2] = "EVERYONE";
})(AdmissionLevel || (AdmissionLevel = {}));
// Retrieve enum metadata with: proto3.getEnumType(AdmissionLevel)
proto3.util.setEnumType(AdmissionLevel, "gitpod.experimental.v1.AdmissionLevel", [
    { no: 0, name: "ADMISSION_LEVEL_UNSPECIFIED" },
    { no: 1, name: "ADMISSION_LEVEL_OWNER_ONLY" },
    { no: 2, name: "ADMISSION_LEVEL_EVERYONE" },
]);
/**
 * @generated from message gitpod.experimental.v1.ListWorkspacesRequest
 */
export class ListWorkspacesRequest extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string organization_id = 3;
         */
        this.organizationId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new ListWorkspacesRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new ListWorkspacesRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new ListWorkspacesRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(ListWorkspacesRequest, a, b);
    }
}
ListWorkspacesRequest.runtime = proto3;
ListWorkspacesRequest.typeName = "gitpod.experimental.v1.ListWorkspacesRequest";
ListWorkspacesRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "pagination", kind: "message", T: Pagination },
    { no: 2, name: "field_mask", kind: "message", T: FieldMask },
    { no: 3, name: "organization_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.experimental.v1.ListWorkspacesResponse
 */
export class ListWorkspacesResponse extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string next_page_token = 1;
         */
        this.nextPageToken = "";
        /**
         * @generated from field: repeated gitpod.experimental.v1.Workspace result = 2;
         */
        this.result = [];
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new ListWorkspacesResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new ListWorkspacesResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new ListWorkspacesResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(ListWorkspacesResponse, a, b);
    }
}
ListWorkspacesResponse.runtime = proto3;
ListWorkspacesResponse.typeName = "gitpod.experimental.v1.ListWorkspacesResponse";
ListWorkspacesResponse.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "next_page_token", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "result", kind: "message", T: Workspace, repeated: true },
]);
/**
 * @generated from message gitpod.experimental.v1.GetWorkspaceRequest
 */
export class GetWorkspaceRequest extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string workspace_id = 1;
         */
        this.workspaceId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new GetWorkspaceRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new GetWorkspaceRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new GetWorkspaceRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(GetWorkspaceRequest, a, b);
    }
}
GetWorkspaceRequest.runtime = proto3;
GetWorkspaceRequest.typeName = "gitpod.experimental.v1.GetWorkspaceRequest";
GetWorkspaceRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.experimental.v1.GetWorkspaceResponse
 */
export class GetWorkspaceResponse extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new GetWorkspaceResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new GetWorkspaceResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new GetWorkspaceResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(GetWorkspaceResponse, a, b);
    }
}
GetWorkspaceResponse.runtime = proto3;
GetWorkspaceResponse.typeName = "gitpod.experimental.v1.GetWorkspaceResponse";
GetWorkspaceResponse.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "result", kind: "message", T: Workspace },
]);
/**
 * @generated from message gitpod.experimental.v1.StreamWorkspaceStatusRequest
 */
export class StreamWorkspaceStatusRequest extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string workspace_id = 1;
         */
        this.workspaceId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new StreamWorkspaceStatusRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new StreamWorkspaceStatusRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new StreamWorkspaceStatusRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(StreamWorkspaceStatusRequest, a, b);
    }
}
StreamWorkspaceStatusRequest.runtime = proto3;
StreamWorkspaceStatusRequest.typeName = "gitpod.experimental.v1.StreamWorkspaceStatusRequest";
StreamWorkspaceStatusRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.experimental.v1.StreamWorkspaceStatusResponse
 */
export class StreamWorkspaceStatusResponse extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new StreamWorkspaceStatusResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new StreamWorkspaceStatusResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new StreamWorkspaceStatusResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(StreamWorkspaceStatusResponse, a, b);
    }
}
StreamWorkspaceStatusResponse.runtime = proto3;
StreamWorkspaceStatusResponse.typeName = "gitpod.experimental.v1.StreamWorkspaceStatusResponse";
StreamWorkspaceStatusResponse.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "result", kind: "message", T: WorkspaceStatus },
]);
/**
 * @generated from message gitpod.experimental.v1.GetOwnerTokenRequest
 */
export class GetOwnerTokenRequest extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string workspace_id = 1;
         */
        this.workspaceId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new GetOwnerTokenRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new GetOwnerTokenRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new GetOwnerTokenRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(GetOwnerTokenRequest, a, b);
    }
}
GetOwnerTokenRequest.runtime = proto3;
GetOwnerTokenRequest.typeName = "gitpod.experimental.v1.GetOwnerTokenRequest";
GetOwnerTokenRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.experimental.v1.GetOwnerTokenResponse
 */
export class GetOwnerTokenResponse extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string token = 1;
         */
        this.token = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new GetOwnerTokenResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new GetOwnerTokenResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new GetOwnerTokenResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(GetOwnerTokenResponse, a, b);
    }
}
GetOwnerTokenResponse.runtime = proto3;
GetOwnerTokenResponse.typeName = "gitpod.experimental.v1.GetOwnerTokenResponse";
GetOwnerTokenResponse.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "token", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.experimental.v1.CreateAndStartWorkspaceRequest
 */
export class CreateAndStartWorkspaceRequest extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string idempotency_token = 1;
         */
        this.idempotencyToken = "";
        /**
         * @generated from oneof gitpod.experimental.v1.CreateAndStartWorkspaceRequest.source
         */
        this.source = { case: undefined };
        /**
         * @generated from field: string organization_id = 6;
         */
        this.organizationId = "";
        /**
         * @generated from field: bool ignore_running_workspace_on_same_commit = 7;
         */
        this.ignoreRunningWorkspaceOnSameCommit = false;
        /**
         * @generated from field: bool ignore_running_prebuild = 8;
         */
        this.ignoreRunningPrebuild = false;
        /**
         * @generated from field: bool allow_using_previous_prebuilds = 9;
         */
        this.allowUsingPreviousPrebuilds = false;
        /**
         * @generated from field: bool force_default_config = 10;
         */
        this.forceDefaultConfig = false;
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new CreateAndStartWorkspaceRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new CreateAndStartWorkspaceRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new CreateAndStartWorkspaceRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(CreateAndStartWorkspaceRequest, a, b);
    }
}
CreateAndStartWorkspaceRequest.runtime = proto3;
CreateAndStartWorkspaceRequest.typeName = "gitpod.experimental.v1.CreateAndStartWorkspaceRequest";
CreateAndStartWorkspaceRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "idempotency_token", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "context_url", kind: "scalar", T: 9 /* ScalarType.STRING */, oneof: "source" },
    { no: 3, name: "prebuild_id", kind: "scalar", T: 9 /* ScalarType.STRING */, oneof: "source" },
    { no: 5, name: "start_spec", kind: "message", T: StartWorkspaceSpec },
    { no: 6, name: "organization_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 7, name: "ignore_running_workspace_on_same_commit", kind: "scalar", T: 8 /* ScalarType.BOOL */ },
    { no: 8, name: "ignore_running_prebuild", kind: "scalar", T: 8 /* ScalarType.BOOL */ },
    { no: 9, name: "allow_using_previous_prebuilds", kind: "scalar", T: 8 /* ScalarType.BOOL */ },
    { no: 10, name: "force_default_config", kind: "scalar", T: 8 /* ScalarType.BOOL */ },
]);
/**
 * @generated from message gitpod.experimental.v1.CreateAndStartWorkspaceResponse
 */
export class CreateAndStartWorkspaceResponse extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string workspace_id = 1;
         */
        this.workspaceId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new CreateAndStartWorkspaceResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new CreateAndStartWorkspaceResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new CreateAndStartWorkspaceResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(CreateAndStartWorkspaceResponse, a, b);
    }
}
CreateAndStartWorkspaceResponse.runtime = proto3;
CreateAndStartWorkspaceResponse.typeName = "gitpod.experimental.v1.CreateAndStartWorkspaceResponse";
CreateAndStartWorkspaceResponse.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.experimental.v1.StartWorkspaceRequest
 */
export class StartWorkspaceRequest extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string workspace_id = 1;
         */
        this.workspaceId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new StartWorkspaceRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new StartWorkspaceRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new StartWorkspaceRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(StartWorkspaceRequest, a, b);
    }
}
StartWorkspaceRequest.runtime = proto3;
StartWorkspaceRequest.typeName = "gitpod.experimental.v1.StartWorkspaceRequest";
StartWorkspaceRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.experimental.v1.StartWorkspaceResponse
 */
export class StartWorkspaceResponse extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new StartWorkspaceResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new StartWorkspaceResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new StartWorkspaceResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(StartWorkspaceResponse, a, b);
    }
}
StartWorkspaceResponse.runtime = proto3;
StartWorkspaceResponse.typeName = "gitpod.experimental.v1.StartWorkspaceResponse";
StartWorkspaceResponse.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "result", kind: "message", T: Workspace },
]);
/**
 * @generated from message gitpod.experimental.v1.StopWorkspaceRequest
 */
export class StopWorkspaceRequest extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string workspace_id = 1;
         */
        this.workspaceId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new StopWorkspaceRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new StopWorkspaceRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new StopWorkspaceRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(StopWorkspaceRequest, a, b);
    }
}
StopWorkspaceRequest.runtime = proto3;
StopWorkspaceRequest.typeName = "gitpod.experimental.v1.StopWorkspaceRequest";
StopWorkspaceRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.experimental.v1.StopWorkspaceResponse
 */
export class StopWorkspaceResponse extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new StopWorkspaceResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new StopWorkspaceResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new StopWorkspaceResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(StopWorkspaceResponse, a, b);
    }
}
StopWorkspaceResponse.runtime = proto3;
StopWorkspaceResponse.typeName = "gitpod.experimental.v1.StopWorkspaceResponse";
StopWorkspaceResponse.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "result", kind: "message", T: Workspace },
]);
/**
 * @generated from message gitpod.experimental.v1.DeleteWorkspaceRequest
 */
export class DeleteWorkspaceRequest extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string workspace_id = 1;
         */
        this.workspaceId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new DeleteWorkspaceRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new DeleteWorkspaceRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new DeleteWorkspaceRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(DeleteWorkspaceRequest, a, b);
    }
}
DeleteWorkspaceRequest.runtime = proto3;
DeleteWorkspaceRequest.typeName = "gitpod.experimental.v1.DeleteWorkspaceRequest";
DeleteWorkspaceRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.experimental.v1.DeleteWorkspaceResponse
 */
export class DeleteWorkspaceResponse extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new DeleteWorkspaceResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new DeleteWorkspaceResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new DeleteWorkspaceResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(DeleteWorkspaceResponse, a, b);
    }
}
DeleteWorkspaceResponse.runtime = proto3;
DeleteWorkspaceResponse.typeName = "gitpod.experimental.v1.DeleteWorkspaceResponse";
DeleteWorkspaceResponse.fields = proto3.util.newFieldList(() => []);
/**
 * @generated from message gitpod.experimental.v1.ListWorkspaceClassesRequest
 */
export class ListWorkspaceClassesRequest extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new ListWorkspaceClassesRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new ListWorkspaceClassesRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new ListWorkspaceClassesRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(ListWorkspaceClassesRequest, a, b);
    }
}
ListWorkspaceClassesRequest.runtime = proto3;
ListWorkspaceClassesRequest.typeName = "gitpod.experimental.v1.ListWorkspaceClassesRequest";
ListWorkspaceClassesRequest.fields = proto3.util.newFieldList(() => []);
/**
 * @generated from message gitpod.experimental.v1.ListWorkspaceClassesResponse
 */
export class ListWorkspaceClassesResponse extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: repeated gitpod.experimental.v1.WorkspaceClass result = 1;
         */
        this.result = [];
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new ListWorkspaceClassesResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new ListWorkspaceClassesResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new ListWorkspaceClassesResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(ListWorkspaceClassesResponse, a, b);
    }
}
ListWorkspaceClassesResponse.runtime = proto3;
ListWorkspaceClassesResponse.typeName = "gitpod.experimental.v1.ListWorkspaceClassesResponse";
ListWorkspaceClassesResponse.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "result", kind: "message", T: WorkspaceClass, repeated: true },
]);
/**
 * Workspace describes a single workspace
 *
 * @generated from message gitpod.experimental.v1.Workspace
 */
export class Workspace extends Message {
    constructor(data) {
        super();
        /**
         * workspace_id is the ID of the workspace
         *
         * @generated from field: string workspace_id = 1;
         */
        this.workspaceId = "";
        /**
         * owner_id is the ID of the user who created this workspace
         *
         * @generated from field: string owner_id = 2;
         */
        this.ownerId = "";
        /**
         * project_id is the ID of the project which this workspace belongs to
         *
         * @generated from field: string project_id = 3;
         */
        this.projectId = "";
        /**
         * description is a human readable description of the workspace
         *
         * @generated from field: string description = 5;
         */
        this.description = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new Workspace().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new Workspace().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new Workspace().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(Workspace, a, b);
    }
}
Workspace.runtime = proto3;
Workspace.typeName = "gitpod.experimental.v1.Workspace";
Workspace.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "owner_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 3, name: "project_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 4, name: "context", kind: "message", T: WorkspaceContext },
    { no: 5, name: "description", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 6, name: "status", kind: "message", T: WorkspaceStatus },
]);
/**
 * WorkspaceStatus represents the currently observed status of a Workspace, including data about child resources that belong to this Workspace.
 *
 * @generated from message gitpod.experimental.v1.WorkspaceStatus
 */
export class WorkspaceStatus extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceStatus().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceStatus().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceStatus().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceStatus, a, b);
    }
}
WorkspaceStatus.runtime = proto3;
WorkspaceStatus.typeName = "gitpod.experimental.v1.WorkspaceStatus";
WorkspaceStatus.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "instance", kind: "message", T: WorkspaceInstance },
]);
/**
 * WorkspaceContext describes the context a workspace was created from
 *
 * @generated from message gitpod.experimental.v1.WorkspaceContext
 */
export class WorkspaceContext extends Message {
    constructor(data) {
        super();
        /**
         * All workspace context originates from a URL - this is the context URL
         * which led to the creation of a workspace.
         *
         * @generated from field: string context_url = 1;
         */
        this.contextUrl = "";
        /**
         * @generated from oneof gitpod.experimental.v1.WorkspaceContext.details
         */
        this.details = { case: undefined };
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceContext().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceContext().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceContext().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceContext, a, b);
    }
}
WorkspaceContext.runtime = proto3;
WorkspaceContext.typeName = "gitpod.experimental.v1.WorkspaceContext";
WorkspaceContext.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "context_url", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "git", kind: "message", T: WorkspaceContext_Git, oneof: "details" },
    { no: 3, name: "prebuild", kind: "message", T: WorkspaceContext_Prebuild, oneof: "details" },
    { no: 4, name: "snapshot", kind: "message", T: WorkspaceContext_Snapshot, oneof: "details" },
]);
/**
 * GitProvider describes the git provider
 *
 * @generated from message gitpod.experimental.v1.WorkspaceContext.GitProvider
 */
export class WorkspaceContext_GitProvider extends Message {
    constructor(data) {
        super();
        /**
         * type is the git provider type, e.g. 'github', 'gitlab', 'bitbucket'
         *
         * @generated from field: string type = 1;
         */
        this.type = "";
        /**
         * hostname is the git provider hostname
         *
         * @generated from field: string hostname = 2;
         */
        this.hostname = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceContext_GitProvider().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceContext_GitProvider().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceContext_GitProvider().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceContext_GitProvider, a, b);
    }
}
WorkspaceContext_GitProvider.runtime = proto3;
WorkspaceContext_GitProvider.typeName = "gitpod.experimental.v1.WorkspaceContext.GitProvider";
WorkspaceContext_GitProvider.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "type", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "hostname", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * Repository describes the originating repository
 *
 * @generated from message gitpod.experimental.v1.WorkspaceContext.Repository
 */
export class WorkspaceContext_Repository extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string name = 1;
         */
        this.name = "";
        /**
         * @generated from field: string owner = 2;
         */
        this.owner = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceContext_Repository().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceContext_Repository().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceContext_Repository().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceContext_Repository, a, b);
    }
}
WorkspaceContext_Repository.runtime = proto3;
WorkspaceContext_Repository.typeName = "gitpod.experimental.v1.WorkspaceContext.Repository";
WorkspaceContext_Repository.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "name", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "owner", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * Explicit Git context
 *
 * @generated from message gitpod.experimental.v1.WorkspaceContext.Git
 */
export class WorkspaceContext_Git extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string normalized_context_url = 1;
         */
        this.normalizedContextUrl = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceContext_Git().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceContext_Git().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceContext_Git().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceContext_Git, a, b);
    }
}
WorkspaceContext_Git.runtime = proto3;
WorkspaceContext_Git.typeName = "gitpod.experimental.v1.WorkspaceContext.Git";
WorkspaceContext_Git.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "normalized_context_url", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "repository", kind: "message", T: WorkspaceContext_Repository },
    { no: 3, name: "provider", kind: "message", T: WorkspaceContext_GitProvider },
]);
/**
 * Workspace was created from a prebuild
 *
 * @generated from message gitpod.experimental.v1.WorkspaceContext.Prebuild
 */
export class WorkspaceContext_Prebuild extends Message {
    constructor(data) {
        super();
        /**
         * prebuild_id is the ID of the prebuild which was used to create this workspace
         *
         * @generated from field: string prebuild_id = 2;
         */
        this.prebuildId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceContext_Prebuild().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceContext_Prebuild().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceContext_Prebuild().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceContext_Prebuild, a, b);
    }
}
WorkspaceContext_Prebuild.runtime = proto3;
WorkspaceContext_Prebuild.typeName = "gitpod.experimental.v1.WorkspaceContext.Prebuild";
WorkspaceContext_Prebuild.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "original_context", kind: "message", T: WorkspaceContext_Git },
    { no: 2, name: "prebuild_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * Snapshot context points to the snapshot which the workspace was created from
 *
 * @generated from message gitpod.experimental.v1.WorkspaceContext.Snapshot
 */
export class WorkspaceContext_Snapshot extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string snapshot_id = 1;
         */
        this.snapshotId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceContext_Snapshot().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceContext_Snapshot().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceContext_Snapshot().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceContext_Snapshot, a, b);
    }
}
WorkspaceContext_Snapshot.runtime = proto3;
WorkspaceContext_Snapshot.typeName = "gitpod.experimental.v1.WorkspaceContext.Snapshot";
WorkspaceContext_Snapshot.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "snapshot_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * WorkspaceInstance describes a single workspace instance
 *
 * @generated from message gitpod.experimental.v1.WorkspaceInstance
 */
export class WorkspaceInstance extends Message {
    constructor(data) {
        super();
        /**
         * Instance ID is the unique identifier of the workspace instance
         *
         * @generated from field: string instance_id = 1;
         */
        this.instanceId = "";
        /**
         * Workspace ID is the unique identifier of the workspace this instance belongs to
         *
         * @generated from field: string workspace_id = 2;
         */
        this.workspaceId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceInstance().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceInstance().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceInstance().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceInstance, a, b);
    }
}
WorkspaceInstance.runtime = proto3;
WorkspaceInstance.typeName = "gitpod.experimental.v1.WorkspaceInstance";
WorkspaceInstance.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "instance_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 3, name: "created_at", kind: "message", T: Timestamp },
    { no: 4, name: "status", kind: "message", T: WorkspaceInstanceStatus },
]);
/**
 * WorkspaceStatus describes a workspace status
 *
 * @generated from message gitpod.experimental.v1.WorkspaceInstanceStatus
 */
export class WorkspaceInstanceStatus extends Message {
    constructor(data) {
        super();
        /**
         * version of the status update. Workspace instances themselves are unversioned,
         * but their statuus has different versions.
         * The value of this field has no semantic meaning (e.g. don't interpret it as
         * as a timestemp), but it can be used to impose a partial order.
         * If a.status_version < b.status_version then a was the status before b.
         *
         * @generated from field: uint64 status_version = 1;
         */
        this.statusVersion = protoInt64.zero;
        /**
         * the phase of a workspace is a simple, high-level summary of where the workspace instance is in its lifecycle
         *
         * @generated from field: gitpod.experimental.v1.WorkspaceInstanceStatus.Phase phase = 2;
         */
        this.phase = WorkspaceInstanceStatus_Phase.UNSPECIFIED;
        /**
         * message is an optional human-readable message detailing the current phase
         *
         * @generated from field: string message = 4;
         */
        this.message = "";
        /**
         * URL contains the endpoint at which the workspace instance is available
         *
         * @generated from field: string url = 5;
         */
        this.url = "";
        /**
         * Admission describes who can access a workspace instance and its ports.
         *
         * @generated from field: gitpod.experimental.v1.AdmissionLevel admission = 6;
         */
        this.admission = AdmissionLevel.UNSPECIFIED;
        /**
         * ports is the list of exposed ports in the workspace.
         *
         * @generated from field: repeated gitpod.experimental.v1.Port ports = 7;
         */
        this.ports = [];
        /**
         * recent_folders is the opened folders inside the workspace. Used to determine the folder path to load the workspace in.
         *
         * @generated from field: repeated string recent_folders = 8;
         */
        this.recentFolders = [];
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceInstanceStatus().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceInstanceStatus().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceInstanceStatus().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceInstanceStatus, a, b);
    }
}
WorkspaceInstanceStatus.runtime = proto3;
WorkspaceInstanceStatus.typeName = "gitpod.experimental.v1.WorkspaceInstanceStatus";
WorkspaceInstanceStatus.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "status_version", kind: "scalar", T: 4 /* ScalarType.UINT64 */ },
    { no: 2, name: "phase", kind: "enum", T: proto3.getEnumType(WorkspaceInstanceStatus_Phase) },
    { no: 3, name: "conditions", kind: "message", T: WorkspaceInstanceStatus_Conditions },
    { no: 4, name: "message", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 5, name: "url", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 6, name: "admission", kind: "enum", T: proto3.getEnumType(AdmissionLevel) },
    { no: 7, name: "ports", kind: "message", T: Port, repeated: true },
    { no: 8, name: "recent_folders", kind: "scalar", T: 9 /* ScalarType.STRING */, repeated: true },
    { no: 9, name: "git_status", kind: "message", T: GitStatus },
]);
/**
 * Phase is a simple, high-level summary of where the workspace instance is in its lifecycle.
 * The phase is not intended to be a comprehensive rollup of observations of the workspace state,
 * nor is it intended to be a comprehensive state machine.
 * (based on  https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle/#pod-phase)
 *
 * @generated from enum gitpod.experimental.v1.WorkspaceInstanceStatus.Phase
 */
export var WorkspaceInstanceStatus_Phase;
(function (WorkspaceInstanceStatus_Phase) {
    /**
     * Unknown indicates an issue within the workspace manager in that it cannot determine the actual phase of
     * a workspace. This phase is usually accompanied by an error.
     *
     * @generated from enum value: PHASE_UNSPECIFIED = 0;
     */
    WorkspaceInstanceStatus_Phase[WorkspaceInstanceStatus_Phase["UNSPECIFIED"] = 0] = "UNSPECIFIED";
    /**
     * Preparing means that we haven't actually started the workspace instance just yet, but rather
     * are still preparing for launch.
     *
     * @generated from enum value: PHASE_PREPARING = 1;
     */
    WorkspaceInstanceStatus_Phase[WorkspaceInstanceStatus_Phase["PREPARING"] = 1] = "PREPARING";
    /**
     * ImageBuild indicates that there's an image build running for this workspace.
     *
     * @generated from enum value: PHASE_IMAGEBUILD = 2;
     */
    WorkspaceInstanceStatus_Phase[WorkspaceInstanceStatus_Phase["IMAGEBUILD"] = 2] = "IMAGEBUILD";
    /**
     * Pending means the workspace does not yet consume resources in the cluster, but rather is looking for
     * some space within the cluster. If for example the cluster needs to scale up to accomodate the
     * workspace, the workspace will be in Pending state until that happened.
     *
     * @generated from enum value: PHASE_PENDING = 3;
     */
    WorkspaceInstanceStatus_Phase[WorkspaceInstanceStatus_Phase["PENDING"] = 3] = "PENDING";
    /**
     * Creating means the workspace is currently being created. That includes downloading the images required
     * to run the workspace over the network. The time spent in this phase varies widely and depends on the current
     * network speed, image size and cache states.
     *
     * @generated from enum value: PHASE_CREATING = 4;
     */
    WorkspaceInstanceStatus_Phase[WorkspaceInstanceStatus_Phase["CREATING"] = 4] = "CREATING";
    /**
     * Initializing is the phase in which the workspace is executing the appropriate workspace initializer (e.g. Git
     * clone or backup download). After this phase one can expect the workspace to either be Running or Failed.
     *
     * @generated from enum value: PHASE_INITIALIZING = 5;
     */
    WorkspaceInstanceStatus_Phase[WorkspaceInstanceStatus_Phase["INITIALIZING"] = 5] = "INITIALIZING";
    /**
     * Running means the workspace is able to actively perform work, either by serving a user through Theia,
     * or as a headless workspace.
     *
     * @generated from enum value: PHASE_RUNNING = 6;
     */
    WorkspaceInstanceStatus_Phase[WorkspaceInstanceStatus_Phase["RUNNING"] = 6] = "RUNNING";
    /**
     * Interrupted is an exceptional state where the container should be running but is temporarily unavailable.
     * When in this state, we expect it to become running or stopping anytime soon.
     *
     * @generated from enum value: PHASE_INTERRUPTED = 7;
     */
    WorkspaceInstanceStatus_Phase[WorkspaceInstanceStatus_Phase["INTERRUPTED"] = 7] = "INTERRUPTED";
    /**
     * Stopping means that the workspace is currently shutting down. It could go to stopped every moment.
     *
     * @generated from enum value: PHASE_STOPPING = 8;
     */
    WorkspaceInstanceStatus_Phase[WorkspaceInstanceStatus_Phase["STOPPING"] = 8] = "STOPPING";
    /**
     * Stopped means the workspace ended regularly because it was shut down.
     *
     * @generated from enum value: PHASE_STOPPED = 9;
     */
    WorkspaceInstanceStatus_Phase[WorkspaceInstanceStatus_Phase["STOPPED"] = 9] = "STOPPED";
})(WorkspaceInstanceStatus_Phase || (WorkspaceInstanceStatus_Phase = {}));
// Retrieve enum metadata with: proto3.getEnumType(WorkspaceInstanceStatus_Phase)
proto3.util.setEnumType(WorkspaceInstanceStatus_Phase, "gitpod.experimental.v1.WorkspaceInstanceStatus.Phase", [
    { no: 0, name: "PHASE_UNSPECIFIED" },
    { no: 1, name: "PHASE_PREPARING" },
    { no: 2, name: "PHASE_IMAGEBUILD" },
    { no: 3, name: "PHASE_PENDING" },
    { no: 4, name: "PHASE_CREATING" },
    { no: 5, name: "PHASE_INITIALIZING" },
    { no: 6, name: "PHASE_RUNNING" },
    { no: 7, name: "PHASE_INTERRUPTED" },
    { no: 8, name: "PHASE_STOPPING" },
    { no: 9, name: "PHASE_STOPPED" },
]);
/**
 * Conditions gives more detailed information as to the state of the workspace. Which condition actually
 * has a value depends on the phase the workspace is in.
 *
 * @generated from message gitpod.experimental.v1.WorkspaceInstanceStatus.Conditions
 */
export class WorkspaceInstanceStatus_Conditions extends Message {
    constructor(data) {
        super();
        /**
         * failed contains the reason the workspace failed to operate. If this field is empty, the workspace has not failed.
         * This field is filled exclusively when caused by system errors.
         *
         * @generated from field: string failed = 1;
         */
        this.failed = "";
        /**
         * timeout contains the reason the workspace has timed out. If this field is empty, the workspace has not timed out.
         *
         * @generated from field: string timeout = 2;
         */
        this.timeout = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceInstanceStatus_Conditions().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceInstanceStatus_Conditions().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceInstanceStatus_Conditions().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceInstanceStatus_Conditions, a, b);
    }
}
WorkspaceInstanceStatus_Conditions.runtime = proto3;
WorkspaceInstanceStatus_Conditions.typeName = "gitpod.experimental.v1.WorkspaceInstanceStatus.Conditions";
WorkspaceInstanceStatus_Conditions.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "failed", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "timeout", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 9, name: "first_user_activity", kind: "message", T: Timestamp },
    { no: 11, name: "stopped_by_request", kind: "scalar", T: 8 /* ScalarType.BOOL */, opt: true },
]);
/**
 * @generated from message gitpod.experimental.v1.Port
 */
export class Port extends Message {
    constructor(data) {
        super();
        /**
         * port number
         *
         * @generated from field: uint64 port = 1;
         */
        this.port = protoInt64.zero;
        /**
         * policy of this port
         *
         * @generated from field: gitpod.experimental.v1.PortPolicy policy = 2;
         */
        this.policy = PortPolicy.UNSPECIFIED;
        /**
         * url that can be used to access the port
         *
         * @generated from field: string url = 3;
         */
        this.url = "";
        /**
         * backend protocol of this port
         *
         * @generated from field: gitpod.experimental.v1.PortProtocol protocol = 4;
         */
        this.protocol = PortProtocol.UNSPECIFIED;
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new Port().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new Port().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new Port().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(Port, a, b);
    }
}
Port.runtime = proto3;
Port.typeName = "gitpod.experimental.v1.Port";
Port.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "port", kind: "scalar", T: 4 /* ScalarType.UINT64 */ },
    { no: 2, name: "policy", kind: "enum", T: proto3.getEnumType(PortPolicy) },
    { no: 3, name: "url", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 4, name: "protocol", kind: "enum", T: proto3.getEnumType(PortProtocol) },
]);
/**
 * StartWorkspaceSpec influences the workspace start
 *
 * @generated from message gitpod.experimental.v1.StartWorkspaceSpec
 */
export class StartWorkspaceSpec extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string workspace_class = 1;
         */
        this.workspaceClass = "";
        /**
         * @generated from field: string region = 3;
         */
        this.region = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new StartWorkspaceSpec().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new StartWorkspaceSpec().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new StartWorkspaceSpec().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(StartWorkspaceSpec, a, b);
    }
}
StartWorkspaceSpec.runtime = proto3;
StartWorkspaceSpec.typeName = "gitpod.experimental.v1.StartWorkspaceSpec";
StartWorkspaceSpec.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace_class", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "ide_settings", kind: "message", T: IDESettings },
    { no: 3, name: "region", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.experimental.v1.IDESettings
 */
export class IDESettings extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string default_ide = 1;
         */
        this.defaultIde = "";
        /**
         * @generated from field: bool use_latest_version = 2;
         */
        this.useLatestVersion = false;
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new IDESettings().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new IDESettings().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new IDESettings().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(IDESettings, a, b);
    }
}
IDESettings.runtime = proto3;
IDESettings.typeName = "gitpod.experimental.v1.IDESettings";
IDESettings.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "default_ide", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "use_latest_version", kind: "scalar", T: 8 /* ScalarType.BOOL */ },
]);
/**
 * @generated from message gitpod.experimental.v1.PortSpec
 */
export class PortSpec extends Message {
    constructor(data) {
        super();
        /**
         * port number
         *
         * @generated from field: uint64 port = 1;
         */
        this.port = protoInt64.zero;
        /**
         * policy of this port
         *
         * @generated from field: gitpod.experimental.v1.PortPolicy policy = 2;
         */
        this.policy = PortPolicy.UNSPECIFIED;
        /**
         * backend protocol of this port
         *
         * @generated from field: gitpod.experimental.v1.PortProtocol protocol = 3;
         */
        this.protocol = PortProtocol.UNSPECIFIED;
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new PortSpec().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new PortSpec().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new PortSpec().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(PortSpec, a, b);
    }
}
PortSpec.runtime = proto3;
PortSpec.typeName = "gitpod.experimental.v1.PortSpec";
PortSpec.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "port", kind: "scalar", T: 4 /* ScalarType.UINT64 */ },
    { no: 2, name: "policy", kind: "enum", T: proto3.getEnumType(PortPolicy) },
    { no: 3, name: "protocol", kind: "enum", T: proto3.getEnumType(PortProtocol) },
]);
/**
 * @generated from message gitpod.experimental.v1.UpdatePortRequest
 */
export class UpdatePortRequest extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string workspace_id = 1;
         */
        this.workspaceId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new UpdatePortRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new UpdatePortRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new UpdatePortRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(UpdatePortRequest, a, b);
    }
}
UpdatePortRequest.runtime = proto3;
UpdatePortRequest.typeName = "gitpod.experimental.v1.UpdatePortRequest";
UpdatePortRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "port", kind: "message", T: PortSpec },
]);
/**
 * @generated from message gitpod.experimental.v1.UpdatePortResponse
 */
export class UpdatePortResponse extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new UpdatePortResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new UpdatePortResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new UpdatePortResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(UpdatePortResponse, a, b);
    }
}
UpdatePortResponse.runtime = proto3;
UpdatePortResponse.typeName = "gitpod.experimental.v1.UpdatePortResponse";
UpdatePortResponse.fields = proto3.util.newFieldList(() => []);
/**
 * GitStatus describes the current working copy status, akin to a combination of "git status" and "git branch"
 *
 * @generated from message gitpod.experimental.v1.GitStatus
 */
export class GitStatus extends Message {
    constructor(data) {
        super();
        /**
         * branch is branch we're currently on
         *
         * @generated from field: string branch = 1;
         */
        this.branch = "";
        /**
         * latest_commit is the most recent commit on the current branch
         *
         * @generated from field: string latest_commit = 2;
         */
        this.latestCommit = "";
        /**
         * uncommited_files is an array of uncommitted files, possibly truncated
         *
         * @generated from field: repeated string uncommited_files = 3;
         */
        this.uncommitedFiles = [];
        /**
         * the total number of uncommited files
         *
         * @generated from field: int32 total_uncommited_files = 6;
         */
        this.totalUncommitedFiles = 0;
        /**
         * untracked_files is an array of untracked files in the workspace, possibly truncated
         *
         * @generated from field: repeated string untracked_files = 4;
         */
        this.untrackedFiles = [];
        /**
         * the total number of untracked files
         *
         * @generated from field: int32 total_untracked_files = 7;
         */
        this.totalUntrackedFiles = 0;
        /**
         * unpushed_commits is an array of unpushed changes in the workspace, possibly truncated
         *
         * @generated from field: repeated string unpushed_commits = 5;
         */
        this.unpushedCommits = [];
        /**
         * the total number of unpushed changes
         *
         * @generated from field: int32 total_unpushed_commits = 8;
         */
        this.totalUnpushedCommits = 0;
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new GitStatus().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new GitStatus().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new GitStatus().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(GitStatus, a, b);
    }
}
GitStatus.runtime = proto3;
GitStatus.typeName = "gitpod.experimental.v1.GitStatus";
GitStatus.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "branch", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "latest_commit", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 3, name: "uncommited_files", kind: "scalar", T: 9 /* ScalarType.STRING */, repeated: true },
    { no: 6, name: "total_uncommited_files", kind: "scalar", T: 5 /* ScalarType.INT32 */ },
    { no: 4, name: "untracked_files", kind: "scalar", T: 9 /* ScalarType.STRING */, repeated: true },
    { no: 7, name: "total_untracked_files", kind: "scalar", T: 5 /* ScalarType.INT32 */ },
    { no: 5, name: "unpushed_commits", kind: "scalar", T: 9 /* ScalarType.STRING */, repeated: true },
    { no: 8, name: "total_unpushed_commits", kind: "scalar", T: 5 /* ScalarType.INT32 */ },
]);
/**
 * @generated from message gitpod.experimental.v1.WorkspaceClass
 */
export class WorkspaceClass extends Message {
    constructor(data) {
        super();
        /**
         * id is the unique identifier of the workspace class
         *
         * @generated from field: string id = 1;
         */
        this.id = "";
        /**
         * display_name is the human readable name of the workspace class
         *
         * @generated from field: string display_name = 2;
         */
        this.displayName = "";
        /**
         * description is a human readable description of the workspace class
         *
         * @generated from field: string description = 3;
         */
        this.description = "";
        /**
         * is_default indicates if this workspace class is the default one
         *
         * @generated from field: bool is_default = 4;
         */
        this.isDefault = false;
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceClass().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceClass().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceClass().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceClass, a, b);
    }
}
WorkspaceClass.runtime = proto3;
WorkspaceClass.typeName = "gitpod.experimental.v1.WorkspaceClass";
WorkspaceClass.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "display_name", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 3, name: "description", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 4, name: "is_default", kind: "scalar", T: 8 /* ScalarType.BOOL */ },
]);
/**
 * @generated from message gitpod.experimental.v1.GetDefaultWorkspaceImageRequest
 */
export class GetDefaultWorkspaceImageRequest extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new GetDefaultWorkspaceImageRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new GetDefaultWorkspaceImageRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new GetDefaultWorkspaceImageRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(GetDefaultWorkspaceImageRequest, a, b);
    }
}
GetDefaultWorkspaceImageRequest.runtime = proto3;
GetDefaultWorkspaceImageRequest.typeName = "gitpod.experimental.v1.GetDefaultWorkspaceImageRequest";
GetDefaultWorkspaceImageRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */, opt: true },
]);
/**
 * @generated from message gitpod.experimental.v1.GetDefaultWorkspaceImageResponse
 */
export class GetDefaultWorkspaceImageResponse extends Message {
    constructor(data) {
        super();
        /**
         * image is the image ref
         *
         * @generated from field: string image = 1;
         */
        this.image = "";
        /**
         * source is the source of the image
         *
         * @generated from field: gitpod.experimental.v1.GetDefaultWorkspaceImageResponse.ImageSource source = 2;
         */
        this.source = GetDefaultWorkspaceImageResponse_ImageSource.UNSPECIFIED;
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new GetDefaultWorkspaceImageResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new GetDefaultWorkspaceImageResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new GetDefaultWorkspaceImageResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(GetDefaultWorkspaceImageResponse, a, b);
    }
}
GetDefaultWorkspaceImageResponse.runtime = proto3;
GetDefaultWorkspaceImageResponse.typeName = "gitpod.experimental.v1.GetDefaultWorkspaceImageResponse";
GetDefaultWorkspaceImageResponse.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "image", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "source", kind: "enum", T: proto3.getEnumType(GetDefaultWorkspaceImageResponse_ImageSource) },
]);
/**
 * @generated from enum gitpod.experimental.v1.GetDefaultWorkspaceImageResponse.ImageSource
 */
export var GetDefaultWorkspaceImageResponse_ImageSource;
(function (GetDefaultWorkspaceImageResponse_ImageSource) {
    /**
     * @generated from enum value: IMAGE_SOURCE_UNSPECIFIED = 0;
     */
    GetDefaultWorkspaceImageResponse_ImageSource[GetDefaultWorkspaceImageResponse_ImageSource["UNSPECIFIED"] = 0] = "UNSPECIFIED";
    /**
     * IMAGE_SOURCE_INSTALLATION means the image from Gitpod instance install config
     *
     * @generated from enum value: IMAGE_SOURCE_INSTALLATION = 1;
     */
    GetDefaultWorkspaceImageResponse_ImageSource[GetDefaultWorkspaceImageResponse_ImageSource["INSTALLATION"] = 1] = "INSTALLATION";
    /**
     * IMAGE_SOURCE_ORGANIZATION means the image from  Organization settings
     *
     * @generated from enum value: IMAGE_SOURCE_ORGANIZATION = 2;
     */
    GetDefaultWorkspaceImageResponse_ImageSource[GetDefaultWorkspaceImageResponse_ImageSource["ORGANIZATION"] = 2] = "ORGANIZATION";
})(GetDefaultWorkspaceImageResponse_ImageSource || (GetDefaultWorkspaceImageResponse_ImageSource = {}));
// Retrieve enum metadata with: proto3.getEnumType(GetDefaultWorkspaceImageResponse_ImageSource)
proto3.util.setEnumType(GetDefaultWorkspaceImageResponse_ImageSource, "gitpod.experimental.v1.GetDefaultWorkspaceImageResponse.ImageSource", [
    { no: 0, name: "IMAGE_SOURCE_UNSPECIFIED" },
    { no: 1, name: "IMAGE_SOURCE_INSTALLATION" },
    { no: 2, name: "IMAGE_SOURCE_ORGANIZATION" },
]);
//# sourceMappingURL=workspaces_pb.js.map