/**
 * Copyright (c) 2024 Gitpod GmbH. All rights reserved.
 * Licensed under the GNU Affero General Public License (AGPL).
 * See License.AGPL.txt in the project root for license information.
 */
import { Duration, Message, proto3, protoInt64, Timestamp } from "@bufbuild/protobuf";
import { PaginationRequest, PaginationResponse } from "./pagination_pb.js";
import { EditorReference } from "./editor_pb.js";
import { EnvironmentVariable } from "./envvar_pb.js";
/**
 * Admission level describes who can access a workspace instance and its ports.
 *
 * @generated from enum gitpod.v1.AdmissionLevel
 */
export var AdmissionLevel;
(function (AdmissionLevel) {
    /**
     * @generated from enum value: ADMISSION_LEVEL_UNSPECIFIED = 0;
     */
    AdmissionLevel[AdmissionLevel["UNSPECIFIED"] = 0] = "UNSPECIFIED";
    /**
     * ADMISSION_LEVEL_OWNER_ONLY means the workspace can only be accessed using
     * the owner token
     *
     * @generated from enum value: ADMISSION_LEVEL_OWNER_ONLY = 1;
     */
    AdmissionLevel[AdmissionLevel["OWNER_ONLY"] = 1] = "OWNER_ONLY";
    /**
     * ADMISSION_LEVEL_EVERYONE means the workspace (including ports) can be
     * accessed by everyone.
     *
     * @generated from enum value: ADMISSION_LEVEL_EVERYONE = 2;
     */
    AdmissionLevel[AdmissionLevel["EVERYONE"] = 2] = "EVERYONE";
})(AdmissionLevel || (AdmissionLevel = {}));
// Retrieve enum metadata with: proto3.getEnumType(AdmissionLevel)
proto3.util.setEnumType(AdmissionLevel, "gitpod.v1.AdmissionLevel", [
    { no: 0, name: "ADMISSION_LEVEL_UNSPECIFIED" },
    { no: 1, name: "ADMISSION_LEVEL_OWNER_ONLY" },
    { no: 2, name: "ADMISSION_LEVEL_EVERYONE" },
]);
/**
 * @generated from message gitpod.v1.UpdateWorkspacePortRequest
 */
export class UpdateWorkspacePortRequest extends Message {
    constructor(data) {
        super();
        /**
         * workspace_id specifies the workspace to update port
         *
         * +required
         *
         * @generated from field: string workspace_id = 1;
         */
        this.workspaceId = "";
        /**
         * port number
         *
         * +required
         *
         * @generated from field: uint64 port = 2;
         */
        this.port = protoInt64.zero;
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new UpdateWorkspacePortRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new UpdateWorkspacePortRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new UpdateWorkspacePortRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(UpdateWorkspacePortRequest, a, b);
    }
}
UpdateWorkspacePortRequest.runtime = proto3;
UpdateWorkspacePortRequest.typeName = "gitpod.v1.UpdateWorkspacePortRequest";
UpdateWorkspacePortRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "port", kind: "scalar", T: 4 /* ScalarType.UINT64 */ },
    { no: 3, name: "admission", kind: "enum", T: proto3.getEnumType(AdmissionLevel), opt: true },
    { no: 4, name: "protocol", kind: "enum", T: proto3.getEnumType(WorkspacePort_Protocol), opt: true },
]);
/**
 * @generated from message gitpod.v1.UpdateWorkspacePortResponse
 */
export class UpdateWorkspacePortResponse extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new UpdateWorkspacePortResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new UpdateWorkspacePortResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new UpdateWorkspacePortResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(UpdateWorkspacePortResponse, a, b);
    }
}
UpdateWorkspacePortResponse.runtime = proto3;
UpdateWorkspacePortResponse.typeName = "gitpod.v1.UpdateWorkspacePortResponse";
UpdateWorkspacePortResponse.fields = proto3.util.newFieldList(() => []);
/**
 * @generated from message gitpod.v1.GetWorkspaceRequest
 */
export class GetWorkspaceRequest extends Message {
    constructor(data) {
        super();
        /**
         * workspace_id specifies the workspace to get
         *
         * +required
         *
         * @generated from field: string workspace_id = 1;
         */
        this.workspaceId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new GetWorkspaceRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new GetWorkspaceRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new GetWorkspaceRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(GetWorkspaceRequest, a, b);
    }
}
GetWorkspaceRequest.runtime = proto3;
GetWorkspaceRequest.typeName = "gitpod.v1.GetWorkspaceRequest";
GetWorkspaceRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.v1.GetWorkspaceResponse
 */
export class GetWorkspaceResponse extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new GetWorkspaceResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new GetWorkspaceResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new GetWorkspaceResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(GetWorkspaceResponse, a, b);
    }
}
GetWorkspaceResponse.runtime = proto3;
GetWorkspaceResponse.typeName = "gitpod.v1.GetWorkspaceResponse";
GetWorkspaceResponse.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace", kind: "message", T: Workspace },
]);
/**
 * @generated from message gitpod.v1.WatchWorkspaceStatusRequest
 */
export class WatchWorkspaceStatusRequest extends Message {
    constructor(data) {
        super();
        /**
         * workspace_id specifies the workspace to watch
         *
         * +optional if empty then watch all workspaces
         *
         * @generated from field: string workspace_id = 1;
         */
        this.workspaceId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WatchWorkspaceStatusRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WatchWorkspaceStatusRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WatchWorkspaceStatusRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WatchWorkspaceStatusRequest, a, b);
    }
}
WatchWorkspaceStatusRequest.runtime = proto3;
WatchWorkspaceStatusRequest.typeName = "gitpod.v1.WatchWorkspaceStatusRequest";
WatchWorkspaceStatusRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.v1.WatchWorkspaceStatusResponse
 */
export class WatchWorkspaceStatusResponse extends Message {
    constructor(data) {
        super();
        /**
         * workspace_id is the ID of the workspace that has status updated
         *
         * @generated from field: string workspace_id = 1;
         */
        this.workspaceId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WatchWorkspaceStatusResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WatchWorkspaceStatusResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WatchWorkspaceStatusResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WatchWorkspaceStatusResponse, a, b);
    }
}
WatchWorkspaceStatusResponse.runtime = proto3;
WatchWorkspaceStatusResponse.typeName = "gitpod.v1.WatchWorkspaceStatusResponse";
WatchWorkspaceStatusResponse.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "status", kind: "message", T: WorkspaceStatus },
]);
/**
 * @generated from message gitpod.v1.ListWorkspacesRequest
 */
export class ListWorkspacesRequest extends Message {
    constructor(data) {
        super();
        /**
         * organization_id is the ID of the organization that contains the workspaces
         *
         * +required
         *
         * @generated from field: string organization_id = 2;
         */
        this.organizationId = "";
        /**
         * pinned indicates whether to list only pinned workspaces
         *
         * @generated from field: bool pinned = 3;
         */
        this.pinned = false;
        /**
         * search_term is a search term to filter workspaces by name
         *
         * @generated from field: string search_term = 4;
         */
        this.searchTerm = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new ListWorkspacesRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new ListWorkspacesRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new ListWorkspacesRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(ListWorkspacesRequest, a, b);
    }
}
ListWorkspacesRequest.runtime = proto3;
ListWorkspacesRequest.typeName = "gitpod.v1.ListWorkspacesRequest";
ListWorkspacesRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "pagination", kind: "message", T: PaginationRequest },
    { no: 2, name: "organization_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 3, name: "pinned", kind: "scalar", T: 8 /* ScalarType.BOOL */ },
    { no: 4, name: "search_term", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.v1.ListWorkspacesResponse
 */
export class ListWorkspacesResponse extends Message {
    constructor(data) {
        super();
        /**
         * workspaces are the workspaces that matched the query
         *
         * @generated from field: repeated gitpod.v1.Workspace workspaces = 2;
         */
        this.workspaces = [];
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new ListWorkspacesResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new ListWorkspacesResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new ListWorkspacesResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(ListWorkspacesResponse, a, b);
    }
}
ListWorkspacesResponse.runtime = proto3;
ListWorkspacesResponse.typeName = "gitpod.v1.ListWorkspacesResponse";
ListWorkspacesResponse.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "pagination", kind: "message", T: PaginationResponse },
    { no: 2, name: "workspaces", kind: "message", T: Workspace, repeated: true },
]);
/**
 * Required fields:
 * - metadata.organization_id
 * - metadata.configuration_id
 *
 * @generated from message gitpod.v1.CreateAndStartWorkspaceRequest
 */
export class CreateAndStartWorkspaceRequest extends Message {
    constructor(data) {
        super();
        /**
         * @generated from oneof gitpod.v1.CreateAndStartWorkspaceRequest.source
         */
        this.source = { case: undefined };
        /**
         * force_default_config indicates that the workspace should be created with
         * the default configuration instead of the configuration provided in
         * `.gitpod.yml` file
         *
         * @generated from field: bool force_default_config = 4 [deprecated = true];
         * @deprecated
         */
        this.forceDefaultConfig = false;
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new CreateAndStartWorkspaceRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new CreateAndStartWorkspaceRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new CreateAndStartWorkspaceRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(CreateAndStartWorkspaceRequest, a, b);
    }
}
CreateAndStartWorkspaceRequest.runtime = proto3;
CreateAndStartWorkspaceRequest.typeName = "gitpod.v1.CreateAndStartWorkspaceRequest";
CreateAndStartWorkspaceRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "metadata", kind: "message", T: WorkspaceMetadata },
    { no: 2, name: "context_url", kind: "message", T: CreateAndStartWorkspaceRequest_ContextURL, oneof: "source" },
    { no: 3, name: "spec", kind: "message", T: WorkspaceSpec, oneof: "source" },
    { no: 4, name: "force_default_config", kind: "scalar", T: 8 /* ScalarType.BOOL */ },
]);
/**
 * @generated from message gitpod.v1.CreateAndStartWorkspaceRequest.ContextURL
 */
export class CreateAndStartWorkspaceRequest_ContextURL extends Message {
    constructor(data) {
        super();
        /**
         * url is the URL from which the workspace is created
         *
         * @generated from field: string url = 1;
         */
        this.url = "";
        /**
         * workspace_class is the class of the workspace we ought to start
         *
         * @generated from field: string workspace_class = 2;
         */
        this.workspaceClass = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new CreateAndStartWorkspaceRequest_ContextURL().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new CreateAndStartWorkspaceRequest_ContextURL().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new CreateAndStartWorkspaceRequest_ContextURL().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(CreateAndStartWorkspaceRequest_ContextURL, a, b);
    }
}
CreateAndStartWorkspaceRequest_ContextURL.runtime = proto3;
CreateAndStartWorkspaceRequest_ContextURL.typeName = "gitpod.v1.CreateAndStartWorkspaceRequest.ContextURL";
CreateAndStartWorkspaceRequest_ContextURL.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "url", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "workspace_class", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 3, name: "editor", kind: "message", T: EditorReference },
]);
/**
 * @generated from message gitpod.v1.CreateAndStartWorkspaceResponse
 */
export class CreateAndStartWorkspaceResponse extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new CreateAndStartWorkspaceResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new CreateAndStartWorkspaceResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new CreateAndStartWorkspaceResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(CreateAndStartWorkspaceResponse, a, b);
    }
}
CreateAndStartWorkspaceResponse.runtime = proto3;
CreateAndStartWorkspaceResponse.typeName = "gitpod.v1.CreateAndStartWorkspaceResponse";
CreateAndStartWorkspaceResponse.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace", kind: "message", T: Workspace },
]);
/**
 * @generated from message gitpod.v1.StartWorkspaceRequest
 */
export class StartWorkspaceRequest extends Message {
    constructor(data) {
        super();
        /**
         * workspace_id specifies the workspace that is going to start
         *
         * +required
         *
         * @generated from field: string workspace_id = 1;
         */
        this.workspaceId = "";
        /**
         * @generated from field: bool force_default_config = 2 [deprecated = true];
         * @deprecated
         */
        this.forceDefaultConfig = false;
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new StartWorkspaceRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new StartWorkspaceRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new StartWorkspaceRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(StartWorkspaceRequest, a, b);
    }
}
StartWorkspaceRequest.runtime = proto3;
StartWorkspaceRequest.typeName = "gitpod.v1.StartWorkspaceRequest";
StartWorkspaceRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "force_default_config", kind: "scalar", T: 8 /* ScalarType.BOOL */ },
]);
/**
 * @generated from message gitpod.v1.StartWorkspaceResponse
 */
export class StartWorkspaceResponse extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new StartWorkspaceResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new StartWorkspaceResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new StartWorkspaceResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(StartWorkspaceResponse, a, b);
    }
}
StartWorkspaceResponse.runtime = proto3;
StartWorkspaceResponse.typeName = "gitpod.v1.StartWorkspaceResponse";
StartWorkspaceResponse.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace", kind: "message", T: Workspace },
]);
/**
 * @generated from message gitpod.v1.GetWorkspaceDefaultImageRequest
 */
export class GetWorkspaceDefaultImageRequest extends Message {
    constructor(data) {
        super();
        /**
         * workspace_id specifies the workspace to get default image
         *
         * @generated from field: string workspace_id = 1;
         */
        this.workspaceId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new GetWorkspaceDefaultImageRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new GetWorkspaceDefaultImageRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new GetWorkspaceDefaultImageRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(GetWorkspaceDefaultImageRequest, a, b);
    }
}
GetWorkspaceDefaultImageRequest.runtime = proto3;
GetWorkspaceDefaultImageRequest.typeName = "gitpod.v1.GetWorkspaceDefaultImageRequest";
GetWorkspaceDefaultImageRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.v1.GetWorkspaceDefaultImageResponse
 */
export class GetWorkspaceDefaultImageResponse extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string default_workspace_image = 1;
         */
        this.defaultWorkspaceImage = "";
        /**
         * @generated from field: gitpod.v1.GetWorkspaceDefaultImageResponse.Source source = 2;
         */
        this.source = GetWorkspaceDefaultImageResponse_Source.UNSPECIFIED;
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new GetWorkspaceDefaultImageResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new GetWorkspaceDefaultImageResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new GetWorkspaceDefaultImageResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(GetWorkspaceDefaultImageResponse, a, b);
    }
}
GetWorkspaceDefaultImageResponse.runtime = proto3;
GetWorkspaceDefaultImageResponse.typeName = "gitpod.v1.GetWorkspaceDefaultImageResponse";
GetWorkspaceDefaultImageResponse.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "default_workspace_image", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "source", kind: "enum", T: proto3.getEnumType(GetWorkspaceDefaultImageResponse_Source) },
]);
/**
 * @generated from enum gitpod.v1.GetWorkspaceDefaultImageResponse.Source
 */
export var GetWorkspaceDefaultImageResponse_Source;
(function (GetWorkspaceDefaultImageResponse_Source) {
    /**
     * @generated from enum value: SOURCE_UNSPECIFIED = 0;
     */
    GetWorkspaceDefaultImageResponse_Source[GetWorkspaceDefaultImageResponse_Source["UNSPECIFIED"] = 0] = "UNSPECIFIED";
    /**
     * @generated from enum value: SOURCE_INSTALLATION = 1;
     */
    GetWorkspaceDefaultImageResponse_Source[GetWorkspaceDefaultImageResponse_Source["INSTALLATION"] = 1] = "INSTALLATION";
    /**
     * @generated from enum value: SOURCE_ORGANIZATION = 2;
     */
    GetWorkspaceDefaultImageResponse_Source[GetWorkspaceDefaultImageResponse_Source["ORGANIZATION"] = 2] = "ORGANIZATION";
})(GetWorkspaceDefaultImageResponse_Source || (GetWorkspaceDefaultImageResponse_Source = {}));
// Retrieve enum metadata with: proto3.getEnumType(GetWorkspaceDefaultImageResponse_Source)
proto3.util.setEnumType(GetWorkspaceDefaultImageResponse_Source, "gitpod.v1.GetWorkspaceDefaultImageResponse.Source", [
    { no: 0, name: "SOURCE_UNSPECIFIED" },
    { no: 1, name: "SOURCE_INSTALLATION" },
    { no: 2, name: "SOURCE_ORGANIZATION" },
]);
/**
 * @generated from message gitpod.v1.SendHeartBeatRequest
 */
export class SendHeartBeatRequest extends Message {
    constructor(data) {
        super();
        /**
         * workspace_id specifies the workspace to send heartbeat
         *
         * +required
         *
         * @generated from field: string workspace_id = 1;
         */
        this.workspaceId = "";
        /**
         * disconnected indicates if the editor connection is disconnected.
         * If set to true, the workspace will be stopped after Timeout.disconnected.
         *
         * @generated from field: bool disconnected = 2;
         */
        this.disconnected = false;
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new SendHeartBeatRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new SendHeartBeatRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new SendHeartBeatRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(SendHeartBeatRequest, a, b);
    }
}
SendHeartBeatRequest.runtime = proto3;
SendHeartBeatRequest.typeName = "gitpod.v1.SendHeartBeatRequest";
SendHeartBeatRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "disconnected", kind: "scalar", T: 8 /* ScalarType.BOOL */ },
]);
/**
 * @generated from message gitpod.v1.SendHeartBeatResponse
 */
export class SendHeartBeatResponse extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new SendHeartBeatResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new SendHeartBeatResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new SendHeartBeatResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(SendHeartBeatResponse, a, b);
    }
}
SendHeartBeatResponse.runtime = proto3;
SendHeartBeatResponse.typeName = "gitpod.v1.SendHeartBeatResponse";
SendHeartBeatResponse.fields = proto3.util.newFieldList(() => []);
/**
 * @generated from message gitpod.v1.GetWorkspaceOwnerTokenRequest
 */
export class GetWorkspaceOwnerTokenRequest extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string workspace_id = 1;
         */
        this.workspaceId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new GetWorkspaceOwnerTokenRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new GetWorkspaceOwnerTokenRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new GetWorkspaceOwnerTokenRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(GetWorkspaceOwnerTokenRequest, a, b);
    }
}
GetWorkspaceOwnerTokenRequest.runtime = proto3;
GetWorkspaceOwnerTokenRequest.typeName = "gitpod.v1.GetWorkspaceOwnerTokenRequest";
GetWorkspaceOwnerTokenRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.v1.GetWorkspaceOwnerTokenResponse
 */
export class GetWorkspaceOwnerTokenResponse extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string owner_token = 1;
         */
        this.ownerToken = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new GetWorkspaceOwnerTokenResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new GetWorkspaceOwnerTokenResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new GetWorkspaceOwnerTokenResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(GetWorkspaceOwnerTokenResponse, a, b);
    }
}
GetWorkspaceOwnerTokenResponse.runtime = proto3;
GetWorkspaceOwnerTokenResponse.typeName = "gitpod.v1.GetWorkspaceOwnerTokenResponse";
GetWorkspaceOwnerTokenResponse.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "owner_token", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.v1.GetWorkspaceEditorCredentialsRequest
 */
export class GetWorkspaceEditorCredentialsRequest extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string workspace_id = 1;
         */
        this.workspaceId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new GetWorkspaceEditorCredentialsRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new GetWorkspaceEditorCredentialsRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new GetWorkspaceEditorCredentialsRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(GetWorkspaceEditorCredentialsRequest, a, b);
    }
}
GetWorkspaceEditorCredentialsRequest.runtime = proto3;
GetWorkspaceEditorCredentialsRequest.typeName = "gitpod.v1.GetWorkspaceEditorCredentialsRequest";
GetWorkspaceEditorCredentialsRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.v1.GetWorkspaceEditorCredentialsResponse
 */
export class GetWorkspaceEditorCredentialsResponse extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string editor_credentials = 1;
         */
        this.editorCredentials = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new GetWorkspaceEditorCredentialsResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new GetWorkspaceEditorCredentialsResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new GetWorkspaceEditorCredentialsResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(GetWorkspaceEditorCredentialsResponse, a, b);
    }
}
GetWorkspaceEditorCredentialsResponse.runtime = proto3;
GetWorkspaceEditorCredentialsResponse.typeName = "gitpod.v1.GetWorkspaceEditorCredentialsResponse";
GetWorkspaceEditorCredentialsResponse.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "editor_credentials", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * +resource get workspace
 *
 * @generated from message gitpod.v1.Workspace
 */
export class Workspace extends Message {
    constructor(data) {
        super();
        /**
         * ID is a unique identifier of this workspace. No other workspace with the same name must be managed by this workspace manager
         *
         * @generated from field: string id = 1;
         */
        this.id = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new Workspace().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new Workspace().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new Workspace().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(Workspace, a, b);
    }
}
Workspace.runtime = proto3;
Workspace.typeName = "gitpod.v1.Workspace";
Workspace.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "metadata", kind: "message", T: WorkspaceMetadata },
    { no: 3, name: "spec", kind: "message", T: WorkspaceSpec },
    { no: 4, name: "status", kind: "message", T: WorkspaceStatus },
]);
/**
 * WorkspaceMetadata is data associated with a workspace that's required for other parts of the system to function
 *
 * @generated from message gitpod.v1.WorkspaceMetadata
 */
export class WorkspaceMetadata extends Message {
    constructor(data) {
        super();
        /**
         * owner_id is the ID of the Gitpod user to whom we'll bill this workspace and who we consider responsible for its content
         *
         * @generated from field: string owner_id = 1;
         */
        this.ownerId = "";
        /**
         * organization_id is the ID of the organization that contains the workspace
         *
         * @generated from field: string organization_id = 2;
         */
        this.organizationId = "";
        /**
         * configuration_id is the ID of the configuration used by this workspace
         *
         * @generated from field: string configuration_id = 3;
         */
        this.configurationId = "";
        /**
         * annotations are key/value pairs that gets attached to the workspace.
         * +internal - not yet implemented
         *
         * @generated from field: map<string, string> annotations = 4;
         */
        this.annotations = {};
        /**
         * name is the name of the workspace as specified by the user
         *
         * @generated from field: string name = 5;
         */
        this.name = "";
        /**
         * pinned indicates whether the workspace is pinned
         *
         * @generated from field: bool pinned = 6;
         */
        this.pinned = false;
        /**
         * original_context_url is the normalized URL from which the workspace was created
         *
         * @generated from field: string original_context_url = 7;
         */
        this.originalContextUrl = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceMetadata().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceMetadata().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceMetadata().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceMetadata, a, b);
    }
}
WorkspaceMetadata.runtime = proto3;
WorkspaceMetadata.typeName = "gitpod.v1.WorkspaceMetadata";
WorkspaceMetadata.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "owner_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "organization_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 3, name: "configuration_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 4, name: "annotations", kind: "map", K: 9 /* ScalarType.STRING */, V: { kind: "scalar", T: 9 /* ScalarType.STRING */ } },
    { no: 5, name: "name", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 6, name: "pinned", kind: "scalar", T: 8 /* ScalarType.BOOL */ },
    { no: 7, name: "original_context_url", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * WorkspaceSpec specifies the configuration of a workspace for a workspace start
 *
 * @generated from message gitpod.v1.WorkspaceSpec
 */
export class WorkspaceSpec extends Message {
    constructor(data) {
        super();
        /**
         * Type denots the kind of workspace we ought to start
         *
         * @generated from field: gitpod.v1.WorkspaceSpec.WorkspaceType type = 2;
         */
        this.type = WorkspaceSpec_WorkspaceType.UNSPECIFIED;
        /**
         * ports is the set of ports which ought to be exposed to the internet
         *
         * @generated from field: repeated gitpod.v1.WorkspacePort ports = 3;
         */
        this.ports = [];
        /**
         * envvars are user-defined environment variables which ought to be available in the workspace (shim'ed environment)
         *
         * @generated from field: repeated gitpod.v1.EnvironmentVariable environment_variables = 4;
         */
        this.environmentVariables = [];
        /**
         * admission controlls who can access the workspace and its ports.
         *
         * @generated from field: gitpod.v1.AdmissionLevel admission = 7;
         */
        this.admission = AdmissionLevel.UNSPECIFIED;
        /**
         * Class denotes the class of the workspace we ought to start
         *
         * @generated from field: string class = 8;
         */
        this.class = "";
        /**
         * ssh_public_keys is user's uploaded ssh public keys
         *
         * @generated from field: repeated string ssh_public_keys = 9;
         */
        this.sshPublicKeys = [];
        /**
         * subassembly_references is a list of workspace IDs that this workspace depends on.
         * For example:
         *   index.docker.io/gitpod-io/subassmeblies/code:latest
         *
         * @generated from field: repeated string subassembly_references = 10;
         */
        this.subassemblyReferences = [];
        /**
         * log_url is the URL where we stream the workspace's logs to.
         * Can be changed when the workspace is PENDING or STOPPED.
         *
         * @generated from field: string log_url = 12;
         */
        this.logUrl = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceSpec().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceSpec().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceSpec().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceSpec, a, b);
    }
}
WorkspaceSpec.runtime = proto3;
WorkspaceSpec.typeName = "gitpod.v1.WorkspaceSpec";
WorkspaceSpec.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "initializer", kind: "message", T: WorkspaceInitializer },
    { no: 2, name: "type", kind: "enum", T: proto3.getEnumType(WorkspaceSpec_WorkspaceType) },
    { no: 3, name: "ports", kind: "message", T: WorkspacePort, repeated: true },
    { no: 4, name: "environment_variables", kind: "message", T: EnvironmentVariable, repeated: true },
    { no: 5, name: "git", kind: "message", T: WorkspaceSpec_GitSpec },
    { no: 6, name: "timeout", kind: "message", T: WorkspaceSpec_Timeout },
    { no: 7, name: "admission", kind: "enum", T: proto3.getEnumType(AdmissionLevel) },
    { no: 8, name: "class", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 9, name: "ssh_public_keys", kind: "scalar", T: 9 /* ScalarType.STRING */, repeated: true },
    { no: 10, name: "subassembly_references", kind: "scalar", T: 9 /* ScalarType.STRING */, repeated: true },
    { no: 11, name: "last_user_activity", kind: "message", T: Timestamp },
    { no: 12, name: "log_url", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 13, name: "editor", kind: "message", T: EditorReference },
]);
/**
 * WorkspaceType specifies the purpose/use of a workspace. Different workspace types are handled differently by all parts of the system.
 *
 * @generated from enum gitpod.v1.WorkspaceSpec.WorkspaceType
 */
export var WorkspaceSpec_WorkspaceType;
(function (WorkspaceSpec_WorkspaceType) {
    /**
     * @generated from enum value: WORKSPACE_TYPE_UNSPECIFIED = 0;
     */
    WorkspaceSpec_WorkspaceType[WorkspaceSpec_WorkspaceType["UNSPECIFIED"] = 0] = "UNSPECIFIED";
    /**
     * Regular workspaces are your off-the-mill workspaces intended for users. They are directly user-facing and hence are most important.
     *
     * @generated from enum value: WORKSPACE_TYPE_REGULAR = 1;
     */
    WorkspaceSpec_WorkspaceType[WorkspaceSpec_WorkspaceType["REGULAR"] = 1] = "REGULAR";
    /**
     * Prebuild workspaces are workspaces used to pre-build the content of other workspaces. They run headless and have no direct user-interaction.
     *
     * @generated from enum value: WORKSPACE_TYPE_PREBUILD = 2;
     */
    WorkspaceSpec_WorkspaceType[WorkspaceSpec_WorkspaceType["PREBUILD"] = 2] = "PREBUILD";
})(WorkspaceSpec_WorkspaceType || (WorkspaceSpec_WorkspaceType = {}));
// Retrieve enum metadata with: proto3.getEnumType(WorkspaceSpec_WorkspaceType)
proto3.util.setEnumType(WorkspaceSpec_WorkspaceType, "gitpod.v1.WorkspaceSpec.WorkspaceType", [
    { no: 0, name: "WORKSPACE_TYPE_UNSPECIFIED" },
    { no: 1, name: "WORKSPACE_TYPE_REGULAR" },
    { no: 2, name: "WORKSPACE_TYPE_PREBUILD" },
]);
/**
 * Timeout configures the workspace timeout
 *
 * @generated from message gitpod.v1.WorkspaceSpec.Timeout
 */
export class WorkspaceSpec_Timeout extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceSpec_Timeout().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceSpec_Timeout().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceSpec_Timeout().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceSpec_Timeout, a, b);
    }
}
WorkspaceSpec_Timeout.runtime = proto3;
WorkspaceSpec_Timeout.typeName = "gitpod.v1.WorkspaceSpec.Timeout";
WorkspaceSpec_Timeout.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "inactivity", kind: "message", T: Duration },
    { no: 2, name: "disconnected", kind: "message", T: Duration },
    { no: 3, name: "maximum_lifetime", kind: "message", T: Duration },
]);
/**
 * GitSpec configures the Git available within the workspace
 *
 * @generated from message gitpod.v1.WorkspaceSpec.GitSpec
 */
export class WorkspaceSpec_GitSpec extends Message {
    constructor(data) {
        super();
        /**
         * The Git username
         *
         * @generated from field: string username = 1;
         */
        this.username = "";
        /**
         * The Git email address
         *
         * @generated from field: string email = 2;
         */
        this.email = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceSpec_GitSpec().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceSpec_GitSpec().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceSpec_GitSpec().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceSpec_GitSpec, a, b);
    }
}
WorkspaceSpec_GitSpec.runtime = proto3;
WorkspaceSpec_GitSpec.typeName = "gitpod.v1.WorkspaceSpec.GitSpec";
WorkspaceSpec_GitSpec.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "username", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "email", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * WorkspaceStatus describes a workspace status
 *
 * @generated from message gitpod.v1.WorkspaceStatus
 */
export class WorkspaceStatus extends Message {
    constructor(data) {
        super();
        /**
         * version of the status update. Workspace instances themselves are unversioned,
         * but their statuus has different versions.
         * The value of this field has no semantic meaning (e.g. don't interpret it as
         * as a timestemp), but it can be used to impose a partial order.
         * If a.status_version < b.status_version then a was the status before b.
         *
         * @generated from field: uint64 status_version = 1;
         */
        this.statusVersion = protoInt64.zero;
        /**
         * workspace_url contains the URL at which the workspace can be accessed.
         * This field is only set if the workspace is running.
         *
         * @generated from field: string workspace_url = 3;
         */
        this.workspaceUrl = "";
        /**
         * instance_id is the ID of the workspace instance - do not use, interpret or rely on this field
         * unless you know what you're doing.
         *
         * @generated from field: string instance_id = 7 [deprecated = true];
         * @deprecated
         */
        this.instanceId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceStatus().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceStatus().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceStatus().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceStatus, a, b);
    }
}
WorkspaceStatus.runtime = proto3;
WorkspaceStatus.typeName = "gitpod.v1.WorkspaceStatus";
WorkspaceStatus.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "status_version", kind: "scalar", T: 4 /* ScalarType.UINT64 */ },
    { no: 2, name: "phase", kind: "message", T: WorkspacePhase },
    { no: 3, name: "workspace_url", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 4, name: "conditions", kind: "message", T: WorkspaceStatus_WorkspaceConditions },
    { no: 5, name: "prebuild_result", kind: "message", T: WorkspaceStatus_PrebuildResult },
    { no: 6, name: "git_status", kind: "message", T: WorkspaceGitStatus },
    { no: 7, name: "instance_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * WorkspaceCondition gives more detailed information as to the state of the workspace. Which condition actually
 * has a value depends on the phase the workspace is in.
 *
 * @generated from message gitpod.v1.WorkspaceStatus.WorkspaceConditions
 */
export class WorkspaceStatus_WorkspaceConditions extends Message {
    constructor(data) {
        super();
        /**
         * failed contains the reason the workspace failed to operate. If this field is empty, the workspace has not failed.
         *
         * @generated from field: string failed = 1;
         */
        this.failed = "";
        /**
         * failed_reason contains the reason the workspace failed to operate.
         * This field is only set if the workspace has failed.
         *
         * @generated from field: gitpod.v1.WorkspaceStatus.WorkspaceConditions.FailedReason failed_reason = 2;
         */
        this.failedReason = WorkspaceStatus_WorkspaceConditions_FailedReason.UNSPECIFIED;
        /**
         * timeout contains the reason the workspace has timed out. If this field is empty, the workspace has not timed out.
         *
         * @generated from field: string timeout = 3;
         */
        this.timeout = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceStatus_WorkspaceConditions().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceStatus_WorkspaceConditions().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceStatus_WorkspaceConditions().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceStatus_WorkspaceConditions, a, b);
    }
}
WorkspaceStatus_WorkspaceConditions.runtime = proto3;
WorkspaceStatus_WorkspaceConditions.typeName = "gitpod.v1.WorkspaceStatus.WorkspaceConditions";
WorkspaceStatus_WorkspaceConditions.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "failed", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "failed_reason", kind: "enum", T: proto3.getEnumType(WorkspaceStatus_WorkspaceConditions_FailedReason) },
    { no: 3, name: "timeout", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from enum gitpod.v1.WorkspaceStatus.WorkspaceConditions.FailedReason
 */
export var WorkspaceStatus_WorkspaceConditions_FailedReason;
(function (WorkspaceStatus_WorkspaceConditions_FailedReason) {
    /**
     * @generated from enum value: FAILED_REASON_UNSPECIFIED = 0;
     */
    WorkspaceStatus_WorkspaceConditions_FailedReason[WorkspaceStatus_WorkspaceConditions_FailedReason["UNSPECIFIED"] = 0] = "UNSPECIFIED";
    /**
     * @generated from enum value: FAILED_REASON_CONTENT_INITIALIZATION_FAILED = 1;
     */
    WorkspaceStatus_WorkspaceConditions_FailedReason[WorkspaceStatus_WorkspaceConditions_FailedReason["CONTENT_INITIALIZATION_FAILED"] = 1] = "CONTENT_INITIALIZATION_FAILED";
    /**
     * @generated from enum value: FAILED_REASON_BACKUP_FAILED = 2;
     */
    WorkspaceStatus_WorkspaceConditions_FailedReason[WorkspaceStatus_WorkspaceConditions_FailedReason["BACKUP_FAILED"] = 2] = "BACKUP_FAILED";
    /**
     * @generated from enum value: FAILED_REASON_IMAGE_PULL_FAILURE = 3;
     */
    WorkspaceStatus_WorkspaceConditions_FailedReason[WorkspaceStatus_WorkspaceConditions_FailedReason["IMAGE_PULL_FAILURE"] = 3] = "IMAGE_PULL_FAILURE";
    /**
     * @generated from enum value: FAILED_REASON_UNEXPECTED_TERMINATION = 4;
     */
    WorkspaceStatus_WorkspaceConditions_FailedReason[WorkspaceStatus_WorkspaceConditions_FailedReason["UNEXPECTED_TERMINATION"] = 4] = "UNEXPECTED_TERMINATION";
})(WorkspaceStatus_WorkspaceConditions_FailedReason || (WorkspaceStatus_WorkspaceConditions_FailedReason = {}));
// Retrieve enum metadata with: proto3.getEnumType(WorkspaceStatus_WorkspaceConditions_FailedReason)
proto3.util.setEnumType(WorkspaceStatus_WorkspaceConditions_FailedReason, "gitpod.v1.WorkspaceStatus.WorkspaceConditions.FailedReason", [
    { no: 0, name: "FAILED_REASON_UNSPECIFIED" },
    { no: 1, name: "FAILED_REASON_CONTENT_INITIALIZATION_FAILED" },
    { no: 2, name: "FAILED_REASON_BACKUP_FAILED" },
    { no: 3, name: "FAILED_REASON_IMAGE_PULL_FAILURE" },
    { no: 4, name: "FAILED_REASON_UNEXPECTED_TERMINATION" },
]);
/**
 * @generated from message gitpod.v1.WorkspaceStatus.PrebuildResult
 */
export class WorkspaceStatus_PrebuildResult extends Message {
    constructor(data) {
        super();
        /**
         * Snapshot points to the content of the prebuild. This string is opaque to the cluster manager,
         * and must be returned unaltered.
         *
         * @generated from field: string snapshot = 1;
         */
        this.snapshot = "";
        /**
         * The prebuild's error message
         *
         * @generated from field: string error_message = 2;
         */
        this.errorMessage = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceStatus_PrebuildResult().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceStatus_PrebuildResult().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceStatus_PrebuildResult().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceStatus_PrebuildResult, a, b);
    }
}
WorkspaceStatus_PrebuildResult.runtime = proto3;
WorkspaceStatus_PrebuildResult.typeName = "gitpod.v1.WorkspaceStatus.PrebuildResult";
WorkspaceStatus_PrebuildResult.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "snapshot", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "error_message", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.v1.WorkspacePort
 */
export class WorkspacePort extends Message {
    constructor(data) {
        super();
        /**
         * port number
         *
         * @generated from field: uint64 port = 1;
         */
        this.port = protoInt64.zero;
        /**
         * policy of this port
         *
         * @generated from field: gitpod.v1.AdmissionLevel admission = 2;
         */
        this.admission = AdmissionLevel.UNSPECIFIED;
        /**
         * url that can be used to access the port
         *
         * @generated from field: string url = 3;
         */
        this.url = "";
        /**
         * backend protocol of this port
         *
         * @generated from field: gitpod.v1.WorkspacePort.Protocol protocol = 4;
         */
        this.protocol = WorkspacePort_Protocol.UNSPECIFIED;
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspacePort().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspacePort().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspacePort().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspacePort, a, b);
    }
}
WorkspacePort.runtime = proto3;
WorkspacePort.typeName = "gitpod.v1.WorkspacePort";
WorkspacePort.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "port", kind: "scalar", T: 4 /* ScalarType.UINT64 */ },
    { no: 2, name: "admission", kind: "enum", T: proto3.getEnumType(AdmissionLevel) },
    { no: 3, name: "url", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 4, name: "protocol", kind: "enum", T: proto3.getEnumType(WorkspacePort_Protocol) },
]);
/**
 * Protocol defines the backend protocol of port
 *
 * @generated from enum gitpod.v1.WorkspacePort.Protocol
 */
export var WorkspacePort_Protocol;
(function (WorkspacePort_Protocol) {
    /**
     * @generated from enum value: PROTOCOL_UNSPECIFIED = 0;
     */
    WorkspacePort_Protocol[WorkspacePort_Protocol["UNSPECIFIED"] = 0] = "UNSPECIFIED";
    /**
     * Http means the port backend is http
     *
     * @generated from enum value: PROTOCOL_HTTP = 1;
     */
    WorkspacePort_Protocol[WorkspacePort_Protocol["HTTP"] = 1] = "HTTP";
    /**
     * Https means the port backend is https
     *
     * @generated from enum value: PROTOCOL_HTTPS = 2;
     */
    WorkspacePort_Protocol[WorkspacePort_Protocol["HTTPS"] = 2] = "HTTPS";
})(WorkspacePort_Protocol || (WorkspacePort_Protocol = {}));
// Retrieve enum metadata with: proto3.getEnumType(WorkspacePort_Protocol)
proto3.util.setEnumType(WorkspacePort_Protocol, "gitpod.v1.WorkspacePort.Protocol", [
    { no: 0, name: "PROTOCOL_UNSPECIFIED" },
    { no: 1, name: "PROTOCOL_HTTP" },
    { no: 2, name: "PROTOCOL_HTTPS" },
]);
/**
 * @generated from message gitpod.v1.WorkspaceGitStatus
 */
export class WorkspaceGitStatus extends Message {
    constructor(data) {
        super();
        /**
         * clone_url is the repository url as you would pass it to "git clone".
         * Only HTTPS clone URLs are supported.
         *
         * @generated from field: string clone_url = 1;
         */
        this.cloneUrl = "";
        /**
         * branch is branch we're currently on
         *
         * @generated from field: string branch = 2;
         */
        this.branch = "";
        /**
         * latest_commit is the most recent commit on the current branch
         *
         * @generated from field: string latest_commit = 3;
         */
        this.latestCommit = "";
        /**
         * uncommited_files is an array of uncommitted files, possibly truncated
         *
         * @generated from field: repeated string uncommited_files = 4;
         */
        this.uncommitedFiles = [];
        /**
         * the total number of uncommited files
         *
         * @generated from field: int32 total_uncommited_files = 5;
         */
        this.totalUncommitedFiles = 0;
        /**
         * untracked_files is an array of untracked files in the workspace, possibly
         * truncated
         *
         * @generated from field: repeated string untracked_files = 6;
         */
        this.untrackedFiles = [];
        /**
         * the total number of untracked files
         *
         * @generated from field: int32 total_untracked_files = 7;
         */
        this.totalUntrackedFiles = 0;
        /**
         * unpushed_commits is an array of unpushed changes in the workspace, possibly
         * truncated
         *
         * @generated from field: repeated string unpushed_commits = 8;
         */
        this.unpushedCommits = [];
        /**
         * the total number of unpushed changes
         *
         * @generated from field: int32 total_unpushed_commits = 9;
         */
        this.totalUnpushedCommits = 0;
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceGitStatus().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceGitStatus().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceGitStatus().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceGitStatus, a, b);
    }
}
WorkspaceGitStatus.runtime = proto3;
WorkspaceGitStatus.typeName = "gitpod.v1.WorkspaceGitStatus";
WorkspaceGitStatus.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "clone_url", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "branch", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 3, name: "latest_commit", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 4, name: "uncommited_files", kind: "scalar", T: 9 /* ScalarType.STRING */, repeated: true },
    { no: 5, name: "total_uncommited_files", kind: "scalar", T: 5 /* ScalarType.INT32 */ },
    { no: 6, name: "untracked_files", kind: "scalar", T: 9 /* ScalarType.STRING */, repeated: true },
    { no: 7, name: "total_untracked_files", kind: "scalar", T: 5 /* ScalarType.INT32 */ },
    { no: 8, name: "unpushed_commits", kind: "scalar", T: 9 /* ScalarType.STRING */, repeated: true },
    { no: 9, name: "total_unpushed_commits", kind: "scalar", T: 5 /* ScalarType.INT32 */ },
]);
/**
 * @generated from message gitpod.v1.WorkspacePhase
 */
export class WorkspacePhase extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: gitpod.v1.WorkspacePhase.Phase name = 1;
         */
        this.name = WorkspacePhase_Phase.UNSPECIFIED;
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspacePhase().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspacePhase().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspacePhase().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspacePhase, a, b);
    }
}
WorkspacePhase.runtime = proto3;
WorkspacePhase.typeName = "gitpod.v1.WorkspacePhase";
WorkspacePhase.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "name", kind: "enum", T: proto3.getEnumType(WorkspacePhase_Phase) },
    { no: 2, name: "last_transition_time", kind: "message", T: Timestamp },
]);
/**
 * @generated from enum gitpod.v1.WorkspacePhase.Phase
 */
export var WorkspacePhase_Phase;
(function (WorkspacePhase_Phase) {
    /**
     * Unknown indicates an issue within the workspace manager in that it cannot
     * determine the actual phase of a workspace. This phase is usually
     * accompanied by an error.
     *
     * @generated from enum value: PHASE_UNSPECIFIED = 0;
     */
    WorkspacePhase_Phase[WorkspacePhase_Phase["UNSPECIFIED"] = 0] = "UNSPECIFIED";
    /**
     * Preparing means that we haven't actually started the workspace instance
     * just yet, but rather are still preparing for launch.
     *
     * @generated from enum value: PHASE_PREPARING = 1;
     */
    WorkspacePhase_Phase[WorkspacePhase_Phase["PREPARING"] = 1] = "PREPARING";
    /**
     * ImageBuild indicates that there's an image build running for this
     * workspace.
     *
     * @generated from enum value: PHASE_IMAGEBUILD = 2;
     */
    WorkspacePhase_Phase[WorkspacePhase_Phase["IMAGEBUILD"] = 2] = "IMAGEBUILD";
    /**
     * Pending means the workspace does not yet consume resources in the
     * cluster, but rather is looking for some space within the cluster. If for
     * example the cluster needs to scale up to accomodate the workspace, the
     * workspace will be in Pending state until that happened.
     *
     * @generated from enum value: PHASE_PENDING = 3;
     */
    WorkspacePhase_Phase[WorkspacePhase_Phase["PENDING"] = 3] = "PENDING";
    /**
     * Creating means the workspace is currently being created. That includes
     * downloading the images required to run the workspace over the network.
     * The time spent in this phase varies widely and depends on the current
     * network speed, image size and cache states.
     *
     * @generated from enum value: PHASE_CREATING = 4;
     */
    WorkspacePhase_Phase[WorkspacePhase_Phase["CREATING"] = 4] = "CREATING";
    /**
     * Initializing is the phase in which the workspace is executing the
     * appropriate workspace initializer (e.g. Git clone or backup download).
     * After this phase one can expect the workspace to either be Running or
     * Failed.
     *
     * @generated from enum value: PHASE_INITIALIZING = 5;
     */
    WorkspacePhase_Phase[WorkspacePhase_Phase["INITIALIZING"] = 5] = "INITIALIZING";
    /**
     * Running means the workspace is able to actively perform work, either by
     * serving a user through Theia, or as a headless workspace.
     *
     * @generated from enum value: PHASE_RUNNING = 6;
     */
    WorkspacePhase_Phase[WorkspacePhase_Phase["RUNNING"] = 6] = "RUNNING";
    /**
     * Interrupted is an exceptional state where the container should be running
     * but is temporarily unavailable. When in this state, we expect it to
     * become running or stopping anytime soon.
     *
     * @generated from enum value: PHASE_INTERRUPTED = 7;
     */
    WorkspacePhase_Phase[WorkspacePhase_Phase["INTERRUPTED"] = 7] = "INTERRUPTED";
    /**
     * Paused means the workspace is currently unavailable, akin to stopped,
     * but faster to wake up.
     *
     * @generated from enum value: PHASE_PAUSED = 8;
     */
    WorkspacePhase_Phase[WorkspacePhase_Phase["PAUSED"] = 8] = "PAUSED";
    /**
     * Stopping means that the workspace is currently shutting down. It could go
     * to stopped every moment.
     *
     * @generated from enum value: PHASE_STOPPING = 9;
     */
    WorkspacePhase_Phase[WorkspacePhase_Phase["STOPPING"] = 9] = "STOPPING";
    /**
     * Stopped means the workspace ended regularly because it was shut down.
     *
     * @generated from enum value: PHASE_STOPPED = 10;
     */
    WorkspacePhase_Phase[WorkspacePhase_Phase["STOPPED"] = 10] = "STOPPED";
})(WorkspacePhase_Phase || (WorkspacePhase_Phase = {}));
// Retrieve enum metadata with: proto3.getEnumType(WorkspacePhase_Phase)
proto3.util.setEnumType(WorkspacePhase_Phase, "gitpod.v1.WorkspacePhase.Phase", [
    { no: 0, name: "PHASE_UNSPECIFIED" },
    { no: 1, name: "PHASE_PREPARING" },
    { no: 2, name: "PHASE_IMAGEBUILD" },
    { no: 3, name: "PHASE_PENDING" },
    { no: 4, name: "PHASE_CREATING" },
    { no: 5, name: "PHASE_INITIALIZING" },
    { no: 6, name: "PHASE_RUNNING" },
    { no: 7, name: "PHASE_INTERRUPTED" },
    { no: 8, name: "PHASE_PAUSED" },
    { no: 9, name: "PHASE_STOPPING" },
    { no: 10, name: "PHASE_STOPPED" },
]);
/**
 * WorkspaceInitializer specifies how a workspace is to be initialized
 *
 * @generated from message gitpod.v1.WorkspaceInitializer
 */
export class WorkspaceInitializer extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: repeated gitpod.v1.WorkspaceInitializer.Spec specs = 1;
         */
        this.specs = [];
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceInitializer().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceInitializer().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceInitializer().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceInitializer, a, b);
    }
}
WorkspaceInitializer.runtime = proto3;
WorkspaceInitializer.typeName = "gitpod.v1.WorkspaceInitializer";
WorkspaceInitializer.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "specs", kind: "message", T: WorkspaceInitializer_Spec, repeated: true },
]);
/**
 * @generated from message gitpod.v1.WorkspaceInitializer.Spec
 */
export class WorkspaceInitializer_Spec extends Message {
    constructor(data) {
        super();
        /**
         * @generated from oneof gitpod.v1.WorkspaceInitializer.Spec.spec
         */
        this.spec = { case: undefined };
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceInitializer_Spec().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceInitializer_Spec().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceInitializer_Spec().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceInitializer_Spec, a, b);
    }
}
WorkspaceInitializer_Spec.runtime = proto3;
WorkspaceInitializer_Spec.typeName = "gitpod.v1.WorkspaceInitializer.Spec";
WorkspaceInitializer_Spec.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "git", kind: "message", T: GitInitializer, oneof: "spec" },
    { no: 2, name: "snapshot", kind: "message", T: SnapshotInitializer, oneof: "spec" },
    { no: 3, name: "prebuild", kind: "message", T: PrebuildInitializer, oneof: "spec" },
    { no: 4, name: "download", kind: "message", T: FileDownloadInitializer, oneof: "spec" },
]);
/**
 * @generated from message gitpod.v1.GitInitializer
 */
export class GitInitializer extends Message {
    constructor(data) {
        super();
        /**
         * remote_uri is the Git remote origin
         *
         * @generated from field: string remote_uri = 1;
         */
        this.remoteUri = "";
        /**
         * upstream_Remote_uri is the fork upstream of a repository
         *
         * @generated from field: string upstream_remote_uri = 2;
         */
        this.upstreamRemoteUri = "";
        /**
         * the target mode determines what gets checked out
         *
         * @generated from field: gitpod.v1.GitInitializer.CloneTargetMode target_mode = 3;
         */
        this.targetMode = GitInitializer_CloneTargetMode.UNSPECIFIED;
        /**
         * the value for the clone target mode - use depends on the target mode
         *
         * @generated from field: string clone_target = 4;
         */
        this.cloneTarget = "";
        /**
         * a path relative to the workspace root in which the code will be checked out to
         *
         * @generated from field: string checkout_location = 5;
         */
        this.checkoutLocation = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new GitInitializer().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new GitInitializer().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new GitInitializer().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(GitInitializer, a, b);
    }
}
GitInitializer.runtime = proto3;
GitInitializer.typeName = "gitpod.v1.GitInitializer";
GitInitializer.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "remote_uri", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "upstream_remote_uri", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 3, name: "target_mode", kind: "enum", T: proto3.getEnumType(GitInitializer_CloneTargetMode) },
    { no: 4, name: "clone_target", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 5, name: "checkout_location", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 6, name: "config", kind: "message", T: GitInitializer_GitConfig },
]);
/**
 * CloneTargetMode is the target state in which we want to leave a GitWorkspace
 *
 * @generated from enum gitpod.v1.GitInitializer.CloneTargetMode
 */
export var GitInitializer_CloneTargetMode;
(function (GitInitializer_CloneTargetMode) {
    /**
     * @generated from enum value: CLONE_TARGET_MODE_UNSPECIFIED = 0;
     */
    GitInitializer_CloneTargetMode[GitInitializer_CloneTargetMode["UNSPECIFIED"] = 0] = "UNSPECIFIED";
    /**
     * REMOTE_HEAD has the local WS point at the remote branch head
     *
     * @generated from enum value: CLONE_TARGET_MODE_REMOTE_HEAD = 1;
     */
    GitInitializer_CloneTargetMode[GitInitializer_CloneTargetMode["REMOTE_HEAD"] = 1] = "REMOTE_HEAD";
    /**
     * REMOTE_COMMIT has the local WS point at a specific commit
     *
     * @generated from enum value: CLONE_TARGET_MODE_REMOTE_COMMIT = 2;
     */
    GitInitializer_CloneTargetMode[GitInitializer_CloneTargetMode["REMOTE_COMMIT"] = 2] = "REMOTE_COMMIT";
    /**
     * REMOTE_BRANCH has the local WS point at a remote branch
     *
     * @generated from enum value: CLONE_TARGET_MODE_REMOTE_BRANCH = 3;
     */
    GitInitializer_CloneTargetMode[GitInitializer_CloneTargetMode["REMOTE_BRANCH"] = 3] = "REMOTE_BRANCH";
    /**
     * LOCAL_BRANCH creates a local branch in the workspace
     *
     * @generated from enum value: CLONE_TARGET_MODE_LOCAL_BRANCH = 4;
     */
    GitInitializer_CloneTargetMode[GitInitializer_CloneTargetMode["LOCAL_BRANCH"] = 4] = "LOCAL_BRANCH";
})(GitInitializer_CloneTargetMode || (GitInitializer_CloneTargetMode = {}));
// Retrieve enum metadata with: proto3.getEnumType(GitInitializer_CloneTargetMode)
proto3.util.setEnumType(GitInitializer_CloneTargetMode, "gitpod.v1.GitInitializer.CloneTargetMode", [
    { no: 0, name: "CLONE_TARGET_MODE_UNSPECIFIED" },
    { no: 1, name: "CLONE_TARGET_MODE_REMOTE_HEAD" },
    { no: 2, name: "CLONE_TARGET_MODE_REMOTE_COMMIT" },
    { no: 3, name: "CLONE_TARGET_MODE_REMOTE_BRANCH" },
    { no: 4, name: "CLONE_TARGET_MODE_LOCAL_BRANCH" },
]);
/**
 * AuthMethod is the means of authentication used during clone
 *
 * @generated from enum gitpod.v1.GitInitializer.AuthMethod
 */
export var GitInitializer_AuthMethod;
(function (GitInitializer_AuthMethod) {
    /**
     * NO_AUTH disables authentication during clone
     *
     * @generated from enum value: AUTH_METHOD_UNSPECIFIED = 0;
     */
    GitInitializer_AuthMethod[GitInitializer_AuthMethod["UNSPECIFIED"] = 0] = "UNSPECIFIED";
    /**
     * BASIC_AUTH uses HTTP basic auth during clone (fails if repo is not cloned through http)
     *
     * @generated from enum value: AUTH_METHOD_BASIC_AUTH = 1;
     */
    GitInitializer_AuthMethod[GitInitializer_AuthMethod["BASIC_AUTH"] = 1] = "BASIC_AUTH";
    /**
     * BASIC_AUTH_OTS uses HTTP basic auth during the clone with the secrets coming from the OTS URL.
     * Fails if either the OTS download or the clone fail.
     *
     * @generated from enum value: AUTH_METHOD_BASIC_AUTH_OTS = 2;
     */
    GitInitializer_AuthMethod[GitInitializer_AuthMethod["BASIC_AUTH_OTS"] = 2] = "BASIC_AUTH_OTS";
})(GitInitializer_AuthMethod || (GitInitializer_AuthMethod = {}));
// Retrieve enum metadata with: proto3.getEnumType(GitInitializer_AuthMethod)
proto3.util.setEnumType(GitInitializer_AuthMethod, "gitpod.v1.GitInitializer.AuthMethod", [
    { no: 0, name: "AUTH_METHOD_UNSPECIFIED" },
    { no: 1, name: "AUTH_METHOD_BASIC_AUTH" },
    { no: 2, name: "AUTH_METHOD_BASIC_AUTH_OTS" },
]);
/**
 * @generated from message gitpod.v1.GitInitializer.GitConfig
 */
export class GitInitializer_GitConfig extends Message {
    constructor(data) {
        super();
        /**
         * custom config values to be set on clone provided through `.gitpod.yml`
         *
         * @generated from field: map<string, string> custom_config = 1;
         */
        this.customConfig = {};
        /**
         * authentication method
         *
         * @generated from field: gitpod.v1.GitInitializer.AuthMethod authentication = 2;
         */
        this.authentication = GitInitializer_AuthMethod.UNSPECIFIED;
        /**
         * auth_user is the username used to authenticate the clone
         *
         * @generated from field: string auth_user = 3;
         */
        this.authUser = "";
        /**
         * auth_password is the password used to authenticate the clone (can also be an API token)
         *
         * @generated from field: string auth_password = 4;
         */
        this.authPassword = "";
        /**
         * auth_ots is a URL where one can download the authentication secret (<username>:<password>)
         * using a GET request.
         *
         * @generated from field: string auth_ots = 5;
         */
        this.authOts = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new GitInitializer_GitConfig().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new GitInitializer_GitConfig().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new GitInitializer_GitConfig().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(GitInitializer_GitConfig, a, b);
    }
}
GitInitializer_GitConfig.runtime = proto3;
GitInitializer_GitConfig.typeName = "gitpod.v1.GitInitializer.GitConfig";
GitInitializer_GitConfig.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "custom_config", kind: "map", K: 9 /* ScalarType.STRING */, V: { kind: "scalar", T: 9 /* ScalarType.STRING */ } },
    { no: 2, name: "authentication", kind: "enum", T: proto3.getEnumType(GitInitializer_AuthMethod) },
    { no: 3, name: "auth_user", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 4, name: "auth_password", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 5, name: "auth_ots", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.v1.SnapshotInitializer
 */
export class SnapshotInitializer extends Message {
    constructor(data) {
        super();
        /**
         * reference of the snapshot to restore
         *
         * @generated from field: string snapshot_id = 1;
         */
        this.snapshotId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new SnapshotInitializer().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new SnapshotInitializer().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new SnapshotInitializer().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(SnapshotInitializer, a, b);
    }
}
SnapshotInitializer.runtime = proto3;
SnapshotInitializer.typeName = "gitpod.v1.SnapshotInitializer";
SnapshotInitializer.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "snapshot_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.v1.PrebuildInitializer
 */
export class PrebuildInitializer extends Message {
    constructor(data) {
        super();
        /**
         * reference of the prebuild to restore
         *
         * @generated from field: string prebuild_id = 1;
         */
        this.prebuildId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new PrebuildInitializer().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new PrebuildInitializer().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new PrebuildInitializer().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(PrebuildInitializer, a, b);
    }
}
PrebuildInitializer.runtime = proto3;
PrebuildInitializer.typeName = "gitpod.v1.PrebuildInitializer";
PrebuildInitializer.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "prebuild_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * FileDownloadInitializer downloads files and uses them as workspace content.
 *
 * @generated from message gitpod.v1.FileDownloadInitializer
 */
export class FileDownloadInitializer extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: repeated gitpod.v1.FileDownloadInitializer.FileInfo files = 1;
         */
        this.files = [];
        /**
         * @generated from field: string target_location = 2;
         */
        this.targetLocation = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new FileDownloadInitializer().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new FileDownloadInitializer().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new FileDownloadInitializer().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(FileDownloadInitializer, a, b);
    }
}
FileDownloadInitializer.runtime = proto3;
FileDownloadInitializer.typeName = "gitpod.v1.FileDownloadInitializer";
FileDownloadInitializer.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "files", kind: "message", T: FileDownloadInitializer_FileInfo, repeated: true },
    { no: 2, name: "target_location", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.v1.FileDownloadInitializer.FileInfo
 */
export class FileDownloadInitializer_FileInfo extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string url = 1;
         */
        this.url = "";
        /**
         * file_path is relative to the target_location, e.g. if target_location is in `/workspace/myrepo`
         * a file_path of `foobar/file` would produce a file in `/workspace/myrepo/foobar/file`.
         * file_path must include the filename. The FileDownloadInitializer will create any parent directories
         * necessary to place the file.
         *
         * @generated from field: string file_path = 2;
         */
        this.filePath = "";
        /**
         * digest is a hash of the file content in the OCI digest format (see https://github.com/opencontainers/image-spec/blob/master/descriptor.md#digests).
         * This information is used to compute subsequent
         * content versions, and to validate the file content was downloaded correctly.
         *
         * @generated from field: string digest = 3;
         */
        this.digest = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new FileDownloadInitializer_FileInfo().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new FileDownloadInitializer_FileInfo().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new FileDownloadInitializer_FileInfo().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(FileDownloadInitializer_FileInfo, a, b);
    }
}
FileDownloadInitializer_FileInfo.runtime = proto3;
FileDownloadInitializer_FileInfo.typeName = "gitpod.v1.FileDownloadInitializer.FileInfo";
FileDownloadInitializer_FileInfo.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "url", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "file_path", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 3, name: "digest", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * GitStatus describes the current Git working copy status, akin to a combination of "git status" and "git branch"
 *
 * @generated from message gitpod.v1.GitStatus
 */
export class GitStatus extends Message {
    constructor(data) {
        super();
        /**
         * branch is branch we're currently on
         *
         * @generated from field: string branch = 1;
         */
        this.branch = "";
        /**
         * latest_commit is the most recent commit on the current branch
         *
         * @generated from field: string latest_commit = 2;
         */
        this.latestCommit = "";
        /**
         * uncommited_files is the number of uncommitted files, possibly truncated
         *
         * @generated from field: repeated string uncommited_files = 3;
         */
        this.uncommitedFiles = [];
        /**
         * the total number of uncommited files
         *
         * @generated from field: int64 total_uncommited_files = 6;
         */
        this.totalUncommitedFiles = protoInt64.zero;
        /**
         * untracked_files is the number of untracked files in the workspace, possibly truncated
         *
         * @generated from field: repeated string untracked_files = 4;
         */
        this.untrackedFiles = [];
        /**
         * the total number of untracked files
         *
         * @generated from field: int64 total_untracked_files = 7;
         */
        this.totalUntrackedFiles = protoInt64.zero;
        /**
         * unpushed_commits is the number of unpushed changes in the workspace, possibly truncated
         *
         * @generated from field: repeated string unpushed_commits = 5;
         */
        this.unpushedCommits = [];
        /**
         * the total number of unpushed changes
         *
         * @generated from field: int64 total_unpushed_commits = 8;
         */
        this.totalUnpushedCommits = protoInt64.zero;
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new GitStatus().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new GitStatus().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new GitStatus().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(GitStatus, a, b);
    }
}
GitStatus.runtime = proto3;
GitStatus.typeName = "gitpod.v1.GitStatus";
GitStatus.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "branch", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "latest_commit", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 3, name: "uncommited_files", kind: "scalar", T: 9 /* ScalarType.STRING */, repeated: true },
    { no: 6, name: "total_uncommited_files", kind: "scalar", T: 3 /* ScalarType.INT64 */ },
    { no: 4, name: "untracked_files", kind: "scalar", T: 9 /* ScalarType.STRING */, repeated: true },
    { no: 7, name: "total_untracked_files", kind: "scalar", T: 3 /* ScalarType.INT64 */ },
    { no: 5, name: "unpushed_commits", kind: "scalar", T: 9 /* ScalarType.STRING */, repeated: true },
    { no: 8, name: "total_unpushed_commits", kind: "scalar", T: 3 /* ScalarType.INT64 */ },
]);
/**
 * @generated from message gitpod.v1.UpdateWorkspaceRequest
 */
export class UpdateWorkspaceRequest extends Message {
    constructor(data) {
        super();
        /**
         * workspace_id specifies the workspace to update
         *
         * +required
         *
         * @generated from field: string workspace_id = 1;
         */
        this.workspaceId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new UpdateWorkspaceRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new UpdateWorkspaceRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new UpdateWorkspaceRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(UpdateWorkspaceRequest, a, b);
    }
}
UpdateWorkspaceRequest.runtime = proto3;
UpdateWorkspaceRequest.typeName = "gitpod.v1.UpdateWorkspaceRequest";
UpdateWorkspaceRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "metadata", kind: "message", T: UpdateWorkspaceRequest_UpdateWorkspaceMetadata, opt: true },
    { no: 3, name: "spec", kind: "message", T: UpdateWorkspaceRequest_UpdateWorkspaceSpec, opt: true },
    { no: 4, name: "git_status", kind: "message", T: WorkspaceGitStatus, opt: true },
]);
/**
 * @generated from message gitpod.v1.UpdateWorkspaceRequest.UpdateWorkspaceMetadata
 */
export class UpdateWorkspaceRequest_UpdateWorkspaceMetadata extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new UpdateWorkspaceRequest_UpdateWorkspaceMetadata().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new UpdateWorkspaceRequest_UpdateWorkspaceMetadata().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new UpdateWorkspaceRequest_UpdateWorkspaceMetadata().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(UpdateWorkspaceRequest_UpdateWorkspaceMetadata, a, b);
    }
}
UpdateWorkspaceRequest_UpdateWorkspaceMetadata.runtime = proto3;
UpdateWorkspaceRequest_UpdateWorkspaceMetadata.typeName = "gitpod.v1.UpdateWorkspaceRequest.UpdateWorkspaceMetadata";
UpdateWorkspaceRequest_UpdateWorkspaceMetadata.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "name", kind: "scalar", T: 9 /* ScalarType.STRING */, opt: true },
    { no: 2, name: "pinned", kind: "scalar", T: 8 /* ScalarType.BOOL */, opt: true },
]);
/**
 * @generated from message gitpod.v1.UpdateWorkspaceRequest.UpdateTimeout
 */
export class UpdateWorkspaceRequest_UpdateTimeout extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new UpdateWorkspaceRequest_UpdateTimeout().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new UpdateWorkspaceRequest_UpdateTimeout().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new UpdateWorkspaceRequest_UpdateTimeout().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(UpdateWorkspaceRequest_UpdateTimeout, a, b);
    }
}
UpdateWorkspaceRequest_UpdateTimeout.runtime = proto3;
UpdateWorkspaceRequest_UpdateTimeout.typeName = "gitpod.v1.UpdateWorkspaceRequest.UpdateTimeout";
UpdateWorkspaceRequest_UpdateTimeout.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "inactivity", kind: "message", T: Duration, opt: true },
    { no: 2, name: "disconnected", kind: "message", T: Duration, opt: true },
]);
/**
 * Note(cw): Ports cannot be updated here in favour of UpdateWorkspacePorts call which exists so that
 * we can update individual ports.
 *
 * @generated from message gitpod.v1.UpdateWorkspaceRequest.UpdateWorkspaceSpec
 */
export class UpdateWorkspaceRequest_UpdateWorkspaceSpec extends Message {
    constructor(data) {
        super();
        /**
         * Note(cw): repeated fields have implicit presence. There's a difference between passing an empty list or nothing.
         *
         * @generated from field: repeated string ssh_public_keys = 3;
         */
        this.sshPublicKeys = [];
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new UpdateWorkspaceRequest_UpdateWorkspaceSpec().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new UpdateWorkspaceRequest_UpdateWorkspaceSpec().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new UpdateWorkspaceRequest_UpdateWorkspaceSpec().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(UpdateWorkspaceRequest_UpdateWorkspaceSpec, a, b);
    }
}
UpdateWorkspaceRequest_UpdateWorkspaceSpec.runtime = proto3;
UpdateWorkspaceRequest_UpdateWorkspaceSpec.typeName = "gitpod.v1.UpdateWorkspaceRequest.UpdateWorkspaceSpec";
UpdateWorkspaceRequest_UpdateWorkspaceSpec.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "timeout", kind: "message", T: UpdateWorkspaceRequest_UpdateTimeout, opt: true },
    { no: 2, name: "admission", kind: "enum", T: proto3.getEnumType(AdmissionLevel), opt: true },
    { no: 3, name: "ssh_public_keys", kind: "scalar", T: 9 /* ScalarType.STRING */, repeated: true },
]);
/**
 * @generated from message gitpod.v1.UpdateWorkspaceResponse
 */
export class UpdateWorkspaceResponse extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new UpdateWorkspaceResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new UpdateWorkspaceResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new UpdateWorkspaceResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(UpdateWorkspaceResponse, a, b);
    }
}
UpdateWorkspaceResponse.runtime = proto3;
UpdateWorkspaceResponse.typeName = "gitpod.v1.UpdateWorkspaceResponse";
UpdateWorkspaceResponse.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace", kind: "message", T: Workspace },
]);
/**
 * @generated from message gitpod.v1.StopWorkspaceRequest
 */
export class StopWorkspaceRequest extends Message {
    constructor(data) {
        super();
        /**
         * workspace_id specifies which workspace should be stopped.
         *
         * +required
         *
         * @generated from field: string workspace_id = 1;
         */
        this.workspaceId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new StopWorkspaceRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new StopWorkspaceRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new StopWorkspaceRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(StopWorkspaceRequest, a, b);
    }
}
StopWorkspaceRequest.runtime = proto3;
StopWorkspaceRequest.typeName = "gitpod.v1.StopWorkspaceRequest";
StopWorkspaceRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.v1.StopWorkspaceResponse
 */
export class StopWorkspaceResponse extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new StopWorkspaceResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new StopWorkspaceResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new StopWorkspaceResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(StopWorkspaceResponse, a, b);
    }
}
StopWorkspaceResponse.runtime = proto3;
StopWorkspaceResponse.typeName = "gitpod.v1.StopWorkspaceResponse";
StopWorkspaceResponse.fields = proto3.util.newFieldList(() => []);
/**
 * @generated from message gitpod.v1.DeleteWorkspaceRequest
 */
export class DeleteWorkspaceRequest extends Message {
    constructor(data) {
        super();
        /**
         * workspace_id specifies the workspace that is going to delete.
         *
         * +required
         *
         * @generated from field: string workspace_id = 1;
         */
        this.workspaceId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new DeleteWorkspaceRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new DeleteWorkspaceRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new DeleteWorkspaceRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(DeleteWorkspaceRequest, a, b);
    }
}
DeleteWorkspaceRequest.runtime = proto3;
DeleteWorkspaceRequest.typeName = "gitpod.v1.DeleteWorkspaceRequest";
DeleteWorkspaceRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.v1.DeleteWorkspaceResponse
 */
export class DeleteWorkspaceResponse extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new DeleteWorkspaceResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new DeleteWorkspaceResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new DeleteWorkspaceResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(DeleteWorkspaceResponse, a, b);
    }
}
DeleteWorkspaceResponse.runtime = proto3;
DeleteWorkspaceResponse.typeName = "gitpod.v1.DeleteWorkspaceResponse";
DeleteWorkspaceResponse.fields = proto3.util.newFieldList(() => []);
/**
 * @generated from message gitpod.v1.ListWorkspaceClassesRequest
 */
export class ListWorkspaceClassesRequest extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new ListWorkspaceClassesRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new ListWorkspaceClassesRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new ListWorkspaceClassesRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(ListWorkspaceClassesRequest, a, b);
    }
}
ListWorkspaceClassesRequest.runtime = proto3;
ListWorkspaceClassesRequest.typeName = "gitpod.v1.ListWorkspaceClassesRequest";
ListWorkspaceClassesRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "pagination", kind: "message", T: PaginationRequest },
]);
/**
 * @generated from message gitpod.v1.ListWorkspaceClassesResponse
 */
export class ListWorkspaceClassesResponse extends Message {
    constructor(data) {
        super();
        /**
         * @generated from field: repeated gitpod.v1.WorkspaceClass workspace_classes = 2;
         */
        this.workspaceClasses = [];
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new ListWorkspaceClassesResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new ListWorkspaceClassesResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new ListWorkspaceClassesResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(ListWorkspaceClassesResponse, a, b);
    }
}
ListWorkspaceClassesResponse.runtime = proto3;
ListWorkspaceClassesResponse.typeName = "gitpod.v1.ListWorkspaceClassesResponse";
ListWorkspaceClassesResponse.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "pagination", kind: "message", T: PaginationResponse },
    { no: 2, name: "workspace_classes", kind: "message", T: WorkspaceClass, repeated: true },
]);
/**
 * @generated from message gitpod.v1.ParseContextURLRequest
 */
export class ParseContextURLRequest extends Message {
    constructor(data) {
        super();
        /**
         * context_url is the URL to parse
         *
         * @generated from field: string context_url = 1;
         */
        this.contextUrl = "";
        /**
         * configuration_id is the ID of the configuration to use
         *
         * @generated from field: string configuration_id = 2;
         */
        this.configurationId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new ParseContextURLRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new ParseContextURLRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new ParseContextURLRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(ParseContextURLRequest, a, b);
    }
}
ParseContextURLRequest.runtime = proto3;
ParseContextURLRequest.typeName = "gitpod.v1.ParseContextURLRequest";
ParseContextURLRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "context_url", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "configuration_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.v1.ParseContextURLResponse
 */
export class ParseContextURLResponse extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new ParseContextURLResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new ParseContextURLResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new ParseContextURLResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(ParseContextURLResponse, a, b);
    }
}
ParseContextURLResponse.runtime = proto3;
ParseContextURLResponse.typeName = "gitpod.v1.ParseContextURLResponse";
ParseContextURLResponse.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "metadata", kind: "message", T: WorkspaceMetadata },
    { no: 2, name: "spec", kind: "message", T: WorkspaceSpec },
]);
/**
 * @generated from message gitpod.v1.WorkspaceClass
 */
export class WorkspaceClass extends Message {
    constructor(data) {
        super();
        /**
         * id is the unique identifier of the workspace class
         *
         * @generated from field: string id = 1;
         */
        this.id = "";
        /**
         * display_name is the human readable name of the workspace class
         *
         * @generated from field: string display_name = 2;
         */
        this.displayName = "";
        /**
         * description is a human readable description of the workspace class
         *
         * @generated from field: string description = 3;
         */
        this.description = "";
        /**
         * is_default indicates if this workspace class is the default one
         *
         * @generated from field: bool is_default = 4;
         */
        this.isDefault = false;
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceClass().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceClass().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceClass().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceClass, a, b);
    }
}
WorkspaceClass.runtime = proto3;
WorkspaceClass.typeName = "gitpod.v1.WorkspaceClass";
WorkspaceClass.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "display_name", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 3, name: "description", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 4, name: "is_default", kind: "scalar", T: 8 /* ScalarType.BOOL */ },
]);
/**
 * @generated from message gitpod.v1.CreateWorkspaceSnapshotRequest
 */
export class CreateWorkspaceSnapshotRequest extends Message {
    constructor(data) {
        super();
        /**
         * workspace_id specifies the workspace to create snapshot
         *
         * +required
         *
         * @generated from field: string workspace_id = 1;
         */
        this.workspaceId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new CreateWorkspaceSnapshotRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new CreateWorkspaceSnapshotRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new CreateWorkspaceSnapshotRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(CreateWorkspaceSnapshotRequest, a, b);
    }
}
CreateWorkspaceSnapshotRequest.runtime = proto3;
CreateWorkspaceSnapshotRequest.typeName = "gitpod.v1.CreateWorkspaceSnapshotRequest";
CreateWorkspaceSnapshotRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.v1.CreateWorkspaceSnapshotResponse
 */
export class CreateWorkspaceSnapshotResponse extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new CreateWorkspaceSnapshotResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new CreateWorkspaceSnapshotResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new CreateWorkspaceSnapshotResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(CreateWorkspaceSnapshotResponse, a, b);
    }
}
CreateWorkspaceSnapshotResponse.runtime = proto3;
CreateWorkspaceSnapshotResponse.typeName = "gitpod.v1.CreateWorkspaceSnapshotResponse";
CreateWorkspaceSnapshotResponse.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "snapshot", kind: "message", T: WorkspaceSnapshot },
]);
/**
 * @generated from message gitpod.v1.WaitForWorkspaceSnapshotRequest
 */
export class WaitForWorkspaceSnapshotRequest extends Message {
    constructor(data) {
        super();
        /**
         * snapshot_id specifies the snapshot to wait for
         *
         * +required
         *
         * @generated from field: string snapshot_id = 1;
         */
        this.snapshotId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WaitForWorkspaceSnapshotRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WaitForWorkspaceSnapshotRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WaitForWorkspaceSnapshotRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WaitForWorkspaceSnapshotRequest, a, b);
    }
}
WaitForWorkspaceSnapshotRequest.runtime = proto3;
WaitForWorkspaceSnapshotRequest.typeName = "gitpod.v1.WaitForWorkspaceSnapshotRequest";
WaitForWorkspaceSnapshotRequest.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "snapshot_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.v1.WaitForWorkspaceSnapshotResponse
 */
export class WaitForWorkspaceSnapshotResponse extends Message {
    constructor(data) {
        super();
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WaitForWorkspaceSnapshotResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WaitForWorkspaceSnapshotResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WaitForWorkspaceSnapshotResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WaitForWorkspaceSnapshotResponse, a, b);
    }
}
WaitForWorkspaceSnapshotResponse.runtime = proto3;
WaitForWorkspaceSnapshotResponse.typeName = "gitpod.v1.WaitForWorkspaceSnapshotResponse";
WaitForWorkspaceSnapshotResponse.fields = proto3.util.newFieldList(() => []);
/**
 * @generated from message gitpod.v1.WorkspaceSnapshot
 */
export class WorkspaceSnapshot extends Message {
    constructor(data) {
        super();
        /**
         * id is the unique identifier of the snapshot
         *
         * @generated from field: string id = 1;
         */
        this.id = "";
        /**
         * workspace_id is the source workspace id of snapshot
         *
         * @generated from field: string workspace_id = 2;
         */
        this.workspaceId = "";
        proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new WorkspaceSnapshot().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new WorkspaceSnapshot().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new WorkspaceSnapshot().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return proto3.util.equals(WorkspaceSnapshot, a, b);
    }
}
WorkspaceSnapshot.runtime = proto3;
WorkspaceSnapshot.typeName = "gitpod.v1.WorkspaceSnapshot";
WorkspaceSnapshot.fields = proto3.util.newFieldList(() => [
    { no: 1, name: "id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "workspace_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 3, name: "creation_time", kind: "message", T: Timestamp },
]);
//# sourceMappingURL=workspace_pb.js.map