/**
 * Copyright (c) 2024 Gitpod GmbH. All rights reserved.
 * Licensed under the GNU Affero General Public License (AGPL).
 * See License.AGPL.txt in the project root for license information.
 */
import type { BinaryReadOptions, FieldList, JsonReadOptions, JsonValue, PartialMessage, PlainMessage } from "@bufbuild/protobuf";
import { Message, proto3, Timestamp } from "@bufbuild/protobuf";
import { Pagination } from "./pagination_pb.js";
/**
 * Configuration of an OpenID client.
 *
 * For the metadata describing the configuration of OIDC providers, cf.
 * https://openid.net/specs/openid-connect-discovery-1_0.html
 *
 * @generated from message gitpod.experimental.v1.OIDCClientConfig
 */
export declare class OIDCClientConfig extends Message<OIDCClientConfig> {
    /**
     * ID is the unique identifier for the OIDC Config.
     * Read only.
     *
     * @generated from field: string id = 1;
     */
    id: string;
    /**
     * @generated from field: string organization_id = 2;
     */
    organizationId: string;
    /**
     * @generated from field: gitpod.experimental.v1.OIDCConfig oidc_config = 3;
     */
    oidcConfig?: OIDCConfig;
    /**
     * @generated from field: gitpod.experimental.v1.OAuth2Config oauth2_config = 4;
     */
    oauth2Config?: OAuth2Config;
    /**
     * Optional.
     *
     * @generated from field: bool oauth_only = 5;
     */
    oauthOnly: boolean;
    /**
     * List of the JWS signing algorithms (alg values) supported by the OP for the
     * ID Token to encode the Claims in a JWT. The algorithm RS256 MUST be
     * included.
     * Optional.
     *
     * @generated from field: repeated string id_token_signing_alg_values_supported = 6;
     */
    idTokenSigningAlgValuesSupported: string[];
    /**
     * Time when the config was created.
     * Read-only.
     *
     * @generated from field: google.protobuf.Timestamp creation_time = 7;
     */
    creationTime?: Timestamp;
    /**
     * Describes the status of this configuration item.
     * Read-only.
     *
     * @generated from field: gitpod.experimental.v1.OIDCClientConfigStatus status = 8;
     */
    status?: OIDCClientConfigStatus;
    /**
     * Whether this config can be used for sign-ins.
     * Defaults to false.
     * Optional.
     *
     * @generated from field: bool active = 9;
     */
    active: boolean;
    /**
     * Whether this config was tested by executing the OIDC flow.
     * Defaults to false.
     * Optional.
     *
     * @generated from field: bool verified = 10;
     */
    verified: boolean;
    constructor(data?: PartialMessage<OIDCClientConfig>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.OIDCClientConfig";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): OIDCClientConfig;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): OIDCClientConfig;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): OIDCClientConfig;
    static equals(a: OIDCClientConfig | PlainMessage<OIDCClientConfig> | undefined, b: OIDCClientConfig | PlainMessage<OIDCClientConfig> | undefined): boolean;
}
/**
 * The OIDC specific part of the client configuration.
 *
 * @generated from message gitpod.experimental.v1.OIDCConfig
 */
export declare class OIDCConfig extends Message<OIDCConfig> {
    /**
     * URL using the https scheme with no query or fragment component that the
     * OIDC provider asserts as its Issuer Identifier.
     * Required.
     *
     * @generated from field: string issuer = 1;
     */
    issuer: string;
    /**
     * A KeySet that can validate the id_token (JSON web token)
     * Either one is required.
     *
     * @generated from field: string jwks = 2;
     */
    jwks: string;
    /**
     * @generated from field: string jwks_url = 3;
     */
    jwksUrl: string;
    /**
     * Provider specific parameters to control the behavior of the consent screen.
     * Optional.
     *
     * @generated from field: gitpod.experimental.v1.ConsentScreenHints hints = 4;
     */
    hints?: ConsentScreenHints;
    /**
     * Optional overrides for key mapping to be applied when extracting claims from id_tokens.
     * Should only be set, if an override is required.
     * Optional.
     *
     * @generated from field: gitpod.experimental.v1.ClaimMappingOverride override_claim_mapping = 5;
     */
    overrideClaimMapping?: ClaimMappingOverride;
    constructor(data?: PartialMessage<OIDCConfig>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.OIDCConfig";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): OIDCConfig;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): OIDCConfig;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): OIDCConfig;
    static equals(a: OIDCConfig | PlainMessage<OIDCConfig> | undefined, b: OIDCConfig | PlainMessage<OIDCConfig> | undefined): boolean;
}
/**
 * Provider specific parameters to control the behavior of the consent screen.
 *
 * @generated from message gitpod.experimental.v1.ConsentScreenHints
 */
export declare class ConsentScreenHints extends Message<ConsentScreenHints> {
    /**
     * Control options for the consent screen.
     * Optional.
     *
     * @generated from field: string prompt = 1;
     */
    prompt: string;
    /**
     * A hint to pre-select the tenant from an AD.
     * Optional.
     *
     * @generated from field: string domain_hint = 2;
     */
    domainHint: string;
    /**
     * Optional.
     *
     * @generated from field: string login_hint = 3;
     */
    loginHint: string;
    constructor(data?: PartialMessage<ConsentScreenHints>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.ConsentScreenHints";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ConsentScreenHints;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ConsentScreenHints;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ConsentScreenHints;
    static equals(a: ConsentScreenHints | PlainMessage<ConsentScreenHints> | undefined, b: ConsentScreenHints | PlainMessage<ConsentScreenHints> | undefined): boolean;
}
/**
 * Optional overrides for key mapping to be applied when extracting claims from id_tokens.
 *
 * @generated from message gitpod.experimental.v1.ClaimMappingOverride
 */
export declare class ClaimMappingOverride extends Message<ClaimMappingOverride> {
    /**
     * Optional.
     *
     * @generated from field: string claim_email_key = 1;
     */
    claimEmailKey: string;
    /**
     * Optional.
     *
     * @generated from field: string claim_groups_key = 2;
     */
    claimGroupsKey: string;
    /**
     * Optional.
     *
     * @generated from field: string claim_username_key = 3;
     */
    claimUsernameKey: string;
    constructor(data?: PartialMessage<ClaimMappingOverride>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.ClaimMappingOverride";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ClaimMappingOverride;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ClaimMappingOverride;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ClaimMappingOverride;
    static equals(a: ClaimMappingOverride | PlainMessage<ClaimMappingOverride> | undefined, b: ClaimMappingOverride | PlainMessage<ClaimMappingOverride> | undefined): boolean;
}
/**
 * The OAuth2 specific part of the client configuration.
 *
 * @generated from message gitpod.experimental.v1.OAuth2Config
 */
export declare class OAuth2Config extends Message<OAuth2Config> {
    /**
     * Required.
     *
     * @generated from field: string client_id = 1;
     */
    clientId: string;
    /**
     * Required for creation/updates.
     * Empty on read.
     *
     * @generated from field: string client_secret = 2;
     */
    clientSecret: string;
    /**
     * Required.
     *
     * @generated from field: string authorization_endpoint = 3;
     */
    authorizationEndpoint: string;
    /**
     * Required.
     *
     * @generated from field: string token_endpoint = 4;
     */
    tokenEndpoint: string;
    /**
     * Required.
     *
     * @generated from field: repeated string scopes = 5;
     */
    scopes: string[];
    /**
     * Source for additional claims for the token.
     * Additional keys may be used to control the extraction of a profile.
     * Required.
     *
     * @generated from field: string userinfo_endpoint = 6;
     */
    userinfoEndpoint: string;
    /**
     * Keys of the userinfo result to extract a profile from.
     * Optional.
     *
     * @generated from field: gitpod.experimental.v1.UserInfoKeys userinfo_keys = 7;
     */
    userinfoKeys?: UserInfoKeys;
    constructor(data?: PartialMessage<OAuth2Config>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.OAuth2Config";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): OAuth2Config;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): OAuth2Config;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): OAuth2Config;
    static equals(a: OAuth2Config | PlainMessage<OAuth2Config> | undefined, b: OAuth2Config | PlainMessage<OAuth2Config> | undefined): boolean;
}
/**
 * Description of keys of a userinfo result.
 *
 * @generated from message gitpod.experimental.v1.UserInfoKeys
 */
export declare class UserInfoKeys extends Message<UserInfoKeys> {
    /**
     * Optional.
     *
     * @generated from field: string userinfo_id_key = 1;
     */
    userinfoIdKey: string;
    /**
     * Optional.
     *
     * @generated from field: string userinfo_name_key = 2;
     */
    userinfoNameKey: string;
    constructor(data?: PartialMessage<UserInfoKeys>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.UserInfoKeys";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UserInfoKeys;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UserInfoKeys;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UserInfoKeys;
    static equals(a: UserInfoKeys | PlainMessage<UserInfoKeys> | undefined, b: UserInfoKeys | PlainMessage<UserInfoKeys> | undefined): boolean;
}
/**
 * The status of an OIDC client configuration.
 *
 * @generated from message gitpod.experimental.v1.OIDCClientConfigStatus
 */
export declare class OIDCClientConfigStatus extends Message<OIDCClientConfigStatus> {
    constructor(data?: PartialMessage<OIDCClientConfigStatus>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.OIDCClientConfigStatus";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): OIDCClientConfigStatus;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): OIDCClientConfigStatus;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): OIDCClientConfigStatus;
    static equals(a: OIDCClientConfigStatus | PlainMessage<OIDCClientConfigStatus> | undefined, b: OIDCClientConfigStatus | PlainMessage<OIDCClientConfigStatus> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.CreateClientConfigRequest
 */
export declare class CreateClientConfigRequest extends Message<CreateClientConfigRequest> {
    /**
     * @generated from field: gitpod.experimental.v1.OIDCClientConfig config = 1;
     */
    config?: OIDCClientConfig;
    /**
     * Optional.
     *
     * @generated from field: bool use_discovery = 2;
     */
    useDiscovery: boolean;
    constructor(data?: PartialMessage<CreateClientConfigRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.CreateClientConfigRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): CreateClientConfigRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): CreateClientConfigRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): CreateClientConfigRequest;
    static equals(a: CreateClientConfigRequest | PlainMessage<CreateClientConfigRequest> | undefined, b: CreateClientConfigRequest | PlainMessage<CreateClientConfigRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.CreateClientConfigResponse
 */
export declare class CreateClientConfigResponse extends Message<CreateClientConfigResponse> {
    /**
     * @generated from field: gitpod.experimental.v1.OIDCClientConfig config = 1;
     */
    config?: OIDCClientConfig;
    constructor(data?: PartialMessage<CreateClientConfigResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.CreateClientConfigResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): CreateClientConfigResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): CreateClientConfigResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): CreateClientConfigResponse;
    static equals(a: CreateClientConfigResponse | PlainMessage<CreateClientConfigResponse> | undefined, b: CreateClientConfigResponse | PlainMessage<CreateClientConfigResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.GetClientConfigRequest
 */
export declare class GetClientConfigRequest extends Message<GetClientConfigRequest> {
    /**
     * @generated from field: string id = 1;
     */
    id: string;
    /**
     * @generated from field: string organization_id = 2;
     */
    organizationId: string;
    constructor(data?: PartialMessage<GetClientConfigRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.GetClientConfigRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetClientConfigRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetClientConfigRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetClientConfigRequest;
    static equals(a: GetClientConfigRequest | PlainMessage<GetClientConfigRequest> | undefined, b: GetClientConfigRequest | PlainMessage<GetClientConfigRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.GetClientConfigResponse
 */
export declare class GetClientConfigResponse extends Message<GetClientConfigResponse> {
    /**
     * @generated from field: gitpod.experimental.v1.OIDCClientConfig config = 1;
     */
    config?: OIDCClientConfig;
    constructor(data?: PartialMessage<GetClientConfigResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.GetClientConfigResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetClientConfigResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetClientConfigResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetClientConfigResponse;
    static equals(a: GetClientConfigResponse | PlainMessage<GetClientConfigResponse> | undefined, b: GetClientConfigResponse | PlainMessage<GetClientConfigResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.ListClientConfigsRequest
 */
export declare class ListClientConfigsRequest extends Message<ListClientConfigsRequest> {
    /**
     * @generated from field: string organization_id = 1;
     */
    organizationId: string;
    /**
     * Page information
     *
     * @generated from field: gitpod.experimental.v1.Pagination pagination = 2;
     */
    pagination?: Pagination;
    constructor(data?: PartialMessage<ListClientConfigsRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.ListClientConfigsRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListClientConfigsRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListClientConfigsRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListClientConfigsRequest;
    static equals(a: ListClientConfigsRequest | PlainMessage<ListClientConfigsRequest> | undefined, b: ListClientConfigsRequest | PlainMessage<ListClientConfigsRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.ListClientConfigsResponse
 */
export declare class ListClientConfigsResponse extends Message<ListClientConfigsResponse> {
    /**
     * @generated from field: repeated gitpod.experimental.v1.OIDCClientConfig client_configs = 1;
     */
    clientConfigs: OIDCClientConfig[];
    /**
     * @generated from field: int64 total_results = 2;
     */
    totalResults: bigint;
    constructor(data?: PartialMessage<ListClientConfigsResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.ListClientConfigsResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListClientConfigsResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListClientConfigsResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListClientConfigsResponse;
    static equals(a: ListClientConfigsResponse | PlainMessage<ListClientConfigsResponse> | undefined, b: ListClientConfigsResponse | PlainMessage<ListClientConfigsResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.UpdateClientConfigRequest
 */
export declare class UpdateClientConfigRequest extends Message<UpdateClientConfigRequest> {
    /**
     * @generated from field: gitpod.experimental.v1.OIDCClientConfig config = 1;
     */
    config?: OIDCClientConfig;
    constructor(data?: PartialMessage<UpdateClientConfigRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.UpdateClientConfigRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdateClientConfigRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdateClientConfigRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdateClientConfigRequest;
    static equals(a: UpdateClientConfigRequest | PlainMessage<UpdateClientConfigRequest> | undefined, b: UpdateClientConfigRequest | PlainMessage<UpdateClientConfigRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.UpdateClientConfigResponse
 */
export declare class UpdateClientConfigResponse extends Message<UpdateClientConfigResponse> {
    constructor(data?: PartialMessage<UpdateClientConfigResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.UpdateClientConfigResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdateClientConfigResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdateClientConfigResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdateClientConfigResponse;
    static equals(a: UpdateClientConfigResponse | PlainMessage<UpdateClientConfigResponse> | undefined, b: UpdateClientConfigResponse | PlainMessage<UpdateClientConfigResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.DeleteClientConfigRequest
 */
export declare class DeleteClientConfigRequest extends Message<DeleteClientConfigRequest> {
    /**
     * @generated from field: string id = 1;
     */
    id: string;
    /**
     * @generated from field: string organization_id = 2;
     */
    organizationId: string;
    constructor(data?: PartialMessage<DeleteClientConfigRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.DeleteClientConfigRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): DeleteClientConfigRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): DeleteClientConfigRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): DeleteClientConfigRequest;
    static equals(a: DeleteClientConfigRequest | PlainMessage<DeleteClientConfigRequest> | undefined, b: DeleteClientConfigRequest | PlainMessage<DeleteClientConfigRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.DeleteClientConfigResponse
 */
export declare class DeleteClientConfigResponse extends Message<DeleteClientConfigResponse> {
    constructor(data?: PartialMessage<DeleteClientConfigResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.DeleteClientConfigResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): DeleteClientConfigResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): DeleteClientConfigResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): DeleteClientConfigResponse;
    static equals(a: DeleteClientConfigResponse | PlainMessage<DeleteClientConfigResponse> | undefined, b: DeleteClientConfigResponse | PlainMessage<DeleteClientConfigResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.SetClientConfigActivationRequest
 */
export declare class SetClientConfigActivationRequest extends Message<SetClientConfigActivationRequest> {
    /**
     * @generated from field: string id = 1;
     */
    id: string;
    /**
     * @generated from field: string organization_id = 2;
     */
    organizationId: string;
    /**
     * @generated from field: bool activate = 3;
     */
    activate: boolean;
    constructor(data?: PartialMessage<SetClientConfigActivationRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.SetClientConfigActivationRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): SetClientConfigActivationRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): SetClientConfigActivationRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): SetClientConfigActivationRequest;
    static equals(a: SetClientConfigActivationRequest | PlainMessage<SetClientConfigActivationRequest> | undefined, b: SetClientConfigActivationRequest | PlainMessage<SetClientConfigActivationRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.SetClientConfigActivationResponse
 */
export declare class SetClientConfigActivationResponse extends Message<SetClientConfigActivationResponse> {
    constructor(data?: PartialMessage<SetClientConfigActivationResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.SetClientConfigActivationResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): SetClientConfigActivationResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): SetClientConfigActivationResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): SetClientConfigActivationResponse;
    static equals(a: SetClientConfigActivationResponse | PlainMessage<SetClientConfigActivationResponse> | undefined, b: SetClientConfigActivationResponse | PlainMessage<SetClientConfigActivationResponse> | undefined): boolean;
}
//# sourceMappingURL=oidc_pb.d.ts.map