"use strict";
/**
 * Copyright (c) 2024 Gitpod GmbH. All rights reserved.
 * Licensed under the GNU Affero General Public License (AGPL).
 * See License.AGPL.txt in the project root for license information.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.SetClientConfigActivationResponse = exports.SetClientConfigActivationRequest = exports.DeleteClientConfigResponse = exports.DeleteClientConfigRequest = exports.UpdateClientConfigResponse = exports.UpdateClientConfigRequest = exports.ListClientConfigsResponse = exports.ListClientConfigsRequest = exports.GetClientConfigResponse = exports.GetClientConfigRequest = exports.CreateClientConfigResponse = exports.CreateClientConfigRequest = exports.OIDCClientConfigStatus = exports.UserInfoKeys = exports.OAuth2Config = exports.ClaimMappingOverride = exports.ConsentScreenHints = exports.OIDCConfig = exports.OIDCClientConfig = void 0;
const protobuf_1 = require("@bufbuild/protobuf");
const pagination_pb_js_1 = require("./pagination_pb.js");
/**
 * Configuration of an OpenID client.
 *
 * For the metadata describing the configuration of OIDC providers, cf.
 * https://openid.net/specs/openid-connect-discovery-1_0.html
 *
 * @generated from message gitpod.experimental.v1.OIDCClientConfig
 */
class OIDCClientConfig extends protobuf_1.Message {
    constructor(data) {
        super();
        /**
         * ID is the unique identifier for the OIDC Config.
         * Read only.
         *
         * @generated from field: string id = 1;
         */
        this.id = "";
        /**
         * @generated from field: string organization_id = 2;
         */
        this.organizationId = "";
        /**
         * Optional.
         *
         * @generated from field: bool oauth_only = 5;
         */
        this.oauthOnly = false;
        /**
         * List of the JWS signing algorithms (alg values) supported by the OP for the
         * ID Token to encode the Claims in a JWT. The algorithm RS256 MUST be
         * included.
         * Optional.
         *
         * @generated from field: repeated string id_token_signing_alg_values_supported = 6;
         */
        this.idTokenSigningAlgValuesSupported = [];
        /**
         * Whether this config can be used for sign-ins.
         * Defaults to false.
         * Optional.
         *
         * @generated from field: bool active = 9;
         */
        this.active = false;
        /**
         * Whether this config was tested by executing the OIDC flow.
         * Defaults to false.
         * Optional.
         *
         * @generated from field: bool verified = 10;
         */
        this.verified = false;
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new OIDCClientConfig().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new OIDCClientConfig().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new OIDCClientConfig().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(OIDCClientConfig, a, b);
    }
}
exports.OIDCClientConfig = OIDCClientConfig;
OIDCClientConfig.runtime = protobuf_1.proto3;
OIDCClientConfig.typeName = "gitpod.experimental.v1.OIDCClientConfig";
OIDCClientConfig.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "organization_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 3, name: "oidc_config", kind: "message", T: OIDCConfig },
    { no: 4, name: "oauth2_config", kind: "message", T: OAuth2Config },
    { no: 5, name: "oauth_only", kind: "scalar", T: 8 /* ScalarType.BOOL */ },
    { no: 6, name: "id_token_signing_alg_values_supported", kind: "scalar", T: 9 /* ScalarType.STRING */, repeated: true },
    { no: 7, name: "creation_time", kind: "message", T: protobuf_1.Timestamp },
    { no: 8, name: "status", kind: "message", T: OIDCClientConfigStatus },
    { no: 9, name: "active", kind: "scalar", T: 8 /* ScalarType.BOOL */ },
    { no: 10, name: "verified", kind: "scalar", T: 8 /* ScalarType.BOOL */ },
]);
/**
 * The OIDC specific part of the client configuration.
 *
 * @generated from message gitpod.experimental.v1.OIDCConfig
 */
class OIDCConfig extends protobuf_1.Message {
    constructor(data) {
        super();
        /**
         * URL using the https scheme with no query or fragment component that the
         * OIDC provider asserts as its Issuer Identifier.
         * Required.
         *
         * @generated from field: string issuer = 1;
         */
        this.issuer = "";
        /**
         * A KeySet that can validate the id_token (JSON web token)
         * Either one is required.
         *
         * @generated from field: string jwks = 2;
         */
        this.jwks = "";
        /**
         * @generated from field: string jwks_url = 3;
         */
        this.jwksUrl = "";
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new OIDCConfig().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new OIDCConfig().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new OIDCConfig().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(OIDCConfig, a, b);
    }
}
exports.OIDCConfig = OIDCConfig;
OIDCConfig.runtime = protobuf_1.proto3;
OIDCConfig.typeName = "gitpod.experimental.v1.OIDCConfig";
OIDCConfig.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "issuer", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "jwks", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 3, name: "jwks_url", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 4, name: "hints", kind: "message", T: ConsentScreenHints },
    { no: 5, name: "override_claim_mapping", kind: "message", T: ClaimMappingOverride },
]);
/**
 * Provider specific parameters to control the behavior of the consent screen.
 *
 * @generated from message gitpod.experimental.v1.ConsentScreenHints
 */
class ConsentScreenHints extends protobuf_1.Message {
    constructor(data) {
        super();
        /**
         * Control options for the consent screen.
         * Optional.
         *
         * @generated from field: string prompt = 1;
         */
        this.prompt = "";
        /**
         * A hint to pre-select the tenant from an AD.
         * Optional.
         *
         * @generated from field: string domain_hint = 2;
         */
        this.domainHint = "";
        /**
         * Optional.
         *
         * @generated from field: string login_hint = 3;
         */
        this.loginHint = "";
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new ConsentScreenHints().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new ConsentScreenHints().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new ConsentScreenHints().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(ConsentScreenHints, a, b);
    }
}
exports.ConsentScreenHints = ConsentScreenHints;
ConsentScreenHints.runtime = protobuf_1.proto3;
ConsentScreenHints.typeName = "gitpod.experimental.v1.ConsentScreenHints";
ConsentScreenHints.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "prompt", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "domain_hint", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 3, name: "login_hint", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * Optional overrides for key mapping to be applied when extracting claims from id_tokens.
 *
 * @generated from message gitpod.experimental.v1.ClaimMappingOverride
 */
class ClaimMappingOverride extends protobuf_1.Message {
    constructor(data) {
        super();
        /**
         * Optional.
         *
         * @generated from field: string claim_email_key = 1;
         */
        this.claimEmailKey = "";
        /**
         * Optional.
         *
         * @generated from field: string claim_groups_key = 2;
         */
        this.claimGroupsKey = "";
        /**
         * Optional.
         *
         * @generated from field: string claim_username_key = 3;
         */
        this.claimUsernameKey = "";
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new ClaimMappingOverride().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new ClaimMappingOverride().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new ClaimMappingOverride().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(ClaimMappingOverride, a, b);
    }
}
exports.ClaimMappingOverride = ClaimMappingOverride;
ClaimMappingOverride.runtime = protobuf_1.proto3;
ClaimMappingOverride.typeName = "gitpod.experimental.v1.ClaimMappingOverride";
ClaimMappingOverride.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "claim_email_key", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "claim_groups_key", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 3, name: "claim_username_key", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * The OAuth2 specific part of the client configuration.
 *
 * @generated from message gitpod.experimental.v1.OAuth2Config
 */
class OAuth2Config extends protobuf_1.Message {
    constructor(data) {
        super();
        /**
         * Required.
         *
         * @generated from field: string client_id = 1;
         */
        this.clientId = "";
        /**
         * Required for creation/updates.
         * Empty on read.
         *
         * @generated from field: string client_secret = 2;
         */
        this.clientSecret = "";
        /**
         * Required.
         *
         * @generated from field: string authorization_endpoint = 3;
         */
        this.authorizationEndpoint = "";
        /**
         * Required.
         *
         * @generated from field: string token_endpoint = 4;
         */
        this.tokenEndpoint = "";
        /**
         * Required.
         *
         * @generated from field: repeated string scopes = 5;
         */
        this.scopes = [];
        /**
         * Source for additional claims for the token.
         * Additional keys may be used to control the extraction of a profile.
         * Required.
         *
         * @generated from field: string userinfo_endpoint = 6;
         */
        this.userinfoEndpoint = "";
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new OAuth2Config().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new OAuth2Config().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new OAuth2Config().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(OAuth2Config, a, b);
    }
}
exports.OAuth2Config = OAuth2Config;
OAuth2Config.runtime = protobuf_1.proto3;
OAuth2Config.typeName = "gitpod.experimental.v1.OAuth2Config";
OAuth2Config.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "client_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "client_secret", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 3, name: "authorization_endpoint", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 4, name: "token_endpoint", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 5, name: "scopes", kind: "scalar", T: 9 /* ScalarType.STRING */, repeated: true },
    { no: 6, name: "userinfo_endpoint", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 7, name: "userinfo_keys", kind: "message", T: UserInfoKeys },
]);
/**
 * Description of keys of a userinfo result.
 *
 * @generated from message gitpod.experimental.v1.UserInfoKeys
 */
class UserInfoKeys extends protobuf_1.Message {
    constructor(data) {
        super();
        /**
         * Optional.
         *
         * @generated from field: string userinfo_id_key = 1;
         */
        this.userinfoIdKey = "";
        /**
         * Optional.
         *
         * @generated from field: string userinfo_name_key = 2;
         */
        this.userinfoNameKey = "";
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new UserInfoKeys().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new UserInfoKeys().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new UserInfoKeys().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(UserInfoKeys, a, b);
    }
}
exports.UserInfoKeys = UserInfoKeys;
UserInfoKeys.runtime = protobuf_1.proto3;
UserInfoKeys.typeName = "gitpod.experimental.v1.UserInfoKeys";
UserInfoKeys.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "userinfo_id_key", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "userinfo_name_key", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * The status of an OIDC client configuration.
 *
 * @generated from message gitpod.experimental.v1.OIDCClientConfigStatus
 */
class OIDCClientConfigStatus extends protobuf_1.Message {
    constructor(data) {
        super();
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new OIDCClientConfigStatus().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new OIDCClientConfigStatus().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new OIDCClientConfigStatus().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(OIDCClientConfigStatus, a, b);
    }
}
exports.OIDCClientConfigStatus = OIDCClientConfigStatus;
OIDCClientConfigStatus.runtime = protobuf_1.proto3;
OIDCClientConfigStatus.typeName = "gitpod.experimental.v1.OIDCClientConfigStatus";
OIDCClientConfigStatus.fields = protobuf_1.proto3.util.newFieldList(() => []);
/**
 * @generated from message gitpod.experimental.v1.CreateClientConfigRequest
 */
class CreateClientConfigRequest extends protobuf_1.Message {
    constructor(data) {
        super();
        /**
         * Optional.
         *
         * @generated from field: bool use_discovery = 2;
         */
        this.useDiscovery = false;
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new CreateClientConfigRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new CreateClientConfigRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new CreateClientConfigRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(CreateClientConfigRequest, a, b);
    }
}
exports.CreateClientConfigRequest = CreateClientConfigRequest;
CreateClientConfigRequest.runtime = protobuf_1.proto3;
CreateClientConfigRequest.typeName = "gitpod.experimental.v1.CreateClientConfigRequest";
CreateClientConfigRequest.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "config", kind: "message", T: OIDCClientConfig },
    { no: 2, name: "use_discovery", kind: "scalar", T: 8 /* ScalarType.BOOL */ },
]);
/**
 * @generated from message gitpod.experimental.v1.CreateClientConfigResponse
 */
class CreateClientConfigResponse extends protobuf_1.Message {
    constructor(data) {
        super();
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new CreateClientConfigResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new CreateClientConfigResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new CreateClientConfigResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(CreateClientConfigResponse, a, b);
    }
}
exports.CreateClientConfigResponse = CreateClientConfigResponse;
CreateClientConfigResponse.runtime = protobuf_1.proto3;
CreateClientConfigResponse.typeName = "gitpod.experimental.v1.CreateClientConfigResponse";
CreateClientConfigResponse.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "config", kind: "message", T: OIDCClientConfig },
]);
/**
 * @generated from message gitpod.experimental.v1.GetClientConfigRequest
 */
class GetClientConfigRequest extends protobuf_1.Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string id = 1;
         */
        this.id = "";
        /**
         * @generated from field: string organization_id = 2;
         */
        this.organizationId = "";
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new GetClientConfigRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new GetClientConfigRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new GetClientConfigRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(GetClientConfigRequest, a, b);
    }
}
exports.GetClientConfigRequest = GetClientConfigRequest;
GetClientConfigRequest.runtime = protobuf_1.proto3;
GetClientConfigRequest.typeName = "gitpod.experimental.v1.GetClientConfigRequest";
GetClientConfigRequest.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "organization_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.experimental.v1.GetClientConfigResponse
 */
class GetClientConfigResponse extends protobuf_1.Message {
    constructor(data) {
        super();
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new GetClientConfigResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new GetClientConfigResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new GetClientConfigResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(GetClientConfigResponse, a, b);
    }
}
exports.GetClientConfigResponse = GetClientConfigResponse;
GetClientConfigResponse.runtime = protobuf_1.proto3;
GetClientConfigResponse.typeName = "gitpod.experimental.v1.GetClientConfigResponse";
GetClientConfigResponse.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "config", kind: "message", T: OIDCClientConfig },
]);
/**
 * @generated from message gitpod.experimental.v1.ListClientConfigsRequest
 */
class ListClientConfigsRequest extends protobuf_1.Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string organization_id = 1;
         */
        this.organizationId = "";
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new ListClientConfigsRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new ListClientConfigsRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new ListClientConfigsRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(ListClientConfigsRequest, a, b);
    }
}
exports.ListClientConfigsRequest = ListClientConfigsRequest;
ListClientConfigsRequest.runtime = protobuf_1.proto3;
ListClientConfigsRequest.typeName = "gitpod.experimental.v1.ListClientConfigsRequest";
ListClientConfigsRequest.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "organization_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "pagination", kind: "message", T: pagination_pb_js_1.Pagination },
]);
/**
 * @generated from message gitpod.experimental.v1.ListClientConfigsResponse
 */
class ListClientConfigsResponse extends protobuf_1.Message {
    constructor(data) {
        super();
        /**
         * @generated from field: repeated gitpod.experimental.v1.OIDCClientConfig client_configs = 1;
         */
        this.clientConfigs = [];
        /**
         * @generated from field: int64 total_results = 2;
         */
        this.totalResults = protobuf_1.protoInt64.zero;
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new ListClientConfigsResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new ListClientConfigsResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new ListClientConfigsResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(ListClientConfigsResponse, a, b);
    }
}
exports.ListClientConfigsResponse = ListClientConfigsResponse;
ListClientConfigsResponse.runtime = protobuf_1.proto3;
ListClientConfigsResponse.typeName = "gitpod.experimental.v1.ListClientConfigsResponse";
ListClientConfigsResponse.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "client_configs", kind: "message", T: OIDCClientConfig, repeated: true },
    { no: 2, name: "total_results", kind: "scalar", T: 3 /* ScalarType.INT64 */ },
]);
/**
 * @generated from message gitpod.experimental.v1.UpdateClientConfigRequest
 */
class UpdateClientConfigRequest extends protobuf_1.Message {
    constructor(data) {
        super();
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new UpdateClientConfigRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new UpdateClientConfigRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new UpdateClientConfigRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(UpdateClientConfigRequest, a, b);
    }
}
exports.UpdateClientConfigRequest = UpdateClientConfigRequest;
UpdateClientConfigRequest.runtime = protobuf_1.proto3;
UpdateClientConfigRequest.typeName = "gitpod.experimental.v1.UpdateClientConfigRequest";
UpdateClientConfigRequest.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "config", kind: "message", T: OIDCClientConfig },
]);
/**
 * @generated from message gitpod.experimental.v1.UpdateClientConfigResponse
 */
class UpdateClientConfigResponse extends protobuf_1.Message {
    constructor(data) {
        super();
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new UpdateClientConfigResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new UpdateClientConfigResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new UpdateClientConfigResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(UpdateClientConfigResponse, a, b);
    }
}
exports.UpdateClientConfigResponse = UpdateClientConfigResponse;
UpdateClientConfigResponse.runtime = protobuf_1.proto3;
UpdateClientConfigResponse.typeName = "gitpod.experimental.v1.UpdateClientConfigResponse";
UpdateClientConfigResponse.fields = protobuf_1.proto3.util.newFieldList(() => []);
/**
 * @generated from message gitpod.experimental.v1.DeleteClientConfigRequest
 */
class DeleteClientConfigRequest extends protobuf_1.Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string id = 1;
         */
        this.id = "";
        /**
         * @generated from field: string organization_id = 2;
         */
        this.organizationId = "";
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new DeleteClientConfigRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new DeleteClientConfigRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new DeleteClientConfigRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(DeleteClientConfigRequest, a, b);
    }
}
exports.DeleteClientConfigRequest = DeleteClientConfigRequest;
DeleteClientConfigRequest.runtime = protobuf_1.proto3;
DeleteClientConfigRequest.typeName = "gitpod.experimental.v1.DeleteClientConfigRequest";
DeleteClientConfigRequest.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "organization_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.experimental.v1.DeleteClientConfigResponse
 */
class DeleteClientConfigResponse extends protobuf_1.Message {
    constructor(data) {
        super();
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new DeleteClientConfigResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new DeleteClientConfigResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new DeleteClientConfigResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(DeleteClientConfigResponse, a, b);
    }
}
exports.DeleteClientConfigResponse = DeleteClientConfigResponse;
DeleteClientConfigResponse.runtime = protobuf_1.proto3;
DeleteClientConfigResponse.typeName = "gitpod.experimental.v1.DeleteClientConfigResponse";
DeleteClientConfigResponse.fields = protobuf_1.proto3.util.newFieldList(() => []);
/**
 * @generated from message gitpod.experimental.v1.SetClientConfigActivationRequest
 */
class SetClientConfigActivationRequest extends protobuf_1.Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string id = 1;
         */
        this.id = "";
        /**
         * @generated from field: string organization_id = 2;
         */
        this.organizationId = "";
        /**
         * @generated from field: bool activate = 3;
         */
        this.activate = false;
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new SetClientConfigActivationRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new SetClientConfigActivationRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new SetClientConfigActivationRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(SetClientConfigActivationRequest, a, b);
    }
}
exports.SetClientConfigActivationRequest = SetClientConfigActivationRequest;
SetClientConfigActivationRequest.runtime = protobuf_1.proto3;
SetClientConfigActivationRequest.typeName = "gitpod.experimental.v1.SetClientConfigActivationRequest";
SetClientConfigActivationRequest.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "organization_id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 3, name: "activate", kind: "scalar", T: 8 /* ScalarType.BOOL */ },
]);
/**
 * @generated from message gitpod.experimental.v1.SetClientConfigActivationResponse
 */
class SetClientConfigActivationResponse extends protobuf_1.Message {
    constructor(data) {
        super();
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new SetClientConfigActivationResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new SetClientConfigActivationResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new SetClientConfigActivationResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(SetClientConfigActivationResponse, a, b);
    }
}
exports.SetClientConfigActivationResponse = SetClientConfigActivationResponse;
SetClientConfigActivationResponse.runtime = protobuf_1.proto3;
SetClientConfigActivationResponse.typeName = "gitpod.experimental.v1.SetClientConfigActivationResponse";
SetClientConfigActivationResponse.fields = protobuf_1.proto3.util.newFieldList(() => []);
//# sourceMappingURL=oidc_pb.js.map