/**
 * Copyright (c) 2024 Gitpod GmbH. All rights reserved.
 * Licensed under the GNU Affero General Public License (AGPL).
 * See License.AGPL.txt in the project root for license information.
 */
import type { BinaryReadOptions, FieldList, JsonReadOptions, JsonValue, PartialMessage, PlainMessage } from "@bufbuild/protobuf";
import { Message, proto3, Timestamp } from "@bufbuild/protobuf";
import { Pagination } from "./pagination_pb.js";
/**
 * @generated from message gitpod.experimental.v1.Project
 */
export declare class Project extends Message<Project> {
    /**
     * ID is the unique identifier for the project.
     * Read only.
     *
     * @generated from field: string id = 1;
     */
    id: string;
    /**
     * Team ID is the Team this Project belongs to.
     * team_id will be empty if the Project belongs to a User, in which case user_id will be set.
     *
     * @generated from field: string team_id = 2;
     */
    teamId: string;
    /**
     * Name is the name of the Project.
     * Required.
     *
     * @generated from field: string name = 4;
     */
    name: string;
    /**
     * Clone URL is the clone URL on which this Project is based.
     * Required.
     *
     * @generated from field: string clone_url = 6;
     */
    cloneUrl: string;
    /**
     * Time when the Project was created.
     * Read-only.
     *
     * @generated from field: google.protobuf.Timestamp creation_time = 7;
     */
    creationTime?: Timestamp;
    /**
     * Settings are configuration options for a Project.
     *
     * @generated from field: gitpod.experimental.v1.ProjectSettings settings = 8;
     */
    settings?: ProjectSettings;
    constructor(data?: PartialMessage<Project>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.Project";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): Project;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): Project;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): Project;
    static equals(a: Project | PlainMessage<Project> | undefined, b: Project | PlainMessage<Project> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.ProjectSettings
 */
export declare class ProjectSettings extends Message<ProjectSettings> {
    /**
     * @generated from field: gitpod.experimental.v1.PrebuildSettings prebuild = 1;
     */
    prebuild?: PrebuildSettings;
    /**
     * @generated from field: gitpod.experimental.v1.WorkspaceSettings workspace = 2;
     */
    workspace?: WorkspaceSettings;
    constructor(data?: PartialMessage<ProjectSettings>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.ProjectSettings";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ProjectSettings;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ProjectSettings;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ProjectSettings;
    static equals(a: ProjectSettings | PlainMessage<ProjectSettings> | undefined, b: ProjectSettings | PlainMessage<ProjectSettings> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.PrebuildSettings
 */
export declare class PrebuildSettings extends Message<PrebuildSettings> {
    /**
     * @generated from field: optional bool enable_prebuilds = 5;
     */
    enablePrebuilds?: boolean;
    /**
     * @generated from field: optional string branch_matching_pattern = 7;
     */
    branchMatchingPattern?: string;
    /**
     * @generated from field: optional string branch_strategy = 8;
     */
    branchStrategy?: string;
    /**
     * @generated from field: optional int32 prebuild_interval = 9;
     */
    prebuildInterval?: number;
    /**
     * @generated from field: optional string workspace_class = 10;
     */
    workspaceClass?: string;
    constructor(data?: PartialMessage<PrebuildSettings>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.PrebuildSettings";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): PrebuildSettings;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): PrebuildSettings;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): PrebuildSettings;
    static equals(a: PrebuildSettings | PlainMessage<PrebuildSettings> | undefined, b: PrebuildSettings | PlainMessage<PrebuildSettings> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.WorkspaceSettings
 */
export declare class WorkspaceSettings extends Message<WorkspaceSettings> {
    /**
     * @generated from field: bool enable_persistent_volume_claim = 1;
     */
    enablePersistentVolumeClaim: boolean;
    /**
     * @generated from field: gitpod.experimental.v1.WorkspaceClassSettings workspace_class = 2;
     */
    workspaceClass?: WorkspaceClassSettings;
    constructor(data?: PartialMessage<WorkspaceSettings>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.WorkspaceSettings";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceSettings;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceSettings;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceSettings;
    static equals(a: WorkspaceSettings | PlainMessage<WorkspaceSettings> | undefined, b: WorkspaceSettings | PlainMessage<WorkspaceSettings> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.WorkspaceClassSettings
 */
export declare class WorkspaceClassSettings extends Message<WorkspaceClassSettings> {
    /**
     * @generated from field: string regular = 1;
     */
    regular: string;
    /**
     * @generated from field: string prebuild = 2;
     */
    prebuild: string;
    constructor(data?: PartialMessage<WorkspaceClassSettings>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.WorkspaceClassSettings";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceClassSettings;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceClassSettings;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceClassSettings;
    static equals(a: WorkspaceClassSettings | PlainMessage<WorkspaceClassSettings> | undefined, b: WorkspaceClassSettings | PlainMessage<WorkspaceClassSettings> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.CreateProjectRequest
 */
export declare class CreateProjectRequest extends Message<CreateProjectRequest> {
    /**
     * @generated from field: gitpod.experimental.v1.Project project = 1;
     */
    project?: Project;
    constructor(data?: PartialMessage<CreateProjectRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.CreateProjectRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): CreateProjectRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): CreateProjectRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): CreateProjectRequest;
    static equals(a: CreateProjectRequest | PlainMessage<CreateProjectRequest> | undefined, b: CreateProjectRequest | PlainMessage<CreateProjectRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.CreateProjectResponse
 */
export declare class CreateProjectResponse extends Message<CreateProjectResponse> {
    /**
     * @generated from field: gitpod.experimental.v1.Project project = 1;
     */
    project?: Project;
    constructor(data?: PartialMessage<CreateProjectResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.CreateProjectResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): CreateProjectResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): CreateProjectResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): CreateProjectResponse;
    static equals(a: CreateProjectResponse | PlainMessage<CreateProjectResponse> | undefined, b: CreateProjectResponse | PlainMessage<CreateProjectResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.GetProjectRequest
 */
export declare class GetProjectRequest extends Message<GetProjectRequest> {
    /**
     * @generated from field: string project_id = 1;
     */
    projectId: string;
    constructor(data?: PartialMessage<GetProjectRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.GetProjectRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetProjectRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetProjectRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetProjectRequest;
    static equals(a: GetProjectRequest | PlainMessage<GetProjectRequest> | undefined, b: GetProjectRequest | PlainMessage<GetProjectRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.GetProjectResponse
 */
export declare class GetProjectResponse extends Message<GetProjectResponse> {
    /**
     * @generated from field: gitpod.experimental.v1.Project project = 1;
     */
    project?: Project;
    constructor(data?: PartialMessage<GetProjectResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.GetProjectResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetProjectResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetProjectResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetProjectResponse;
    static equals(a: GetProjectResponse | PlainMessage<GetProjectResponse> | undefined, b: GetProjectResponse | PlainMessage<GetProjectResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.ListProjectsRequest
 */
export declare class ListProjectsRequest extends Message<ListProjectsRequest> {
    /**
     * Team ID filters Projects owned by team_id
     *
     * @generated from field: string team_id = 2;
     */
    teamId: string;
    /**
     * Page information
     *
     * @generated from field: gitpod.experimental.v1.Pagination pagination = 3;
     */
    pagination?: Pagination;
    constructor(data?: PartialMessage<ListProjectsRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.ListProjectsRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListProjectsRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListProjectsRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListProjectsRequest;
    static equals(a: ListProjectsRequest | PlainMessage<ListProjectsRequest> | undefined, b: ListProjectsRequest | PlainMessage<ListProjectsRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.ListProjectsResponse
 */
export declare class ListProjectsResponse extends Message<ListProjectsResponse> {
    /**
     * @generated from field: repeated gitpod.experimental.v1.Project projects = 1;
     */
    projects: Project[];
    /**
     * @generated from field: int32 total_results = 2;
     */
    totalResults: number;
    constructor(data?: PartialMessage<ListProjectsResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.ListProjectsResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListProjectsResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListProjectsResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListProjectsResponse;
    static equals(a: ListProjectsResponse | PlainMessage<ListProjectsResponse> | undefined, b: ListProjectsResponse | PlainMessage<ListProjectsResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.DeleteProjectRequest
 */
export declare class DeleteProjectRequest extends Message<DeleteProjectRequest> {
    /**
     * @generated from field: string project_id = 1;
     */
    projectId: string;
    constructor(data?: PartialMessage<DeleteProjectRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.DeleteProjectRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): DeleteProjectRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): DeleteProjectRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): DeleteProjectRequest;
    static equals(a: DeleteProjectRequest | PlainMessage<DeleteProjectRequest> | undefined, b: DeleteProjectRequest | PlainMessage<DeleteProjectRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.DeleteProjectResponse
 */
export declare class DeleteProjectResponse extends Message<DeleteProjectResponse> {
    constructor(data?: PartialMessage<DeleteProjectResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.DeleteProjectResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): DeleteProjectResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): DeleteProjectResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): DeleteProjectResponse;
    static equals(a: DeleteProjectResponse | PlainMessage<DeleteProjectResponse> | undefined, b: DeleteProjectResponse | PlainMessage<DeleteProjectResponse> | undefined): boolean;
}
//# sourceMappingURL=projects_pb.d.ts.map