/**
 * Copyright (c) 2024 Gitpod GmbH. All rights reserved.
 * Licensed under the GNU Affero General Public License (AGPL).
 * See License.AGPL.txt in the project root for license information.
 */
import type { BinaryReadOptions, FieldList, JsonReadOptions, JsonValue, PartialMessage, PlainMessage } from "@bufbuild/protobuf";
import { Message, proto3, Timestamp } from "@bufbuild/protobuf";
/**
 * @generated from enum gitpod.experimental.v1.TeamRole
 */
export declare enum TeamRole {
    /**
     * TEAM_ROLE_UNKNOWN is the unkwnon state.
     *
     * @generated from enum value: TEAM_ROLE_UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * TEAM_ROLE_OWNER is the owner of the team.
     * A team can have multiple owners, but there must always be at least one owner.
     *
     * @generated from enum value: TEAM_ROLE_OWNER = 1;
     */
    OWNER = 1,
    /**
     * TEAM_ROLE_MEMBER is a regular member of a team.
     *
     * @generated from enum value: TEAM_ROLE_MEMBER = 2;
     */
    MEMBER = 2
}
/**
 * @generated from message gitpod.experimental.v1.Team
 */
export declare class Team extends Message<Team> {
    /**
     * id is a UUID of the Team
     *
     * @generated from field: string id = 1;
     */
    id: string;
    /**
     * name is the name of the Team
     *
     * @generated from field: string name = 2;
     */
    name: string;
    /**
     * slug is the slug of the Team
     *
     * @generated from field: string slug = 3;
     */
    slug: string;
    /**
     * members are the team members of this Team
     *
     * @generated from field: repeated gitpod.experimental.v1.TeamMember members = 4;
     */
    members: TeamMember[];
    /**
     * team_invitation is the team invitation.
     *
     * @generated from field: gitpod.experimental.v1.TeamInvitation team_invitation = 5;
     */
    teamInvitation?: TeamInvitation;
    constructor(data?: PartialMessage<Team>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.Team";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): Team;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): Team;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): Team;
    static equals(a: Team | PlainMessage<Team> | undefined, b: Team | PlainMessage<Team> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.TeamMember
 */
export declare class TeamMember extends Message<TeamMember> {
    /**
     * user_id is the identifier of the user
     *
     * @generated from field: string user_id = 1;
     */
    userId: string;
    /**
     * role is the role this member is assigned
     *
     * @generated from field: gitpod.experimental.v1.TeamRole role = 2;
     */
    role: TeamRole;
    /**
     * member_since is the timestamp when the member joined the team
     *
     * @generated from field: google.protobuf.Timestamp member_since = 3;
     */
    memberSince?: Timestamp;
    /**
     * avatar_url is the URL for the TeamMember
     *
     * @generated from field: string avatar_url = 4;
     */
    avatarUrl: string;
    /**
     * full_name is the name of the TeamMember
     *
     * @generated from field: string full_name = 5;
     */
    fullName: string;
    /**
     * primary_email is the primary email of the TeamMember
     *
     * @generated from field: string primary_email = 6;
     */
    primaryEmail: string;
    /**
     * owned_by_organization indicates if the TeamMember is owned by the organization
     *
     * @generated from field: bool owned_by_organization = 7;
     */
    ownedByOrganization: boolean;
    constructor(data?: PartialMessage<TeamMember>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.TeamMember";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): TeamMember;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): TeamMember;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): TeamMember;
    static equals(a: TeamMember | PlainMessage<TeamMember> | undefined, b: TeamMember | PlainMessage<TeamMember> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.TeamInvitation
 */
export declare class TeamInvitation extends Message<TeamInvitation> {
    /**
     * id is the invitation ID.
     *
     * @generated from field: string id = 1;
     */
    id: string;
    constructor(data?: PartialMessage<TeamInvitation>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.TeamInvitation";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): TeamInvitation;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): TeamInvitation;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): TeamInvitation;
    static equals(a: TeamInvitation | PlainMessage<TeamInvitation> | undefined, b: TeamInvitation | PlainMessage<TeamInvitation> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.CreateTeamRequest
 */
export declare class CreateTeamRequest extends Message<CreateTeamRequest> {
    /**
     * name is the team name
     *
     * @generated from field: string name = 1;
     */
    name: string;
    constructor(data?: PartialMessage<CreateTeamRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.CreateTeamRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): CreateTeamRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): CreateTeamRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): CreateTeamRequest;
    static equals(a: CreateTeamRequest | PlainMessage<CreateTeamRequest> | undefined, b: CreateTeamRequest | PlainMessage<CreateTeamRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.CreateTeamResponse
 */
export declare class CreateTeamResponse extends Message<CreateTeamResponse> {
    /**
     * @generated from field: gitpod.experimental.v1.Team team = 1;
     */
    team?: Team;
    constructor(data?: PartialMessage<CreateTeamResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.CreateTeamResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): CreateTeamResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): CreateTeamResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): CreateTeamResponse;
    static equals(a: CreateTeamResponse | PlainMessage<CreateTeamResponse> | undefined, b: CreateTeamResponse | PlainMessage<CreateTeamResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.GetTeamRequest
 */
export declare class GetTeamRequest extends Message<GetTeamRequest> {
    /**
     * team_id is the unique identifier of the Team to retreive.
     *
     * @generated from field: string team_id = 1;
     */
    teamId: string;
    constructor(data?: PartialMessage<GetTeamRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.GetTeamRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetTeamRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetTeamRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetTeamRequest;
    static equals(a: GetTeamRequest | PlainMessage<GetTeamRequest> | undefined, b: GetTeamRequest | PlainMessage<GetTeamRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.GetTeamResponse
 */
export declare class GetTeamResponse extends Message<GetTeamResponse> {
    /**
     * @generated from field: gitpod.experimental.v1.Team team = 1;
     */
    team?: Team;
    constructor(data?: PartialMessage<GetTeamResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.GetTeamResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetTeamResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetTeamResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetTeamResponse;
    static equals(a: GetTeamResponse | PlainMessage<GetTeamResponse> | undefined, b: GetTeamResponse | PlainMessage<GetTeamResponse> | undefined): boolean;
}
/**
 * TODO: pagination options
 *
 * @generated from message gitpod.experimental.v1.ListTeamsRequest
 */
export declare class ListTeamsRequest extends Message<ListTeamsRequest> {
    constructor(data?: PartialMessage<ListTeamsRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.ListTeamsRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListTeamsRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListTeamsRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListTeamsRequest;
    static equals(a: ListTeamsRequest | PlainMessage<ListTeamsRequest> | undefined, b: ListTeamsRequest | PlainMessage<ListTeamsRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.ListTeamsResponse
 */
export declare class ListTeamsResponse extends Message<ListTeamsResponse> {
    /**
     * @generated from field: repeated gitpod.experimental.v1.Team teams = 1;
     */
    teams: Team[];
    constructor(data?: PartialMessage<ListTeamsResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.ListTeamsResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListTeamsResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListTeamsResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListTeamsResponse;
    static equals(a: ListTeamsResponse | PlainMessage<ListTeamsResponse> | undefined, b: ListTeamsResponse | PlainMessage<ListTeamsResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.DeleteTeamRequest
 */
export declare class DeleteTeamRequest extends Message<DeleteTeamRequest> {
    /**
     * team_id is the ID of the team to delete
     *
     * @generated from field: string team_id = 1;
     */
    teamId: string;
    constructor(data?: PartialMessage<DeleteTeamRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.DeleteTeamRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): DeleteTeamRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): DeleteTeamRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): DeleteTeamRequest;
    static equals(a: DeleteTeamRequest | PlainMessage<DeleteTeamRequest> | undefined, b: DeleteTeamRequest | PlainMessage<DeleteTeamRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.DeleteTeamResponse
 */
export declare class DeleteTeamResponse extends Message<DeleteTeamResponse> {
    constructor(data?: PartialMessage<DeleteTeamResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.DeleteTeamResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): DeleteTeamResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): DeleteTeamResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): DeleteTeamResponse;
    static equals(a: DeleteTeamResponse | PlainMessage<DeleteTeamResponse> | undefined, b: DeleteTeamResponse | PlainMessage<DeleteTeamResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.GetTeamInvitationRequest
 */
export declare class GetTeamInvitationRequest extends Message<GetTeamInvitationRequest> {
    /**
     * @generated from field: string team_id = 1;
     */
    teamId: string;
    constructor(data?: PartialMessage<GetTeamInvitationRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.GetTeamInvitationRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetTeamInvitationRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetTeamInvitationRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetTeamInvitationRequest;
    static equals(a: GetTeamInvitationRequest | PlainMessage<GetTeamInvitationRequest> | undefined, b: GetTeamInvitationRequest | PlainMessage<GetTeamInvitationRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.GetTeamInvitationResponse
 */
export declare class GetTeamInvitationResponse extends Message<GetTeamInvitationResponse> {
    /**
     * team_invitation is the invitation for the team.
     *
     * @generated from field: gitpod.experimental.v1.TeamInvitation team_invitation = 1;
     */
    teamInvitation?: TeamInvitation;
    constructor(data?: PartialMessage<GetTeamInvitationResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.GetTeamInvitationResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetTeamInvitationResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetTeamInvitationResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetTeamInvitationResponse;
    static equals(a: GetTeamInvitationResponse | PlainMessage<GetTeamInvitationResponse> | undefined, b: GetTeamInvitationResponse | PlainMessage<GetTeamInvitationResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.JoinTeamRequest
 */
export declare class JoinTeamRequest extends Message<JoinTeamRequest> {
    /**
     * invitation_id is the invitation ID for a Team
     *
     * @generated from field: string invitation_id = 1;
     */
    invitationId: string;
    constructor(data?: PartialMessage<JoinTeamRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.JoinTeamRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): JoinTeamRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): JoinTeamRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): JoinTeamRequest;
    static equals(a: JoinTeamRequest | PlainMessage<JoinTeamRequest> | undefined, b: JoinTeamRequest | PlainMessage<JoinTeamRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.JoinTeamResponse
 */
export declare class JoinTeamResponse extends Message<JoinTeamResponse> {
    /**
     * team is the team the user has just joined
     *
     * @generated from field: gitpod.experimental.v1.Team team = 1;
     */
    team?: Team;
    constructor(data?: PartialMessage<JoinTeamResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.JoinTeamResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): JoinTeamResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): JoinTeamResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): JoinTeamResponse;
    static equals(a: JoinTeamResponse | PlainMessage<JoinTeamResponse> | undefined, b: JoinTeamResponse | PlainMessage<JoinTeamResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.ResetTeamInvitationRequest
 */
export declare class ResetTeamInvitationRequest extends Message<ResetTeamInvitationRequest> {
    /**
     * @generated from field: string team_id = 1;
     */
    teamId: string;
    constructor(data?: PartialMessage<ResetTeamInvitationRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.ResetTeamInvitationRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ResetTeamInvitationRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ResetTeamInvitationRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ResetTeamInvitationRequest;
    static equals(a: ResetTeamInvitationRequest | PlainMessage<ResetTeamInvitationRequest> | undefined, b: ResetTeamInvitationRequest | PlainMessage<ResetTeamInvitationRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.ResetTeamInvitationResponse
 */
export declare class ResetTeamInvitationResponse extends Message<ResetTeamInvitationResponse> {
    /**
     * team_invitation is the new invitation for the team.
     *
     * @generated from field: gitpod.experimental.v1.TeamInvitation team_invitation = 1;
     */
    teamInvitation?: TeamInvitation;
    constructor(data?: PartialMessage<ResetTeamInvitationResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.ResetTeamInvitationResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ResetTeamInvitationResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ResetTeamInvitationResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ResetTeamInvitationResponse;
    static equals(a: ResetTeamInvitationResponse | PlainMessage<ResetTeamInvitationResponse> | undefined, b: ResetTeamInvitationResponse | PlainMessage<ResetTeamInvitationResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.ListTeamMembersRequest
 */
export declare class ListTeamMembersRequest extends Message<ListTeamMembersRequest> {
    /**
     * team_id is the ID of the team that contains the members to list
     *
     * @generated from field: string team_id = 1;
     */
    teamId: string;
    constructor(data?: PartialMessage<ListTeamMembersRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.ListTeamMembersRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListTeamMembersRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListTeamMembersRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListTeamMembersRequest;
    static equals(a: ListTeamMembersRequest | PlainMessage<ListTeamMembersRequest> | undefined, b: ListTeamMembersRequest | PlainMessage<ListTeamMembersRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.ListTeamMembersResponse
 */
export declare class ListTeamMembersResponse extends Message<ListTeamMembersResponse> {
    /**
     * members are the team members of this Team
     *
     * @generated from field: repeated gitpod.experimental.v1.TeamMember members = 1;
     */
    members: TeamMember[];
    constructor(data?: PartialMessage<ListTeamMembersResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.ListTeamMembersResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListTeamMembersResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListTeamMembersResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListTeamMembersResponse;
    static equals(a: ListTeamMembersResponse | PlainMessage<ListTeamMembersResponse> | undefined, b: ListTeamMembersResponse | PlainMessage<ListTeamMembersResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.UpdateTeamMemberRequest
 */
export declare class UpdateTeamMemberRequest extends Message<UpdateTeamMemberRequest> {
    /**
     * team_id is the ID of the team in which the role is to be updated
     *
     * @generated from field: string team_id = 1;
     */
    teamId: string;
    /**
     * team_member is the team member being updated.
     *
     * @generated from field: gitpod.experimental.v1.TeamMember team_member = 2;
     */
    teamMember?: TeamMember;
    constructor(data?: PartialMessage<UpdateTeamMemberRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.UpdateTeamMemberRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdateTeamMemberRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdateTeamMemberRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdateTeamMemberRequest;
    static equals(a: UpdateTeamMemberRequest | PlainMessage<UpdateTeamMemberRequest> | undefined, b: UpdateTeamMemberRequest | PlainMessage<UpdateTeamMemberRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.UpdateTeamMemberResponse
 */
export declare class UpdateTeamMemberResponse extends Message<UpdateTeamMemberResponse> {
    /**
     * @generated from field: gitpod.experimental.v1.TeamMember team_member = 2;
     */
    teamMember?: TeamMember;
    constructor(data?: PartialMessage<UpdateTeamMemberResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.UpdateTeamMemberResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdateTeamMemberResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdateTeamMemberResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdateTeamMemberResponse;
    static equals(a: UpdateTeamMemberResponse | PlainMessage<UpdateTeamMemberResponse> | undefined, b: UpdateTeamMemberResponse | PlainMessage<UpdateTeamMemberResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.DeleteTeamMemberRequest
 */
export declare class DeleteTeamMemberRequest extends Message<DeleteTeamMemberRequest> {
    /**
     * team_id is the ID of the team in which a member should be deleted.
     *
     * @generated from field: string team_id = 1;
     */
    teamId: string;
    /**
     * team_member_id is the ID of the TeamMember that should be deleted from the team.
     *
     * @generated from field: string team_member_id = 2;
     */
    teamMemberId: string;
    constructor(data?: PartialMessage<DeleteTeamMemberRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.DeleteTeamMemberRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): DeleteTeamMemberRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): DeleteTeamMemberRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): DeleteTeamMemberRequest;
    static equals(a: DeleteTeamMemberRequest | PlainMessage<DeleteTeamMemberRequest> | undefined, b: DeleteTeamMemberRequest | PlainMessage<DeleteTeamMemberRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.DeleteTeamMemberResponse
 */
export declare class DeleteTeamMemberResponse extends Message<DeleteTeamMemberResponse> {
    constructor(data?: PartialMessage<DeleteTeamMemberResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.DeleteTeamMemberResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): DeleteTeamMemberResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): DeleteTeamMemberResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): DeleteTeamMemberResponse;
    static equals(a: DeleteTeamMemberResponse | PlainMessage<DeleteTeamMemberResponse> | undefined, b: DeleteTeamMemberResponse | PlainMessage<DeleteTeamMemberResponse> | undefined): boolean;
}
//# sourceMappingURL=teams_pb.d.ts.map