/**
 * Copyright (c) 2024 Gitpod GmbH. All rights reserved.
 * Licensed under the GNU Affero General Public License (AGPL).
 * See License.AGPL.txt in the project root for license information.
 */
import type { BinaryReadOptions, FieldList, JsonReadOptions, JsonValue, PartialMessage, PlainMessage } from "@bufbuild/protobuf";
import { FieldMask, Message, proto3, Timestamp } from "@bufbuild/protobuf";
import { Pagination } from "./pagination_pb.js";
/**
 * PersonalAccessToken represents details of an access token for personal use.
 *
 * @generated from message gitpod.experimental.v1.PersonalAccessToken
 */
export declare class PersonalAccessToken extends Message<PersonalAccessToken> {
    /**
     * id is the unique identifier of this token
     * Read only.
     *
     * @generated from field: string id = 1;
     */
    id: string;
    /**
     * value is the secret value of the token
     * The value property is only populated when the PersonalAccessToken is first created, and never again.
     * Read only.
     *
     * @generated from field: string value = 2;
     */
    value: string;
    /**
     * name is the name of the token for humans, set by the user.
     * Must match regexp ^[a-zA-Z0-9-_ ]{3,63}$
     *
     * @generated from field: string name = 3;
     */
    name: string;
    /**
     * expiration_time is the time when the token expires
     * Read only.
     *
     * @generated from field: google.protobuf.Timestamp expiration_time = 4;
     */
    expirationTime?: Timestamp;
    /**
     * scopes are the permission scopes attached to this token.
     * By default, no scopes are attached and therefore no access is granted to this token.
     * Specifying '*' grants all permissions the owner of the token has.
     *
     * @generated from field: repeated string scopes = 5;
     */
    scopes: string[];
    /**
     * created_time is the time when the token was first created.
     *
     * @generated from field: google.protobuf.Timestamp created_at = 6;
     */
    createdAt?: Timestamp;
    constructor(data?: PartialMessage<PersonalAccessToken>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.PersonalAccessToken";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): PersonalAccessToken;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): PersonalAccessToken;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): PersonalAccessToken;
    static equals(a: PersonalAccessToken | PlainMessage<PersonalAccessToken> | undefined, b: PersonalAccessToken | PlainMessage<PersonalAccessToken> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.CreatePersonalAccessTokenRequest
 */
export declare class CreatePersonalAccessTokenRequest extends Message<CreatePersonalAccessTokenRequest> {
    /**
     * @generated from field: gitpod.experimental.v1.PersonalAccessToken token = 1;
     */
    token?: PersonalAccessToken;
    constructor(data?: PartialMessage<CreatePersonalAccessTokenRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.CreatePersonalAccessTokenRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): CreatePersonalAccessTokenRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): CreatePersonalAccessTokenRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): CreatePersonalAccessTokenRequest;
    static equals(a: CreatePersonalAccessTokenRequest | PlainMessage<CreatePersonalAccessTokenRequest> | undefined, b: CreatePersonalAccessTokenRequest | PlainMessage<CreatePersonalAccessTokenRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.CreatePersonalAccessTokenResponse
 */
export declare class CreatePersonalAccessTokenResponse extends Message<CreatePersonalAccessTokenResponse> {
    /**
     * @generated from field: gitpod.experimental.v1.PersonalAccessToken token = 1;
     */
    token?: PersonalAccessToken;
    constructor(data?: PartialMessage<CreatePersonalAccessTokenResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.CreatePersonalAccessTokenResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): CreatePersonalAccessTokenResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): CreatePersonalAccessTokenResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): CreatePersonalAccessTokenResponse;
    static equals(a: CreatePersonalAccessTokenResponse | PlainMessage<CreatePersonalAccessTokenResponse> | undefined, b: CreatePersonalAccessTokenResponse | PlainMessage<CreatePersonalAccessTokenResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.GetPersonalAccessTokenRequest
 */
export declare class GetPersonalAccessTokenRequest extends Message<GetPersonalAccessTokenRequest> {
    /**
     * @generated from field: string id = 1;
     */
    id: string;
    constructor(data?: PartialMessage<GetPersonalAccessTokenRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.GetPersonalAccessTokenRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetPersonalAccessTokenRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetPersonalAccessTokenRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetPersonalAccessTokenRequest;
    static equals(a: GetPersonalAccessTokenRequest | PlainMessage<GetPersonalAccessTokenRequest> | undefined, b: GetPersonalAccessTokenRequest | PlainMessage<GetPersonalAccessTokenRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.GetPersonalAccessTokenResponse
 */
export declare class GetPersonalAccessTokenResponse extends Message<GetPersonalAccessTokenResponse> {
    /**
     * @generated from field: gitpod.experimental.v1.PersonalAccessToken token = 1;
     */
    token?: PersonalAccessToken;
    constructor(data?: PartialMessage<GetPersonalAccessTokenResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.GetPersonalAccessTokenResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetPersonalAccessTokenResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetPersonalAccessTokenResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetPersonalAccessTokenResponse;
    static equals(a: GetPersonalAccessTokenResponse | PlainMessage<GetPersonalAccessTokenResponse> | undefined, b: GetPersonalAccessTokenResponse | PlainMessage<GetPersonalAccessTokenResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.ListPersonalAccessTokensRequest
 */
export declare class ListPersonalAccessTokensRequest extends Message<ListPersonalAccessTokensRequest> {
    /**
     * Page information
     *
     * @generated from field: gitpod.experimental.v1.Pagination pagination = 1;
     */
    pagination?: Pagination;
    constructor(data?: PartialMessage<ListPersonalAccessTokensRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.ListPersonalAccessTokensRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListPersonalAccessTokensRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListPersonalAccessTokensRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListPersonalAccessTokensRequest;
    static equals(a: ListPersonalAccessTokensRequest | PlainMessage<ListPersonalAccessTokensRequest> | undefined, b: ListPersonalAccessTokensRequest | PlainMessage<ListPersonalAccessTokensRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.ListPersonalAccessTokensResponse
 */
export declare class ListPersonalAccessTokensResponse extends Message<ListPersonalAccessTokensResponse> {
    /**
     * @generated from field: repeated gitpod.experimental.v1.PersonalAccessToken tokens = 1;
     */
    tokens: PersonalAccessToken[];
    /**
     * @generated from field: int64 total_results = 2;
     */
    totalResults: bigint;
    constructor(data?: PartialMessage<ListPersonalAccessTokensResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.ListPersonalAccessTokensResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListPersonalAccessTokensResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListPersonalAccessTokensResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListPersonalAccessTokensResponse;
    static equals(a: ListPersonalAccessTokensResponse | PlainMessage<ListPersonalAccessTokensResponse> | undefined, b: ListPersonalAccessTokensResponse | PlainMessage<ListPersonalAccessTokensResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.RegeneratePersonalAccessTokenRequest
 */
export declare class RegeneratePersonalAccessTokenRequest extends Message<RegeneratePersonalAccessTokenRequest> {
    /**
     * id is the ID of the PersonalAccessToken
     *
     * @generated from field: string id = 1;
     */
    id: string;
    /**
     * expiration time is the time when the new token should expire
     *
     * @generated from field: google.protobuf.Timestamp expiration_time = 2;
     */
    expirationTime?: Timestamp;
    constructor(data?: PartialMessage<RegeneratePersonalAccessTokenRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.RegeneratePersonalAccessTokenRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): RegeneratePersonalAccessTokenRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): RegeneratePersonalAccessTokenRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): RegeneratePersonalAccessTokenRequest;
    static equals(a: RegeneratePersonalAccessTokenRequest | PlainMessage<RegeneratePersonalAccessTokenRequest> | undefined, b: RegeneratePersonalAccessTokenRequest | PlainMessage<RegeneratePersonalAccessTokenRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.RegeneratePersonalAccessTokenResponse
 */
export declare class RegeneratePersonalAccessTokenResponse extends Message<RegeneratePersonalAccessTokenResponse> {
    /**
     * @generated from field: gitpod.experimental.v1.PersonalAccessToken token = 1;
     */
    token?: PersonalAccessToken;
    constructor(data?: PartialMessage<RegeneratePersonalAccessTokenResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.RegeneratePersonalAccessTokenResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): RegeneratePersonalAccessTokenResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): RegeneratePersonalAccessTokenResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): RegeneratePersonalAccessTokenResponse;
    static equals(a: RegeneratePersonalAccessTokenResponse | PlainMessage<RegeneratePersonalAccessTokenResponse> | undefined, b: RegeneratePersonalAccessTokenResponse | PlainMessage<RegeneratePersonalAccessTokenResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.UpdatePersonalAccessTokenRequest
 */
export declare class UpdatePersonalAccessTokenRequest extends Message<UpdatePersonalAccessTokenRequest> {
    /**
     * @generated from field: gitpod.experimental.v1.PersonalAccessToken token = 1;
     */
    token?: PersonalAccessToken;
    /**
     * @generated from field: google.protobuf.FieldMask update_mask = 2;
     */
    updateMask?: FieldMask;
    constructor(data?: PartialMessage<UpdatePersonalAccessTokenRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.UpdatePersonalAccessTokenRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdatePersonalAccessTokenRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdatePersonalAccessTokenRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdatePersonalAccessTokenRequest;
    static equals(a: UpdatePersonalAccessTokenRequest | PlainMessage<UpdatePersonalAccessTokenRequest> | undefined, b: UpdatePersonalAccessTokenRequest | PlainMessage<UpdatePersonalAccessTokenRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.UpdatePersonalAccessTokenResponse
 */
export declare class UpdatePersonalAccessTokenResponse extends Message<UpdatePersonalAccessTokenResponse> {
    /**
     * @generated from field: gitpod.experimental.v1.PersonalAccessToken token = 1;
     */
    token?: PersonalAccessToken;
    constructor(data?: PartialMessage<UpdatePersonalAccessTokenResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.UpdatePersonalAccessTokenResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdatePersonalAccessTokenResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdatePersonalAccessTokenResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdatePersonalAccessTokenResponse;
    static equals(a: UpdatePersonalAccessTokenResponse | PlainMessage<UpdatePersonalAccessTokenResponse> | undefined, b: UpdatePersonalAccessTokenResponse | PlainMessage<UpdatePersonalAccessTokenResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.DeletePersonalAccessTokenRequest
 */
export declare class DeletePersonalAccessTokenRequest extends Message<DeletePersonalAccessTokenRequest> {
    /**
     * @generated from field: string id = 1;
     */
    id: string;
    constructor(data?: PartialMessage<DeletePersonalAccessTokenRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.DeletePersonalAccessTokenRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): DeletePersonalAccessTokenRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): DeletePersonalAccessTokenRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): DeletePersonalAccessTokenRequest;
    static equals(a: DeletePersonalAccessTokenRequest | PlainMessage<DeletePersonalAccessTokenRequest> | undefined, b: DeletePersonalAccessTokenRequest | PlainMessage<DeletePersonalAccessTokenRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.DeletePersonalAccessTokenResponse
 */
export declare class DeletePersonalAccessTokenResponse extends Message<DeletePersonalAccessTokenResponse> {
    constructor(data?: PartialMessage<DeletePersonalAccessTokenResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.DeletePersonalAccessTokenResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): DeletePersonalAccessTokenResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): DeletePersonalAccessTokenResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): DeletePersonalAccessTokenResponse;
    static equals(a: DeletePersonalAccessTokenResponse | PlainMessage<DeletePersonalAccessTokenResponse> | undefined, b: DeletePersonalAccessTokenResponse | PlainMessage<DeletePersonalAccessTokenResponse> | undefined): boolean;
}
//# sourceMappingURL=tokens_pb.d.ts.map