"use strict";
/**
 * Copyright (c) 2024 Gitpod GmbH. All rights reserved.
 * Licensed under the GNU Affero General Public License (AGPL).
 * See License.AGPL.txt in the project root for license information.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.DeletePersonalAccessTokenResponse = exports.DeletePersonalAccessTokenRequest = exports.UpdatePersonalAccessTokenResponse = exports.UpdatePersonalAccessTokenRequest = exports.RegeneratePersonalAccessTokenResponse = exports.RegeneratePersonalAccessTokenRequest = exports.ListPersonalAccessTokensResponse = exports.ListPersonalAccessTokensRequest = exports.GetPersonalAccessTokenResponse = exports.GetPersonalAccessTokenRequest = exports.CreatePersonalAccessTokenResponse = exports.CreatePersonalAccessTokenRequest = exports.PersonalAccessToken = void 0;
const protobuf_1 = require("@bufbuild/protobuf");
const pagination_pb_js_1 = require("./pagination_pb.js");
/**
 * PersonalAccessToken represents details of an access token for personal use.
 *
 * @generated from message gitpod.experimental.v1.PersonalAccessToken
 */
class PersonalAccessToken extends protobuf_1.Message {
    constructor(data) {
        super();
        /**
         * id is the unique identifier of this token
         * Read only.
         *
         * @generated from field: string id = 1;
         */
        this.id = "";
        /**
         * value is the secret value of the token
         * The value property is only populated when the PersonalAccessToken is first created, and never again.
         * Read only.
         *
         * @generated from field: string value = 2;
         */
        this.value = "";
        /**
         * name is the name of the token for humans, set by the user.
         * Must match regexp ^[a-zA-Z0-9-_ ]{3,63}$
         *
         * @generated from field: string name = 3;
         */
        this.name = "";
        /**
         * scopes are the permission scopes attached to this token.
         * By default, no scopes are attached and therefore no access is granted to this token.
         * Specifying '*' grants all permissions the owner of the token has.
         *
         * @generated from field: repeated string scopes = 5;
         */
        this.scopes = [];
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new PersonalAccessToken().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new PersonalAccessToken().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new PersonalAccessToken().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(PersonalAccessToken, a, b);
    }
}
exports.PersonalAccessToken = PersonalAccessToken;
PersonalAccessToken.runtime = protobuf_1.proto3;
PersonalAccessToken.typeName = "gitpod.experimental.v1.PersonalAccessToken";
PersonalAccessToken.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "value", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 3, name: "name", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 4, name: "expiration_time", kind: "message", T: protobuf_1.Timestamp },
    { no: 5, name: "scopes", kind: "scalar", T: 9 /* ScalarType.STRING */, repeated: true },
    { no: 6, name: "created_at", kind: "message", T: protobuf_1.Timestamp },
]);
/**
 * @generated from message gitpod.experimental.v1.CreatePersonalAccessTokenRequest
 */
class CreatePersonalAccessTokenRequest extends protobuf_1.Message {
    constructor(data) {
        super();
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new CreatePersonalAccessTokenRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new CreatePersonalAccessTokenRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new CreatePersonalAccessTokenRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(CreatePersonalAccessTokenRequest, a, b);
    }
}
exports.CreatePersonalAccessTokenRequest = CreatePersonalAccessTokenRequest;
CreatePersonalAccessTokenRequest.runtime = protobuf_1.proto3;
CreatePersonalAccessTokenRequest.typeName = "gitpod.experimental.v1.CreatePersonalAccessTokenRequest";
CreatePersonalAccessTokenRequest.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "token", kind: "message", T: PersonalAccessToken },
]);
/**
 * @generated from message gitpod.experimental.v1.CreatePersonalAccessTokenResponse
 */
class CreatePersonalAccessTokenResponse extends protobuf_1.Message {
    constructor(data) {
        super();
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new CreatePersonalAccessTokenResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new CreatePersonalAccessTokenResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new CreatePersonalAccessTokenResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(CreatePersonalAccessTokenResponse, a, b);
    }
}
exports.CreatePersonalAccessTokenResponse = CreatePersonalAccessTokenResponse;
CreatePersonalAccessTokenResponse.runtime = protobuf_1.proto3;
CreatePersonalAccessTokenResponse.typeName = "gitpod.experimental.v1.CreatePersonalAccessTokenResponse";
CreatePersonalAccessTokenResponse.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "token", kind: "message", T: PersonalAccessToken },
]);
/**
 * @generated from message gitpod.experimental.v1.GetPersonalAccessTokenRequest
 */
class GetPersonalAccessTokenRequest extends protobuf_1.Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string id = 1;
         */
        this.id = "";
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new GetPersonalAccessTokenRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new GetPersonalAccessTokenRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new GetPersonalAccessTokenRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(GetPersonalAccessTokenRequest, a, b);
    }
}
exports.GetPersonalAccessTokenRequest = GetPersonalAccessTokenRequest;
GetPersonalAccessTokenRequest.runtime = protobuf_1.proto3;
GetPersonalAccessTokenRequest.typeName = "gitpod.experimental.v1.GetPersonalAccessTokenRequest";
GetPersonalAccessTokenRequest.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.experimental.v1.GetPersonalAccessTokenResponse
 */
class GetPersonalAccessTokenResponse extends protobuf_1.Message {
    constructor(data) {
        super();
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new GetPersonalAccessTokenResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new GetPersonalAccessTokenResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new GetPersonalAccessTokenResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(GetPersonalAccessTokenResponse, a, b);
    }
}
exports.GetPersonalAccessTokenResponse = GetPersonalAccessTokenResponse;
GetPersonalAccessTokenResponse.runtime = protobuf_1.proto3;
GetPersonalAccessTokenResponse.typeName = "gitpod.experimental.v1.GetPersonalAccessTokenResponse";
GetPersonalAccessTokenResponse.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "token", kind: "message", T: PersonalAccessToken },
]);
/**
 * @generated from message gitpod.experimental.v1.ListPersonalAccessTokensRequest
 */
class ListPersonalAccessTokensRequest extends protobuf_1.Message {
    constructor(data) {
        super();
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new ListPersonalAccessTokensRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new ListPersonalAccessTokensRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new ListPersonalAccessTokensRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(ListPersonalAccessTokensRequest, a, b);
    }
}
exports.ListPersonalAccessTokensRequest = ListPersonalAccessTokensRequest;
ListPersonalAccessTokensRequest.runtime = protobuf_1.proto3;
ListPersonalAccessTokensRequest.typeName = "gitpod.experimental.v1.ListPersonalAccessTokensRequest";
ListPersonalAccessTokensRequest.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "pagination", kind: "message", T: pagination_pb_js_1.Pagination },
]);
/**
 * @generated from message gitpod.experimental.v1.ListPersonalAccessTokensResponse
 */
class ListPersonalAccessTokensResponse extends protobuf_1.Message {
    constructor(data) {
        super();
        /**
         * @generated from field: repeated gitpod.experimental.v1.PersonalAccessToken tokens = 1;
         */
        this.tokens = [];
        /**
         * @generated from field: int64 total_results = 2;
         */
        this.totalResults = protobuf_1.protoInt64.zero;
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new ListPersonalAccessTokensResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new ListPersonalAccessTokensResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new ListPersonalAccessTokensResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(ListPersonalAccessTokensResponse, a, b);
    }
}
exports.ListPersonalAccessTokensResponse = ListPersonalAccessTokensResponse;
ListPersonalAccessTokensResponse.runtime = protobuf_1.proto3;
ListPersonalAccessTokensResponse.typeName = "gitpod.experimental.v1.ListPersonalAccessTokensResponse";
ListPersonalAccessTokensResponse.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "tokens", kind: "message", T: PersonalAccessToken, repeated: true },
    { no: 2, name: "total_results", kind: "scalar", T: 3 /* ScalarType.INT64 */ },
]);
/**
 * @generated from message gitpod.experimental.v1.RegeneratePersonalAccessTokenRequest
 */
class RegeneratePersonalAccessTokenRequest extends protobuf_1.Message {
    constructor(data) {
        super();
        /**
         * id is the ID of the PersonalAccessToken
         *
         * @generated from field: string id = 1;
         */
        this.id = "";
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new RegeneratePersonalAccessTokenRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new RegeneratePersonalAccessTokenRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new RegeneratePersonalAccessTokenRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(RegeneratePersonalAccessTokenRequest, a, b);
    }
}
exports.RegeneratePersonalAccessTokenRequest = RegeneratePersonalAccessTokenRequest;
RegeneratePersonalAccessTokenRequest.runtime = protobuf_1.proto3;
RegeneratePersonalAccessTokenRequest.typeName = "gitpod.experimental.v1.RegeneratePersonalAccessTokenRequest";
RegeneratePersonalAccessTokenRequest.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
    { no: 2, name: "expiration_time", kind: "message", T: protobuf_1.Timestamp },
]);
/**
 * @generated from message gitpod.experimental.v1.RegeneratePersonalAccessTokenResponse
 */
class RegeneratePersonalAccessTokenResponse extends protobuf_1.Message {
    constructor(data) {
        super();
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new RegeneratePersonalAccessTokenResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new RegeneratePersonalAccessTokenResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new RegeneratePersonalAccessTokenResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(RegeneratePersonalAccessTokenResponse, a, b);
    }
}
exports.RegeneratePersonalAccessTokenResponse = RegeneratePersonalAccessTokenResponse;
RegeneratePersonalAccessTokenResponse.runtime = protobuf_1.proto3;
RegeneratePersonalAccessTokenResponse.typeName = "gitpod.experimental.v1.RegeneratePersonalAccessTokenResponse";
RegeneratePersonalAccessTokenResponse.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "token", kind: "message", T: PersonalAccessToken },
]);
/**
 * @generated from message gitpod.experimental.v1.UpdatePersonalAccessTokenRequest
 */
class UpdatePersonalAccessTokenRequest extends protobuf_1.Message {
    constructor(data) {
        super();
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new UpdatePersonalAccessTokenRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new UpdatePersonalAccessTokenRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new UpdatePersonalAccessTokenRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(UpdatePersonalAccessTokenRequest, a, b);
    }
}
exports.UpdatePersonalAccessTokenRequest = UpdatePersonalAccessTokenRequest;
UpdatePersonalAccessTokenRequest.runtime = protobuf_1.proto3;
UpdatePersonalAccessTokenRequest.typeName = "gitpod.experimental.v1.UpdatePersonalAccessTokenRequest";
UpdatePersonalAccessTokenRequest.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "token", kind: "message", T: PersonalAccessToken },
    { no: 2, name: "update_mask", kind: "message", T: protobuf_1.FieldMask },
]);
/**
 * @generated from message gitpod.experimental.v1.UpdatePersonalAccessTokenResponse
 */
class UpdatePersonalAccessTokenResponse extends protobuf_1.Message {
    constructor(data) {
        super();
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new UpdatePersonalAccessTokenResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new UpdatePersonalAccessTokenResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new UpdatePersonalAccessTokenResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(UpdatePersonalAccessTokenResponse, a, b);
    }
}
exports.UpdatePersonalAccessTokenResponse = UpdatePersonalAccessTokenResponse;
UpdatePersonalAccessTokenResponse.runtime = protobuf_1.proto3;
UpdatePersonalAccessTokenResponse.typeName = "gitpod.experimental.v1.UpdatePersonalAccessTokenResponse";
UpdatePersonalAccessTokenResponse.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "token", kind: "message", T: PersonalAccessToken },
]);
/**
 * @generated from message gitpod.experimental.v1.DeletePersonalAccessTokenRequest
 */
class DeletePersonalAccessTokenRequest extends protobuf_1.Message {
    constructor(data) {
        super();
        /**
         * @generated from field: string id = 1;
         */
        this.id = "";
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new DeletePersonalAccessTokenRequest().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new DeletePersonalAccessTokenRequest().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new DeletePersonalAccessTokenRequest().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(DeletePersonalAccessTokenRequest, a, b);
    }
}
exports.DeletePersonalAccessTokenRequest = DeletePersonalAccessTokenRequest;
DeletePersonalAccessTokenRequest.runtime = protobuf_1.proto3;
DeletePersonalAccessTokenRequest.typeName = "gitpod.experimental.v1.DeletePersonalAccessTokenRequest";
DeletePersonalAccessTokenRequest.fields = protobuf_1.proto3.util.newFieldList(() => [
    { no: 1, name: "id", kind: "scalar", T: 9 /* ScalarType.STRING */ },
]);
/**
 * @generated from message gitpod.experimental.v1.DeletePersonalAccessTokenResponse
 */
class DeletePersonalAccessTokenResponse extends protobuf_1.Message {
    constructor(data) {
        super();
        protobuf_1.proto3.util.initPartial(data, this);
    }
    static fromBinary(bytes, options) {
        return new DeletePersonalAccessTokenResponse().fromBinary(bytes, options);
    }
    static fromJson(jsonValue, options) {
        return new DeletePersonalAccessTokenResponse().fromJson(jsonValue, options);
    }
    static fromJsonString(jsonString, options) {
        return new DeletePersonalAccessTokenResponse().fromJsonString(jsonString, options);
    }
    static equals(a, b) {
        return protobuf_1.proto3.util.equals(DeletePersonalAccessTokenResponse, a, b);
    }
}
exports.DeletePersonalAccessTokenResponse = DeletePersonalAccessTokenResponse;
DeletePersonalAccessTokenResponse.runtime = protobuf_1.proto3;
DeletePersonalAccessTokenResponse.typeName = "gitpod.experimental.v1.DeletePersonalAccessTokenResponse";
DeletePersonalAccessTokenResponse.fields = protobuf_1.proto3.util.newFieldList(() => []);
//# sourceMappingURL=tokens_pb.js.map