/**
 * Copyright (c) 2024 Gitpod GmbH. All rights reserved.
 * Licensed under the GNU Affero General Public License (AGPL).
 * See License.AGPL.txt in the project root for license information.
 */
import { CreateAndStartWorkspaceRequest, CreateAndStartWorkspaceResponse, DeleteWorkspaceRequest, DeleteWorkspaceResponse, GetDefaultWorkspaceImageRequest, GetDefaultWorkspaceImageResponse, GetOwnerTokenRequest, GetOwnerTokenResponse, GetWorkspaceRequest, GetWorkspaceResponse, ListWorkspaceClassesRequest, ListWorkspaceClassesResponse, ListWorkspacesRequest, ListWorkspacesResponse, StartWorkspaceRequest, StartWorkspaceResponse, StopWorkspaceRequest, StopWorkspaceResponse, StreamWorkspaceStatusRequest, StreamWorkspaceStatusResponse, UpdatePortRequest, UpdatePortResponse } from "./workspaces_pb.js";
import { MethodKind } from "@bufbuild/protobuf";
/**
 * @generated from service gitpod.experimental.v1.WorkspacesService
 */
export declare const WorkspacesService: {
    readonly typeName: "gitpod.experimental.v1.WorkspacesService";
    readonly methods: {
        /**
         * ListWorkspaces enumerates all workspaces belonging to the authenticated user.
         *
         * @generated from rpc gitpod.experimental.v1.WorkspacesService.ListWorkspaces
         */
        readonly listWorkspaces: {
            readonly name: "ListWorkspaces";
            readonly I: typeof ListWorkspacesRequest;
            readonly O: typeof ListWorkspacesResponse;
            readonly kind: MethodKind.Unary;
        };
        /**
         * GetWorkspace returns a single workspace.
         *
         * @generated from rpc gitpod.experimental.v1.WorkspacesService.GetWorkspace
         */
        readonly getWorkspace: {
            readonly name: "GetWorkspace";
            readonly I: typeof GetWorkspaceRequest;
            readonly O: typeof GetWorkspaceResponse;
            readonly kind: MethodKind.Unary;
        };
        /**
         * StreamWorkspaceStatus returns workspace status once it changed.
         *
         * @generated from rpc gitpod.experimental.v1.WorkspacesService.StreamWorkspaceStatus
         */
        readonly streamWorkspaceStatus: {
            readonly name: "StreamWorkspaceStatus";
            readonly I: typeof StreamWorkspaceStatusRequest;
            readonly O: typeof StreamWorkspaceStatusResponse;
            readonly kind: MethodKind.ServerStreaming;
        };
        /**
         * GetOwnerToken returns an owner token.
         *
         * @generated from rpc gitpod.experimental.v1.WorkspacesService.GetOwnerToken
         */
        readonly getOwnerToken: {
            readonly name: "GetOwnerToken";
            readonly I: typeof GetOwnerTokenRequest;
            readonly O: typeof GetOwnerTokenResponse;
            readonly kind: MethodKind.Unary;
        };
        /**
         * CreateAndStartWorkspace creates a new workspace and starts it.
         *
         * @generated from rpc gitpod.experimental.v1.WorkspacesService.CreateAndStartWorkspace
         */
        readonly createAndStartWorkspace: {
            readonly name: "CreateAndStartWorkspace";
            readonly I: typeof CreateAndStartWorkspaceRequest;
            readonly O: typeof CreateAndStartWorkspaceResponse;
            readonly kind: MethodKind.Unary;
        };
        /**
         * StartWorkspace starts an existing workspace.
         *
         * @generated from rpc gitpod.experimental.v1.WorkspacesService.StartWorkspace
         */
        readonly startWorkspace: {
            readonly name: "StartWorkspace";
            readonly I: typeof StartWorkspaceRequest;
            readonly O: typeof StartWorkspaceResponse;
            readonly kind: MethodKind.Unary;
        };
        /**
         * StopWorkspace stops a running workspace (instance).
         * Errors:
         *   NOT_FOUND:           the workspace_id is unkown
         *   FAILED_PRECONDITION: if there's no running instance
         *
         * @generated from rpc gitpod.experimental.v1.WorkspacesService.StopWorkspace
         */
        readonly stopWorkspace: {
            readonly name: "StopWorkspace";
            readonly I: typeof StopWorkspaceRequest;
            readonly O: typeof StopWorkspaceResponse;
            readonly kind: MethodKind.Unary;
        };
        /**
         * DeleteWorkspace deletes a workspace.
         * When the workspace is running, it will be stopped as well.
         * Deleted workspaces cannot be started again.
         *
         * @generated from rpc gitpod.experimental.v1.WorkspacesService.DeleteWorkspace
         */
        readonly deleteWorkspace: {
            readonly name: "DeleteWorkspace";
            readonly I: typeof DeleteWorkspaceRequest;
            readonly O: typeof DeleteWorkspaceResponse;
            readonly kind: MethodKind.Unary;
        };
        /**
         * @generated from rpc gitpod.experimental.v1.WorkspacesService.UpdatePort
         */
        readonly updatePort: {
            readonly name: "UpdatePort";
            readonly I: typeof UpdatePortRequest;
            readonly O: typeof UpdatePortResponse;
            readonly kind: MethodKind.Unary;
        };
        /**
         * ListWorkspaceClasses enumerates all available workspace classes.
         *
         * @generated from rpc gitpod.experimental.v1.WorkspacesService.ListWorkspaceClasses
         */
        readonly listWorkspaceClasses: {
            readonly name: "ListWorkspaceClasses";
            readonly I: typeof ListWorkspaceClassesRequest;
            readonly O: typeof ListWorkspaceClassesResponse;
            readonly kind: MethodKind.Unary;
        };
        /**
         * GetDefaultWorkspaceImage returns the default workspace image from different sources.
         *
         * @generated from rpc gitpod.experimental.v1.WorkspacesService.GetDefaultWorkspaceImage
         */
        readonly getDefaultWorkspaceImage: {
            readonly name: "GetDefaultWorkspaceImage";
            readonly I: typeof GetDefaultWorkspaceImageRequest;
            readonly O: typeof GetDefaultWorkspaceImageResponse;
            readonly kind: MethodKind.Unary;
        };
    };
};
//# sourceMappingURL=workspaces_connect.d.ts.map