/**
 * Copyright (c) 2024 Gitpod GmbH. All rights reserved.
 * Licensed under the GNU Affero General Public License (AGPL).
 * See License.AGPL.txt in the project root for license information.
 */
import type { BinaryReadOptions, FieldList, JsonReadOptions, JsonValue, PartialMessage, PlainMessage } from "@bufbuild/protobuf";
import { FieldMask, Message, proto3, Timestamp } from "@bufbuild/protobuf";
import { Pagination } from "./pagination_pb.js";
/**
 * PortPolicy defines the accssbility policy of a workspace port is guarded by an authentication in the proxy
 *
 * @generated from enum gitpod.experimental.v1.PortPolicy
 */
export declare enum PortPolicy {
    /**
     * @generated from enum value: PORT_POLICY_UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * Private means the port is accessible by the workspace owner only using the workspace port URL
     *
     * @generated from enum value: PORT_POLICY_PRIVATE = 1;
     */
    PRIVATE = 1,
    /**
     * Public means the port is accessible by everybody using the workspace port URL
     *
     * @generated from enum value: PORT_POLICY_PUBLIC = 2;
     */
    PUBLIC = 2
}
/**
 * PortProtocol defines the backend protocol of port
 *
 * @generated from enum gitpod.experimental.v1.PortProtocol
 */
export declare enum PortProtocol {
    /**
     * @generated from enum value: PORT_PROTOCOL_UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * Http means the port backend is http
     *
     * @generated from enum value: PORT_PROTOCOL_HTTP = 1;
     */
    HTTP = 1,
    /**
     * Https means the port backend is https
     *
     * @generated from enum value: PORT_PROTOCOL_HTTPS = 2;
     */
    HTTPS = 2
}
/**
 * Admission level describes who can access a workspace instance and its ports.
 *
 * @generated from enum gitpod.experimental.v1.AdmissionLevel
 */
export declare enum AdmissionLevel {
    /**
     * @generated from enum value: ADMISSION_LEVEL_UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * ADMISSION_LEVEL_OWNER_ONLY means the workspace can only be accessed using the owner token
     *
     * @generated from enum value: ADMISSION_LEVEL_OWNER_ONLY = 1;
     */
    OWNER_ONLY = 1,
    /**
     * ADMISSION_LEVEL_EVERYONE means the workspace (including ports) can be accessed by everyone.
     *
     * @generated from enum value: ADMISSION_LEVEL_EVERYONE = 2;
     */
    EVERYONE = 2
}
/**
 * @generated from message gitpod.experimental.v1.ListWorkspacesRequest
 */
export declare class ListWorkspacesRequest extends Message<ListWorkspacesRequest> {
    /**
     * @generated from field: gitpod.experimental.v1.Pagination pagination = 1;
     */
    pagination?: Pagination;
    /**
     * @generated from field: google.protobuf.FieldMask field_mask = 2;
     */
    fieldMask?: FieldMask;
    /**
     * @generated from field: string organization_id = 3;
     */
    organizationId: string;
    constructor(data?: PartialMessage<ListWorkspacesRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.ListWorkspacesRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListWorkspacesRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListWorkspacesRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListWorkspacesRequest;
    static equals(a: ListWorkspacesRequest | PlainMessage<ListWorkspacesRequest> | undefined, b: ListWorkspacesRequest | PlainMessage<ListWorkspacesRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.ListWorkspacesResponse
 */
export declare class ListWorkspacesResponse extends Message<ListWorkspacesResponse> {
    /**
     * @generated from field: string next_page_token = 1;
     */
    nextPageToken: string;
    /**
     * @generated from field: repeated gitpod.experimental.v1.Workspace result = 2;
     */
    result: Workspace[];
    constructor(data?: PartialMessage<ListWorkspacesResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.ListWorkspacesResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListWorkspacesResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListWorkspacesResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListWorkspacesResponse;
    static equals(a: ListWorkspacesResponse | PlainMessage<ListWorkspacesResponse> | undefined, b: ListWorkspacesResponse | PlainMessage<ListWorkspacesResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.GetWorkspaceRequest
 */
export declare class GetWorkspaceRequest extends Message<GetWorkspaceRequest> {
    /**
     * @generated from field: string workspace_id = 1;
     */
    workspaceId: string;
    constructor(data?: PartialMessage<GetWorkspaceRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.GetWorkspaceRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetWorkspaceRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetWorkspaceRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetWorkspaceRequest;
    static equals(a: GetWorkspaceRequest | PlainMessage<GetWorkspaceRequest> | undefined, b: GetWorkspaceRequest | PlainMessage<GetWorkspaceRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.GetWorkspaceResponse
 */
export declare class GetWorkspaceResponse extends Message<GetWorkspaceResponse> {
    /**
     * @generated from field: gitpod.experimental.v1.Workspace result = 1;
     */
    result?: Workspace;
    constructor(data?: PartialMessage<GetWorkspaceResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.GetWorkspaceResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetWorkspaceResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetWorkspaceResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetWorkspaceResponse;
    static equals(a: GetWorkspaceResponse | PlainMessage<GetWorkspaceResponse> | undefined, b: GetWorkspaceResponse | PlainMessage<GetWorkspaceResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.StreamWorkspaceStatusRequest
 */
export declare class StreamWorkspaceStatusRequest extends Message<StreamWorkspaceStatusRequest> {
    /**
     * @generated from field: string workspace_id = 1;
     */
    workspaceId: string;
    constructor(data?: PartialMessage<StreamWorkspaceStatusRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.StreamWorkspaceStatusRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): StreamWorkspaceStatusRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): StreamWorkspaceStatusRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): StreamWorkspaceStatusRequest;
    static equals(a: StreamWorkspaceStatusRequest | PlainMessage<StreamWorkspaceStatusRequest> | undefined, b: StreamWorkspaceStatusRequest | PlainMessage<StreamWorkspaceStatusRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.StreamWorkspaceStatusResponse
 */
export declare class StreamWorkspaceStatusResponse extends Message<StreamWorkspaceStatusResponse> {
    /**
     * @generated from field: gitpod.experimental.v1.WorkspaceStatus result = 1;
     */
    result?: WorkspaceStatus;
    constructor(data?: PartialMessage<StreamWorkspaceStatusResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.StreamWorkspaceStatusResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): StreamWorkspaceStatusResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): StreamWorkspaceStatusResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): StreamWorkspaceStatusResponse;
    static equals(a: StreamWorkspaceStatusResponse | PlainMessage<StreamWorkspaceStatusResponse> | undefined, b: StreamWorkspaceStatusResponse | PlainMessage<StreamWorkspaceStatusResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.GetOwnerTokenRequest
 */
export declare class GetOwnerTokenRequest extends Message<GetOwnerTokenRequest> {
    /**
     * @generated from field: string workspace_id = 1;
     */
    workspaceId: string;
    constructor(data?: PartialMessage<GetOwnerTokenRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.GetOwnerTokenRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetOwnerTokenRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetOwnerTokenRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetOwnerTokenRequest;
    static equals(a: GetOwnerTokenRequest | PlainMessage<GetOwnerTokenRequest> | undefined, b: GetOwnerTokenRequest | PlainMessage<GetOwnerTokenRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.GetOwnerTokenResponse
 */
export declare class GetOwnerTokenResponse extends Message<GetOwnerTokenResponse> {
    /**
     * @generated from field: string token = 1;
     */
    token: string;
    constructor(data?: PartialMessage<GetOwnerTokenResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.GetOwnerTokenResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetOwnerTokenResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetOwnerTokenResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetOwnerTokenResponse;
    static equals(a: GetOwnerTokenResponse | PlainMessage<GetOwnerTokenResponse> | undefined, b: GetOwnerTokenResponse | PlainMessage<GetOwnerTokenResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.CreateAndStartWorkspaceRequest
 */
export declare class CreateAndStartWorkspaceRequest extends Message<CreateAndStartWorkspaceRequest> {
    /**
     * @generated from field: string idempotency_token = 1;
     */
    idempotencyToken: string;
    /**
     * @generated from oneof gitpod.experimental.v1.CreateAndStartWorkspaceRequest.source
     */
    source: {
        /**
         * @generated from field: string context_url = 2;
         */
        value: string;
        case: "contextUrl";
    } | {
        /**
         * @generated from field: string prebuild_id = 3;
         */
        value: string;
        case: "prebuildId";
    } | {
        case: undefined;
        value?: undefined;
    };
    /**
     * @generated from field: gitpod.experimental.v1.StartWorkspaceSpec start_spec = 5;
     */
    startSpec?: StartWorkspaceSpec;
    /**
     * @generated from field: string organization_id = 6;
     */
    organizationId: string;
    /**
     * @generated from field: bool ignore_running_workspace_on_same_commit = 7;
     */
    ignoreRunningWorkspaceOnSameCommit: boolean;
    /**
     * @generated from field: bool ignore_running_prebuild = 8;
     */
    ignoreRunningPrebuild: boolean;
    /**
     * @generated from field: bool allow_using_previous_prebuilds = 9;
     */
    allowUsingPreviousPrebuilds: boolean;
    /**
     * @generated from field: bool force_default_config = 10;
     */
    forceDefaultConfig: boolean;
    constructor(data?: PartialMessage<CreateAndStartWorkspaceRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.CreateAndStartWorkspaceRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): CreateAndStartWorkspaceRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): CreateAndStartWorkspaceRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): CreateAndStartWorkspaceRequest;
    static equals(a: CreateAndStartWorkspaceRequest | PlainMessage<CreateAndStartWorkspaceRequest> | undefined, b: CreateAndStartWorkspaceRequest | PlainMessage<CreateAndStartWorkspaceRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.CreateAndStartWorkspaceResponse
 */
export declare class CreateAndStartWorkspaceResponse extends Message<CreateAndStartWorkspaceResponse> {
    /**
     * @generated from field: string workspace_id = 1;
     */
    workspaceId: string;
    constructor(data?: PartialMessage<CreateAndStartWorkspaceResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.CreateAndStartWorkspaceResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): CreateAndStartWorkspaceResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): CreateAndStartWorkspaceResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): CreateAndStartWorkspaceResponse;
    static equals(a: CreateAndStartWorkspaceResponse | PlainMessage<CreateAndStartWorkspaceResponse> | undefined, b: CreateAndStartWorkspaceResponse | PlainMessage<CreateAndStartWorkspaceResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.StartWorkspaceRequest
 */
export declare class StartWorkspaceRequest extends Message<StartWorkspaceRequest> {
    /**
     * @generated from field: string workspace_id = 1;
     */
    workspaceId: string;
    constructor(data?: PartialMessage<StartWorkspaceRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.StartWorkspaceRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): StartWorkspaceRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): StartWorkspaceRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): StartWorkspaceRequest;
    static equals(a: StartWorkspaceRequest | PlainMessage<StartWorkspaceRequest> | undefined, b: StartWorkspaceRequest | PlainMessage<StartWorkspaceRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.StartWorkspaceResponse
 */
export declare class StartWorkspaceResponse extends Message<StartWorkspaceResponse> {
    /**
     * @generated from field: gitpod.experimental.v1.Workspace result = 1;
     */
    result?: Workspace;
    constructor(data?: PartialMessage<StartWorkspaceResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.StartWorkspaceResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): StartWorkspaceResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): StartWorkspaceResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): StartWorkspaceResponse;
    static equals(a: StartWorkspaceResponse | PlainMessage<StartWorkspaceResponse> | undefined, b: StartWorkspaceResponse | PlainMessage<StartWorkspaceResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.StopWorkspaceRequest
 */
export declare class StopWorkspaceRequest extends Message<StopWorkspaceRequest> {
    /**
     * @generated from field: string workspace_id = 1;
     */
    workspaceId: string;
    constructor(data?: PartialMessage<StopWorkspaceRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.StopWorkspaceRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): StopWorkspaceRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): StopWorkspaceRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): StopWorkspaceRequest;
    static equals(a: StopWorkspaceRequest | PlainMessage<StopWorkspaceRequest> | undefined, b: StopWorkspaceRequest | PlainMessage<StopWorkspaceRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.StopWorkspaceResponse
 */
export declare class StopWorkspaceResponse extends Message<StopWorkspaceResponse> {
    /**
     * @generated from field: gitpod.experimental.v1.Workspace result = 1;
     */
    result?: Workspace;
    constructor(data?: PartialMessage<StopWorkspaceResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.StopWorkspaceResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): StopWorkspaceResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): StopWorkspaceResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): StopWorkspaceResponse;
    static equals(a: StopWorkspaceResponse | PlainMessage<StopWorkspaceResponse> | undefined, b: StopWorkspaceResponse | PlainMessage<StopWorkspaceResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.DeleteWorkspaceRequest
 */
export declare class DeleteWorkspaceRequest extends Message<DeleteWorkspaceRequest> {
    /**
     * @generated from field: string workspace_id = 1;
     */
    workspaceId: string;
    constructor(data?: PartialMessage<DeleteWorkspaceRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.DeleteWorkspaceRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): DeleteWorkspaceRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): DeleteWorkspaceRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): DeleteWorkspaceRequest;
    static equals(a: DeleteWorkspaceRequest | PlainMessage<DeleteWorkspaceRequest> | undefined, b: DeleteWorkspaceRequest | PlainMessage<DeleteWorkspaceRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.DeleteWorkspaceResponse
 */
export declare class DeleteWorkspaceResponse extends Message<DeleteWorkspaceResponse> {
    constructor(data?: PartialMessage<DeleteWorkspaceResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.DeleteWorkspaceResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): DeleteWorkspaceResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): DeleteWorkspaceResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): DeleteWorkspaceResponse;
    static equals(a: DeleteWorkspaceResponse | PlainMessage<DeleteWorkspaceResponse> | undefined, b: DeleteWorkspaceResponse | PlainMessage<DeleteWorkspaceResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.ListWorkspaceClassesRequest
 */
export declare class ListWorkspaceClassesRequest extends Message<ListWorkspaceClassesRequest> {
    constructor(data?: PartialMessage<ListWorkspaceClassesRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.ListWorkspaceClassesRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListWorkspaceClassesRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListWorkspaceClassesRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListWorkspaceClassesRequest;
    static equals(a: ListWorkspaceClassesRequest | PlainMessage<ListWorkspaceClassesRequest> | undefined, b: ListWorkspaceClassesRequest | PlainMessage<ListWorkspaceClassesRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.ListWorkspaceClassesResponse
 */
export declare class ListWorkspaceClassesResponse extends Message<ListWorkspaceClassesResponse> {
    /**
     * @generated from field: repeated gitpod.experimental.v1.WorkspaceClass result = 1;
     */
    result: WorkspaceClass[];
    constructor(data?: PartialMessage<ListWorkspaceClassesResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.ListWorkspaceClassesResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListWorkspaceClassesResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListWorkspaceClassesResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListWorkspaceClassesResponse;
    static equals(a: ListWorkspaceClassesResponse | PlainMessage<ListWorkspaceClassesResponse> | undefined, b: ListWorkspaceClassesResponse | PlainMessage<ListWorkspaceClassesResponse> | undefined): boolean;
}
/**
 * Workspace describes a single workspace
 *
 * @generated from message gitpod.experimental.v1.Workspace
 */
export declare class Workspace extends Message<Workspace> {
    /**
     * workspace_id is the ID of the workspace
     *
     * @generated from field: string workspace_id = 1;
     */
    workspaceId: string;
    /**
     * owner_id is the ID of the user who created this workspace
     *
     * @generated from field: string owner_id = 2;
     */
    ownerId: string;
    /**
     * project_id is the ID of the project which this workspace belongs to
     *
     * @generated from field: string project_id = 3;
     */
    projectId: string;
    /**
     * context reports the original context the workspace was created from
     *
     * @generated from field: gitpod.experimental.v1.WorkspaceContext context = 4;
     */
    context?: WorkspaceContext;
    /**
     * description is a human readable description of the workspace
     *
     * @generated from field: string description = 5;
     */
    description: string;
    /**
     * status is the current status of this Workspace.
     *
     * @generated from field: gitpod.experimental.v1.WorkspaceStatus status = 6;
     */
    status?: WorkspaceStatus;
    constructor(data?: PartialMessage<Workspace>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.Workspace";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): Workspace;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): Workspace;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): Workspace;
    static equals(a: Workspace | PlainMessage<Workspace> | undefined, b: Workspace | PlainMessage<Workspace> | undefined): boolean;
}
/**
 * WorkspaceStatus represents the currently observed status of a Workspace, including data about child resources that belong to this Workspace.
 *
 * @generated from message gitpod.experimental.v1.WorkspaceStatus
 */
export declare class WorkspaceStatus extends Message<WorkspaceStatus> {
    /**
     * instance is the currently assigned WorkspaceInstance to this workspace. Empty when there is no WorkspaceInstance assigned.
     *
     * @generated from field: gitpod.experimental.v1.WorkspaceInstance instance = 1;
     */
    instance?: WorkspaceInstance;
    constructor(data?: PartialMessage<WorkspaceStatus>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.WorkspaceStatus";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceStatus;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceStatus;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceStatus;
    static equals(a: WorkspaceStatus | PlainMessage<WorkspaceStatus> | undefined, b: WorkspaceStatus | PlainMessage<WorkspaceStatus> | undefined): boolean;
}
/**
 * WorkspaceContext describes the context a workspace was created from
 *
 * @generated from message gitpod.experimental.v1.WorkspaceContext
 */
export declare class WorkspaceContext extends Message<WorkspaceContext> {
    /**
     * All workspace context originates from a URL - this is the context URL
     * which led to the creation of a workspace.
     *
     * @generated from field: string context_url = 1;
     */
    contextUrl: string;
    /**
     * @generated from oneof gitpod.experimental.v1.WorkspaceContext.details
     */
    details: {
        /**
         * @generated from field: gitpod.experimental.v1.WorkspaceContext.Git git = 2;
         */
        value: WorkspaceContext_Git;
        case: "git";
    } | {
        /**
         * @generated from field: gitpod.experimental.v1.WorkspaceContext.Prebuild prebuild = 3;
         */
        value: WorkspaceContext_Prebuild;
        case: "prebuild";
    } | {
        /**
         * @generated from field: gitpod.experimental.v1.WorkspaceContext.Snapshot snapshot = 4;
         */
        value: WorkspaceContext_Snapshot;
        case: "snapshot";
    } | {
        case: undefined;
        value?: undefined;
    };
    constructor(data?: PartialMessage<WorkspaceContext>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.WorkspaceContext";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceContext;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceContext;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceContext;
    static equals(a: WorkspaceContext | PlainMessage<WorkspaceContext> | undefined, b: WorkspaceContext | PlainMessage<WorkspaceContext> | undefined): boolean;
}
/**
 * GitProvider describes the git provider
 *
 * @generated from message gitpod.experimental.v1.WorkspaceContext.GitProvider
 */
export declare class WorkspaceContext_GitProvider extends Message<WorkspaceContext_GitProvider> {
    /**
     * type is the git provider type, e.g. 'github', 'gitlab', 'bitbucket'
     *
     * @generated from field: string type = 1;
     */
    type: string;
    /**
     * hostname is the git provider hostname
     *
     * @generated from field: string hostname = 2;
     */
    hostname: string;
    constructor(data?: PartialMessage<WorkspaceContext_GitProvider>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.WorkspaceContext.GitProvider";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceContext_GitProvider;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceContext_GitProvider;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceContext_GitProvider;
    static equals(a: WorkspaceContext_GitProvider | PlainMessage<WorkspaceContext_GitProvider> | undefined, b: WorkspaceContext_GitProvider | PlainMessage<WorkspaceContext_GitProvider> | undefined): boolean;
}
/**
 * Repository describes the originating repository
 *
 * @generated from message gitpod.experimental.v1.WorkspaceContext.Repository
 */
export declare class WorkspaceContext_Repository extends Message<WorkspaceContext_Repository> {
    /**
     * @generated from field: string name = 1;
     */
    name: string;
    /**
     * @generated from field: string owner = 2;
     */
    owner: string;
    constructor(data?: PartialMessage<WorkspaceContext_Repository>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.WorkspaceContext.Repository";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceContext_Repository;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceContext_Repository;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceContext_Repository;
    static equals(a: WorkspaceContext_Repository | PlainMessage<WorkspaceContext_Repository> | undefined, b: WorkspaceContext_Repository | PlainMessage<WorkspaceContext_Repository> | undefined): boolean;
}
/**
 * Explicit Git context
 *
 * @generated from message gitpod.experimental.v1.WorkspaceContext.Git
 */
export declare class WorkspaceContext_Git extends Message<WorkspaceContext_Git> {
    /**
     * @generated from field: string normalized_context_url = 1;
     */
    normalizedContextUrl: string;
    /**
     * @generated from field: gitpod.experimental.v1.WorkspaceContext.Repository repository = 2;
     */
    repository?: WorkspaceContext_Repository;
    /**
     * provider is the git provider
     *
     * @generated from field: gitpod.experimental.v1.WorkspaceContext.GitProvider provider = 3;
     */
    provider?: WorkspaceContext_GitProvider;
    constructor(data?: PartialMessage<WorkspaceContext_Git>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.WorkspaceContext.Git";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceContext_Git;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceContext_Git;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceContext_Git;
    static equals(a: WorkspaceContext_Git | PlainMessage<WorkspaceContext_Git> | undefined, b: WorkspaceContext_Git | PlainMessage<WorkspaceContext_Git> | undefined): boolean;
}
/**
 * Workspace was created from a prebuild
 *
 * @generated from message gitpod.experimental.v1.WorkspaceContext.Prebuild
 */
export declare class WorkspaceContext_Prebuild extends Message<WorkspaceContext_Prebuild> {
    /**
     * original_context is the Git context which lead to the selection
     * of a prebuild.
     *
     * @generated from field: gitpod.experimental.v1.WorkspaceContext.Git original_context = 1;
     */
    originalContext?: WorkspaceContext_Git;
    /**
     * prebuild_id is the ID of the prebuild which was used to create this workspace
     *
     * @generated from field: string prebuild_id = 2;
     */
    prebuildId: string;
    constructor(data?: PartialMessage<WorkspaceContext_Prebuild>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.WorkspaceContext.Prebuild";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceContext_Prebuild;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceContext_Prebuild;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceContext_Prebuild;
    static equals(a: WorkspaceContext_Prebuild | PlainMessage<WorkspaceContext_Prebuild> | undefined, b: WorkspaceContext_Prebuild | PlainMessage<WorkspaceContext_Prebuild> | undefined): boolean;
}
/**
 * Snapshot context points to the snapshot which the workspace was created from
 *
 * @generated from message gitpod.experimental.v1.WorkspaceContext.Snapshot
 */
export declare class WorkspaceContext_Snapshot extends Message<WorkspaceContext_Snapshot> {
    /**
     * @generated from field: string snapshot_id = 1;
     */
    snapshotId: string;
    constructor(data?: PartialMessage<WorkspaceContext_Snapshot>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.WorkspaceContext.Snapshot";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceContext_Snapshot;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceContext_Snapshot;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceContext_Snapshot;
    static equals(a: WorkspaceContext_Snapshot | PlainMessage<WorkspaceContext_Snapshot> | undefined, b: WorkspaceContext_Snapshot | PlainMessage<WorkspaceContext_Snapshot> | undefined): boolean;
}
/**
 * WorkspaceInstance describes a single workspace instance
 *
 * @generated from message gitpod.experimental.v1.WorkspaceInstance
 */
export declare class WorkspaceInstance extends Message<WorkspaceInstance> {
    /**
     * Instance ID is the unique identifier of the workspace instance
     *
     * @generated from field: string instance_id = 1;
     */
    instanceId: string;
    /**
     * Workspace ID is the unique identifier of the workspace this instance belongs to
     *
     * @generated from field: string workspace_id = 2;
     */
    workspaceId: string;
    /**
     * @generated from field: google.protobuf.Timestamp created_at = 3;
     */
    createdAt?: Timestamp;
    /**
     * @generated from field: gitpod.experimental.v1.WorkspaceInstanceStatus status = 4;
     */
    status?: WorkspaceInstanceStatus;
    constructor(data?: PartialMessage<WorkspaceInstance>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.WorkspaceInstance";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceInstance;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceInstance;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceInstance;
    static equals(a: WorkspaceInstance | PlainMessage<WorkspaceInstance> | undefined, b: WorkspaceInstance | PlainMessage<WorkspaceInstance> | undefined): boolean;
}
/**
 * WorkspaceStatus describes a workspace status
 *
 * @generated from message gitpod.experimental.v1.WorkspaceInstanceStatus
 */
export declare class WorkspaceInstanceStatus extends Message<WorkspaceInstanceStatus> {
    /**
     * version of the status update. Workspace instances themselves are unversioned,
     * but their statuus has different versions.
     * The value of this field has no semantic meaning (e.g. don't interpret it as
     * as a timestemp), but it can be used to impose a partial order.
     * If a.status_version < b.status_version then a was the status before b.
     *
     * @generated from field: uint64 status_version = 1;
     */
    statusVersion: bigint;
    /**
     * the phase of a workspace is a simple, high-level summary of where the workspace instance is in its lifecycle
     *
     * @generated from field: gitpod.experimental.v1.WorkspaceInstanceStatus.Phase phase = 2;
     */
    phase: WorkspaceInstanceStatus_Phase;
    /**
     * conditions detail the current state of the workspace instance
     *
     * @generated from field: gitpod.experimental.v1.WorkspaceInstanceStatus.Conditions conditions = 3;
     */
    conditions?: WorkspaceInstanceStatus_Conditions;
    /**
     * message is an optional human-readable message detailing the current phase
     *
     * @generated from field: string message = 4;
     */
    message: string;
    /**
     * URL contains the endpoint at which the workspace instance is available
     *
     * @generated from field: string url = 5;
     */
    url: string;
    /**
     * Admission describes who can access a workspace instance and its ports.
     *
     * @generated from field: gitpod.experimental.v1.AdmissionLevel admission = 6;
     */
    admission: AdmissionLevel;
    /**
     * ports is the list of exposed ports in the workspace.
     *
     * @generated from field: repeated gitpod.experimental.v1.Port ports = 7;
     */
    ports: Port[];
    /**
     * recent_folders is the opened folders inside the workspace. Used to determine the folder path to load the workspace in.
     *
     * @generated from field: repeated string recent_folders = 8;
     */
    recentFolders: string[];
    /**
     * gitStatus details the Git working copy status of the workspace.
     * Note: this is a best-effort field and more often than not will not be present. Its absence does not
     * indicate the absence of a working copy.
     *
     * @generated from field: gitpod.experimental.v1.GitStatus git_status = 9;
     */
    gitStatus?: GitStatus;
    constructor(data?: PartialMessage<WorkspaceInstanceStatus>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.WorkspaceInstanceStatus";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceInstanceStatus;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceInstanceStatus;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceInstanceStatus;
    static equals(a: WorkspaceInstanceStatus | PlainMessage<WorkspaceInstanceStatus> | undefined, b: WorkspaceInstanceStatus | PlainMessage<WorkspaceInstanceStatus> | undefined): boolean;
}
/**
 * Phase is a simple, high-level summary of where the workspace instance is in its lifecycle.
 * The phase is not intended to be a comprehensive rollup of observations of the workspace state,
 * nor is it intended to be a comprehensive state machine.
 * (based on  https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle/#pod-phase)
 *
 * @generated from enum gitpod.experimental.v1.WorkspaceInstanceStatus.Phase
 */
export declare enum WorkspaceInstanceStatus_Phase {
    /**
     * Unknown indicates an issue within the workspace manager in that it cannot determine the actual phase of
     * a workspace. This phase is usually accompanied by an error.
     *
     * @generated from enum value: PHASE_UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * Preparing means that we haven't actually started the workspace instance just yet, but rather
     * are still preparing for launch.
     *
     * @generated from enum value: PHASE_PREPARING = 1;
     */
    PREPARING = 1,
    /**
     * ImageBuild indicates that there's an image build running for this workspace.
     *
     * @generated from enum value: PHASE_IMAGEBUILD = 2;
     */
    IMAGEBUILD = 2,
    /**
     * Pending means the workspace does not yet consume resources in the cluster, but rather is looking for
     * some space within the cluster. If for example the cluster needs to scale up to accomodate the
     * workspace, the workspace will be in Pending state until that happened.
     *
     * @generated from enum value: PHASE_PENDING = 3;
     */
    PENDING = 3,
    /**
     * Creating means the workspace is currently being created. That includes downloading the images required
     * to run the workspace over the network. The time spent in this phase varies widely and depends on the current
     * network speed, image size and cache states.
     *
     * @generated from enum value: PHASE_CREATING = 4;
     */
    CREATING = 4,
    /**
     * Initializing is the phase in which the workspace is executing the appropriate workspace initializer (e.g. Git
     * clone or backup download). After this phase one can expect the workspace to either be Running or Failed.
     *
     * @generated from enum value: PHASE_INITIALIZING = 5;
     */
    INITIALIZING = 5,
    /**
     * Running means the workspace is able to actively perform work, either by serving a user through Theia,
     * or as a headless workspace.
     *
     * @generated from enum value: PHASE_RUNNING = 6;
     */
    RUNNING = 6,
    /**
     * Interrupted is an exceptional state where the container should be running but is temporarily unavailable.
     * When in this state, we expect it to become running or stopping anytime soon.
     *
     * @generated from enum value: PHASE_INTERRUPTED = 7;
     */
    INTERRUPTED = 7,
    /**
     * Stopping means that the workspace is currently shutting down. It could go to stopped every moment.
     *
     * @generated from enum value: PHASE_STOPPING = 8;
     */
    STOPPING = 8,
    /**
     * Stopped means the workspace ended regularly because it was shut down.
     *
     * @generated from enum value: PHASE_STOPPED = 9;
     */
    STOPPED = 9
}
/**
 * Conditions gives more detailed information as to the state of the workspace. Which condition actually
 * has a value depends on the phase the workspace is in.
 *
 * @generated from message gitpod.experimental.v1.WorkspaceInstanceStatus.Conditions
 */
export declare class WorkspaceInstanceStatus_Conditions extends Message<WorkspaceInstanceStatus_Conditions> {
    /**
     * failed contains the reason the workspace failed to operate. If this field is empty, the workspace has not failed.
     * This field is filled exclusively when caused by system errors.
     *
     * @generated from field: string failed = 1;
     */
    failed: string;
    /**
     * timeout contains the reason the workspace has timed out. If this field is empty, the workspace has not timed out.
     *
     * @generated from field: string timeout = 2;
     */
    timeout: string;
    /**
     * first_user_activity is the time when MarkActive was first called on the workspace
     *
     * @generated from field: google.protobuf.Timestamp first_user_activity = 9;
     */
    firstUserActivity?: Timestamp;
    /**
     * stopped_by_request is true if the workspace was stopped using a StopWorkspace call
     *
     * @generated from field: optional bool stopped_by_request = 11;
     */
    stoppedByRequest?: boolean;
    constructor(data?: PartialMessage<WorkspaceInstanceStatus_Conditions>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.WorkspaceInstanceStatus.Conditions";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceInstanceStatus_Conditions;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceInstanceStatus_Conditions;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceInstanceStatus_Conditions;
    static equals(a: WorkspaceInstanceStatus_Conditions | PlainMessage<WorkspaceInstanceStatus_Conditions> | undefined, b: WorkspaceInstanceStatus_Conditions | PlainMessage<WorkspaceInstanceStatus_Conditions> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.Port
 */
export declare class Port extends Message<Port> {
    /**
     * port number
     *
     * @generated from field: uint64 port = 1;
     */
    port: bigint;
    /**
     * policy of this port
     *
     * @generated from field: gitpod.experimental.v1.PortPolicy policy = 2;
     */
    policy: PortPolicy;
    /**
     * url that can be used to access the port
     *
     * @generated from field: string url = 3;
     */
    url: string;
    /**
     * backend protocol of this port
     *
     * @generated from field: gitpod.experimental.v1.PortProtocol protocol = 4;
     */
    protocol: PortProtocol;
    constructor(data?: PartialMessage<Port>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.Port";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): Port;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): Port;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): Port;
    static equals(a: Port | PlainMessage<Port> | undefined, b: Port | PlainMessage<Port> | undefined): boolean;
}
/**
 * StartWorkspaceSpec influences the workspace start
 *
 * @generated from message gitpod.experimental.v1.StartWorkspaceSpec
 */
export declare class StartWorkspaceSpec extends Message<StartWorkspaceSpec> {
    /**
     * @generated from field: string workspace_class = 1;
     */
    workspaceClass: string;
    /**
     * @generated from field: gitpod.experimental.v1.IDESettings ide_settings = 2;
     */
    ideSettings?: IDESettings;
    /**
     * @generated from field: string region = 3;
     */
    region: string;
    constructor(data?: PartialMessage<StartWorkspaceSpec>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.StartWorkspaceSpec";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): StartWorkspaceSpec;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): StartWorkspaceSpec;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): StartWorkspaceSpec;
    static equals(a: StartWorkspaceSpec | PlainMessage<StartWorkspaceSpec> | undefined, b: StartWorkspaceSpec | PlainMessage<StartWorkspaceSpec> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.IDESettings
 */
export declare class IDESettings extends Message<IDESettings> {
    /**
     * @generated from field: string default_ide = 1;
     */
    defaultIde: string;
    /**
     * @generated from field: bool use_latest_version = 2;
     */
    useLatestVersion: boolean;
    constructor(data?: PartialMessage<IDESettings>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.IDESettings";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): IDESettings;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): IDESettings;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): IDESettings;
    static equals(a: IDESettings | PlainMessage<IDESettings> | undefined, b: IDESettings | PlainMessage<IDESettings> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.PortSpec
 */
export declare class PortSpec extends Message<PortSpec> {
    /**
     * port number
     *
     * @generated from field: uint64 port = 1;
     */
    port: bigint;
    /**
     * policy of this port
     *
     * @generated from field: gitpod.experimental.v1.PortPolicy policy = 2;
     */
    policy: PortPolicy;
    /**
     * backend protocol of this port
     *
     * @generated from field: gitpod.experimental.v1.PortProtocol protocol = 3;
     */
    protocol: PortProtocol;
    constructor(data?: PartialMessage<PortSpec>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.PortSpec";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): PortSpec;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): PortSpec;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): PortSpec;
    static equals(a: PortSpec | PlainMessage<PortSpec> | undefined, b: PortSpec | PlainMessage<PortSpec> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.UpdatePortRequest
 */
export declare class UpdatePortRequest extends Message<UpdatePortRequest> {
    /**
     * @generated from field: string workspace_id = 1;
     */
    workspaceId: string;
    /**
     * @generated from field: gitpod.experimental.v1.PortSpec port = 2;
     */
    port?: PortSpec;
    constructor(data?: PartialMessage<UpdatePortRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.UpdatePortRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdatePortRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdatePortRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdatePortRequest;
    static equals(a: UpdatePortRequest | PlainMessage<UpdatePortRequest> | undefined, b: UpdatePortRequest | PlainMessage<UpdatePortRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.UpdatePortResponse
 */
export declare class UpdatePortResponse extends Message<UpdatePortResponse> {
    constructor(data?: PartialMessage<UpdatePortResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.UpdatePortResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdatePortResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdatePortResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdatePortResponse;
    static equals(a: UpdatePortResponse | PlainMessage<UpdatePortResponse> | undefined, b: UpdatePortResponse | PlainMessage<UpdatePortResponse> | undefined): boolean;
}
/**
 * GitStatus describes the current working copy status, akin to a combination of "git status" and "git branch"
 *
 * @generated from message gitpod.experimental.v1.GitStatus
 */
export declare class GitStatus extends Message<GitStatus> {
    /**
     * branch is branch we're currently on
     *
     * @generated from field: string branch = 1;
     */
    branch: string;
    /**
     * latest_commit is the most recent commit on the current branch
     *
     * @generated from field: string latest_commit = 2;
     */
    latestCommit: string;
    /**
     * uncommited_files is an array of uncommitted files, possibly truncated
     *
     * @generated from field: repeated string uncommited_files = 3;
     */
    uncommitedFiles: string[];
    /**
     * the total number of uncommited files
     *
     * @generated from field: int32 total_uncommited_files = 6;
     */
    totalUncommitedFiles: number;
    /**
     * untracked_files is an array of untracked files in the workspace, possibly truncated
     *
     * @generated from field: repeated string untracked_files = 4;
     */
    untrackedFiles: string[];
    /**
     * the total number of untracked files
     *
     * @generated from field: int32 total_untracked_files = 7;
     */
    totalUntrackedFiles: number;
    /**
     * unpushed_commits is an array of unpushed changes in the workspace, possibly truncated
     *
     * @generated from field: repeated string unpushed_commits = 5;
     */
    unpushedCommits: string[];
    /**
     * the total number of unpushed changes
     *
     * @generated from field: int32 total_unpushed_commits = 8;
     */
    totalUnpushedCommits: number;
    constructor(data?: PartialMessage<GitStatus>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.GitStatus";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GitStatus;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GitStatus;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GitStatus;
    static equals(a: GitStatus | PlainMessage<GitStatus> | undefined, b: GitStatus | PlainMessage<GitStatus> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.WorkspaceClass
 */
export declare class WorkspaceClass extends Message<WorkspaceClass> {
    /**
     * id is the unique identifier of the workspace class
     *
     * @generated from field: string id = 1;
     */
    id: string;
    /**
     * display_name is the human readable name of the workspace class
     *
     * @generated from field: string display_name = 2;
     */
    displayName: string;
    /**
     * description is a human readable description of the workspace class
     *
     * @generated from field: string description = 3;
     */
    description: string;
    /**
     * is_default indicates if this workspace class is the default one
     *
     * @generated from field: bool is_default = 4;
     */
    isDefault: boolean;
    constructor(data?: PartialMessage<WorkspaceClass>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.WorkspaceClass";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceClass;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceClass;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceClass;
    static equals(a: WorkspaceClass | PlainMessage<WorkspaceClass> | undefined, b: WorkspaceClass | PlainMessage<WorkspaceClass> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.GetDefaultWorkspaceImageRequest
 */
export declare class GetDefaultWorkspaceImageRequest extends Message<GetDefaultWorkspaceImageRequest> {
    /**
     * @generated from field: optional string workspace_id = 1;
     */
    workspaceId?: string;
    constructor(data?: PartialMessage<GetDefaultWorkspaceImageRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.GetDefaultWorkspaceImageRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetDefaultWorkspaceImageRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetDefaultWorkspaceImageRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetDefaultWorkspaceImageRequest;
    static equals(a: GetDefaultWorkspaceImageRequest | PlainMessage<GetDefaultWorkspaceImageRequest> | undefined, b: GetDefaultWorkspaceImageRequest | PlainMessage<GetDefaultWorkspaceImageRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.experimental.v1.GetDefaultWorkspaceImageResponse
 */
export declare class GetDefaultWorkspaceImageResponse extends Message<GetDefaultWorkspaceImageResponse> {
    /**
     * image is the image ref
     *
     * @generated from field: string image = 1;
     */
    image: string;
    /**
     * source is the source of the image
     *
     * @generated from field: gitpod.experimental.v1.GetDefaultWorkspaceImageResponse.ImageSource source = 2;
     */
    source: GetDefaultWorkspaceImageResponse_ImageSource;
    constructor(data?: PartialMessage<GetDefaultWorkspaceImageResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.experimental.v1.GetDefaultWorkspaceImageResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetDefaultWorkspaceImageResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetDefaultWorkspaceImageResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetDefaultWorkspaceImageResponse;
    static equals(a: GetDefaultWorkspaceImageResponse | PlainMessage<GetDefaultWorkspaceImageResponse> | undefined, b: GetDefaultWorkspaceImageResponse | PlainMessage<GetDefaultWorkspaceImageResponse> | undefined): boolean;
}
/**
 * @generated from enum gitpod.experimental.v1.GetDefaultWorkspaceImageResponse.ImageSource
 */
export declare enum GetDefaultWorkspaceImageResponse_ImageSource {
    /**
     * @generated from enum value: IMAGE_SOURCE_UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * IMAGE_SOURCE_INSTALLATION means the image from Gitpod instance install config
     *
     * @generated from enum value: IMAGE_SOURCE_INSTALLATION = 1;
     */
    INSTALLATION = 1,
    /**
     * IMAGE_SOURCE_ORGANIZATION means the image from  Organization settings
     *
     * @generated from enum value: IMAGE_SOURCE_ORGANIZATION = 2;
     */
    ORGANIZATION = 2
}
//# sourceMappingURL=workspaces_pb.d.ts.map