/**
 * Copyright (c) 2024 Gitpod GmbH. All rights reserved.
 * Licensed under the GNU Affero General Public License (AGPL).
 * See License.AGPL.txt in the project root for license information.
 */
import type { BinaryReadOptions, FieldList, JsonReadOptions, JsonValue, PartialMessage, PlainMessage } from "@bufbuild/protobuf";
import { Message, proto3 } from "@bufbuild/protobuf";
import { PaginationRequest, PaginationResponse } from "./pagination_pb.js";
/**
 * @generated from enum gitpod.v1.AuthProviderType
 */
export declare enum AuthProviderType {
    /**
     * This value is not allowed.
     *
     * @generated from enum value: AUTH_PROVIDER_TYPE_UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * @generated from enum value: AUTH_PROVIDER_TYPE_GITHUB = 1;
     */
    GITHUB = 1,
    /**
     * @generated from enum value: AUTH_PROVIDER_TYPE_GITLAB = 2;
     */
    GITLAB = 2,
    /**
     * @generated from enum value: AUTH_PROVIDER_TYPE_BITBUCKET = 3;
     */
    BITBUCKET = 3,
    /**
     * @generated from enum value: AUTH_PROVIDER_TYPE_BITBUCKET_SERVER = 4;
     */
    BITBUCKET_SERVER = 4
}
/**
 * @generated from message gitpod.v1.CreateAuthProviderRequest
 */
export declare class CreateAuthProviderRequest extends Message<CreateAuthProviderRequest> {
    /**
     * @generated from oneof gitpod.v1.CreateAuthProviderRequest.owner
     */
    owner: {
        /**
         * @generated from field: string owner_id = 1;
         */
        value: string;
        case: "ownerId";
    } | {
        /**
         * @generated from field: string organization_id = 2;
         */
        value: string;
        case: "organizationId";
    } | {
        case: undefined;
        value?: undefined;
    };
    /**
     * @generated from field: gitpod.v1.AuthProviderType type = 3;
     */
    type: AuthProviderType;
    /**
     * @generated from field: string host = 4;
     */
    host: string;
    /**
     * @generated from field: gitpod.v1.OAuth2Config oauth2_config = 5;
     */
    oauth2Config?: OAuth2Config;
    constructor(data?: PartialMessage<CreateAuthProviderRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.CreateAuthProviderRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): CreateAuthProviderRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): CreateAuthProviderRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): CreateAuthProviderRequest;
    static equals(a: CreateAuthProviderRequest | PlainMessage<CreateAuthProviderRequest> | undefined, b: CreateAuthProviderRequest | PlainMessage<CreateAuthProviderRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.CreateAuthProviderResponse
 */
export declare class CreateAuthProviderResponse extends Message<CreateAuthProviderResponse> {
    /**
     * @generated from field: gitpod.v1.AuthProvider auth_provider = 1;
     */
    authProvider?: AuthProvider;
    constructor(data?: PartialMessage<CreateAuthProviderResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.CreateAuthProviderResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): CreateAuthProviderResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): CreateAuthProviderResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): CreateAuthProviderResponse;
    static equals(a: CreateAuthProviderResponse | PlainMessage<CreateAuthProviderResponse> | undefined, b: CreateAuthProviderResponse | PlainMessage<CreateAuthProviderResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.GetAuthProviderRequest
 */
export declare class GetAuthProviderRequest extends Message<GetAuthProviderRequest> {
    /**
     * @generated from field: string auth_provider_id = 1;
     */
    authProviderId: string;
    constructor(data?: PartialMessage<GetAuthProviderRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.GetAuthProviderRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetAuthProviderRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetAuthProviderRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetAuthProviderRequest;
    static equals(a: GetAuthProviderRequest | PlainMessage<GetAuthProviderRequest> | undefined, b: GetAuthProviderRequest | PlainMessage<GetAuthProviderRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.GetAuthProviderResponse
 */
export declare class GetAuthProviderResponse extends Message<GetAuthProviderResponse> {
    /**
     * @generated from field: gitpod.v1.AuthProvider auth_provider = 1;
     */
    authProvider?: AuthProvider;
    constructor(data?: PartialMessage<GetAuthProviderResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.GetAuthProviderResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetAuthProviderResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetAuthProviderResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetAuthProviderResponse;
    static equals(a: GetAuthProviderResponse | PlainMessage<GetAuthProviderResponse> | undefined, b: GetAuthProviderResponse | PlainMessage<GetAuthProviderResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.ListAuthProvidersRequest
 */
export declare class ListAuthProvidersRequest extends Message<ListAuthProvidersRequest> {
    /**
     * @generated from field: gitpod.v1.PaginationRequest pagination = 1;
     */
    pagination?: PaginationRequest;
    /**
     * @generated from oneof gitpod.v1.ListAuthProvidersRequest.id
     */
    id: {
        /**
         * @generated from field: string user_id = 2;
         */
        value: string;
        case: "userId";
    } | {
        /**
         * @generated from field: string organization_id = 3;
         */
        value: string;
        case: "organizationId";
    } | {
        case: undefined;
        value?: undefined;
    };
    constructor(data?: PartialMessage<ListAuthProvidersRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.ListAuthProvidersRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListAuthProvidersRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListAuthProvidersRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListAuthProvidersRequest;
    static equals(a: ListAuthProvidersRequest | PlainMessage<ListAuthProvidersRequest> | undefined, b: ListAuthProvidersRequest | PlainMessage<ListAuthProvidersRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.ListAuthProvidersResponse
 */
export declare class ListAuthProvidersResponse extends Message<ListAuthProvidersResponse> {
    /**
     * @generated from field: repeated gitpod.v1.AuthProvider auth_providers = 1;
     */
    authProviders: AuthProvider[];
    /**
     * @generated from field: gitpod.v1.PaginationResponse pagination = 2;
     */
    pagination?: PaginationResponse;
    constructor(data?: PartialMessage<ListAuthProvidersResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.ListAuthProvidersResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListAuthProvidersResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListAuthProvidersResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListAuthProvidersResponse;
    static equals(a: ListAuthProvidersResponse | PlainMessage<ListAuthProvidersResponse> | undefined, b: ListAuthProvidersResponse | PlainMessage<ListAuthProvidersResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.ListAuthProviderDescriptionsRequest
 */
export declare class ListAuthProviderDescriptionsRequest extends Message<ListAuthProviderDescriptionsRequest> {
    /**
     * @generated from field: gitpod.v1.PaginationRequest pagination = 1;
     */
    pagination?: PaginationRequest;
    /**
     * @generated from oneof gitpod.v1.ListAuthProviderDescriptionsRequest.id
     */
    id: {
        /**
         * @generated from field: string user_id = 2;
         */
        value: string;
        case: "userId";
    } | {
        /**
         * @generated from field: string organization_id = 3;
         */
        value: string;
        case: "organizationId";
    } | {
        case: undefined;
        value?: undefined;
    };
    constructor(data?: PartialMessage<ListAuthProviderDescriptionsRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.ListAuthProviderDescriptionsRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListAuthProviderDescriptionsRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListAuthProviderDescriptionsRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListAuthProviderDescriptionsRequest;
    static equals(a: ListAuthProviderDescriptionsRequest | PlainMessage<ListAuthProviderDescriptionsRequest> | undefined, b: ListAuthProviderDescriptionsRequest | PlainMessage<ListAuthProviderDescriptionsRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.ListAuthProviderDescriptionsResponse
 */
export declare class ListAuthProviderDescriptionsResponse extends Message<ListAuthProviderDescriptionsResponse> {
    /**
     * @generated from field: repeated gitpod.v1.AuthProviderDescription descriptions = 1;
     */
    descriptions: AuthProviderDescription[];
    /**
     * @generated from field: gitpod.v1.PaginationResponse pagination = 2;
     */
    pagination?: PaginationResponse;
    constructor(data?: PartialMessage<ListAuthProviderDescriptionsResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.ListAuthProviderDescriptionsResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListAuthProviderDescriptionsResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListAuthProviderDescriptionsResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListAuthProviderDescriptionsResponse;
    static equals(a: ListAuthProviderDescriptionsResponse | PlainMessage<ListAuthProviderDescriptionsResponse> | undefined, b: ListAuthProviderDescriptionsResponse | PlainMessage<ListAuthProviderDescriptionsResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.UpdateAuthProviderRequest
 */
export declare class UpdateAuthProviderRequest extends Message<UpdateAuthProviderRequest> {
    /**
     * @generated from field: string auth_provider_id = 1;
     */
    authProviderId: string;
    /**
     * @generated from field: optional string client_id = 2;
     */
    clientId?: string;
    /**
     * @generated from field: optional string client_secret = 3;
     */
    clientSecret?: string;
    constructor(data?: PartialMessage<UpdateAuthProviderRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.UpdateAuthProviderRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdateAuthProviderRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdateAuthProviderRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdateAuthProviderRequest;
    static equals(a: UpdateAuthProviderRequest | PlainMessage<UpdateAuthProviderRequest> | undefined, b: UpdateAuthProviderRequest | PlainMessage<UpdateAuthProviderRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.UpdateAuthProviderResponse
 */
export declare class UpdateAuthProviderResponse extends Message<UpdateAuthProviderResponse> {
    /**
     * @generated from field: gitpod.v1.AuthProvider auth_provider = 1;
     */
    authProvider?: AuthProvider;
    constructor(data?: PartialMessage<UpdateAuthProviderResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.UpdateAuthProviderResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdateAuthProviderResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdateAuthProviderResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdateAuthProviderResponse;
    static equals(a: UpdateAuthProviderResponse | PlainMessage<UpdateAuthProviderResponse> | undefined, b: UpdateAuthProviderResponse | PlainMessage<UpdateAuthProviderResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.DeleteAuthProviderRequest
 */
export declare class DeleteAuthProviderRequest extends Message<DeleteAuthProviderRequest> {
    /**
     * @generated from field: string auth_provider_id = 1;
     */
    authProviderId: string;
    constructor(data?: PartialMessage<DeleteAuthProviderRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.DeleteAuthProviderRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): DeleteAuthProviderRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): DeleteAuthProviderRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): DeleteAuthProviderRequest;
    static equals(a: DeleteAuthProviderRequest | PlainMessage<DeleteAuthProviderRequest> | undefined, b: DeleteAuthProviderRequest | PlainMessage<DeleteAuthProviderRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.DeleteAuthProviderResponse
 */
export declare class DeleteAuthProviderResponse extends Message<DeleteAuthProviderResponse> {
    constructor(data?: PartialMessage<DeleteAuthProviderResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.DeleteAuthProviderResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): DeleteAuthProviderResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): DeleteAuthProviderResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): DeleteAuthProviderResponse;
    static equals(a: DeleteAuthProviderResponse | PlainMessage<DeleteAuthProviderResponse> | undefined, b: DeleteAuthProviderResponse | PlainMessage<DeleteAuthProviderResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.AuthProviderDescription
 */
export declare class AuthProviderDescription extends Message<AuthProviderDescription> {
    /**
     * @generated from field: string id = 1;
     */
    id: string;
    /**
     * @generated from field: gitpod.v1.AuthProviderType type = 4;
     */
    type: AuthProviderType;
    /**
     * @generated from field: string host = 5;
     */
    host: string;
    /**
     * @generated from field: string icon = 6;
     */
    icon: string;
    /**
     * @generated from field: string description = 7;
     */
    description: string;
    constructor(data?: PartialMessage<AuthProviderDescription>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.AuthProviderDescription";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): AuthProviderDescription;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): AuthProviderDescription;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): AuthProviderDescription;
    static equals(a: AuthProviderDescription | PlainMessage<AuthProviderDescription> | undefined, b: AuthProviderDescription | PlainMessage<AuthProviderDescription> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.AuthProvider
 */
export declare class AuthProvider extends Message<AuthProvider> {
    /**
     * @generated from field: string id = 1;
     */
    id: string;
    /**
     * @generated from oneof gitpod.v1.AuthProvider.owner
     */
    owner: {
        /**
         * @generated from field: string owner_id = 2;
         */
        value: string;
        case: "ownerId";
    } | {
        /**
         * @generated from field: string organization_id = 3;
         */
        value: string;
        case: "organizationId";
    } | {
        case: undefined;
        value?: undefined;
    };
    /**
     * @generated from field: gitpod.v1.AuthProviderType type = 4;
     */
    type: AuthProviderType;
    /**
     * @generated from field: string host = 5;
     */
    host: string;
    /**
     * @generated from field: string icon = 6;
     */
    icon: string;
    /**
     * @generated from field: string description = 7;
     */
    description: string;
    /**
     * @generated from field: string settings_url = 8;
     */
    settingsUrl: string;
    /**
     * @generated from field: bool verified = 9;
     */
    verified: boolean;
    /**
     * @generated from field: bool enable_login = 10;
     */
    enableLogin: boolean;
    /**
     * @generated from field: repeated string scopes = 11;
     */
    scopes: string[];
    /**
     * @generated from field: gitpod.v1.OAuth2Config oauth2_config = 12;
     */
    oauth2Config?: OAuth2Config;
    constructor(data?: PartialMessage<AuthProvider>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.AuthProvider";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): AuthProvider;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): AuthProvider;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): AuthProvider;
    static equals(a: AuthProvider | PlainMessage<AuthProvider> | undefined, b: AuthProvider | PlainMessage<AuthProvider> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.OAuth2Config
 */
export declare class OAuth2Config extends Message<OAuth2Config> {
    /**
     * @generated from field: string client_id = 1;
     */
    clientId: string;
    /**
     * @generated from field: string client_secret = 2;
     */
    clientSecret: string;
    constructor(data?: PartialMessage<OAuth2Config>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.OAuth2Config";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): OAuth2Config;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): OAuth2Config;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): OAuth2Config;
    static equals(a: OAuth2Config | PlainMessage<OAuth2Config> | undefined, b: OAuth2Config | PlainMessage<OAuth2Config> | undefined): boolean;
}
//# sourceMappingURL=authprovider_pb.d.ts.map