/**
 * Copyright (c) 2024 Gitpod GmbH. All rights reserved.
 * Licensed under the GNU Affero General Public License (AGPL).
 * See License.AGPL.txt in the project root for license information.
 */
import type { BinaryReadOptions, FieldList, JsonReadOptions, JsonValue, PartialMessage, PlainMessage } from "@bufbuild/protobuf";
import { Message, proto3, Timestamp } from "@bufbuild/protobuf";
import { PaginationRequest, PaginationResponse } from "./pagination_pb.js";
import { Sort } from "./sorting_pb.js";
/**
 * @generated from enum gitpod.v1.BranchMatchingStrategy
 */
export declare enum BranchMatchingStrategy {
    /**
     * @generated from enum value: BRANCH_MATCHING_STRATEGY_UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * @generated from enum value: BRANCH_MATCHING_STRATEGY_DEFAULT_BRANCH = 1;
     */
    DEFAULT_BRANCH = 1,
    /**
     * @generated from enum value: BRANCH_MATCHING_STRATEGY_ALL_BRANCHES = 2;
     */
    ALL_BRANCHES = 2,
    /**
     * @generated from enum value: BRANCH_MATCHING_STRATEGY_MATCHED_BRANCHES = 3;
     */
    MATCHED_BRANCHES = 3
}
/**
 * @generated from message gitpod.v1.Configuration
 */
export declare class Configuration extends Message<Configuration> {
    /**
     * @generated from field: string id = 1;
     */
    id: string;
    /**
     * @generated from field: string organization_id = 2;
     */
    organizationId: string;
    /**
     * @generated from field: string name = 3;
     */
    name: string;
    /**
     * @generated from field: string clone_url = 4;
     */
    cloneUrl: string;
    /**
     * @generated from field: google.protobuf.Timestamp creation_time = 5;
     */
    creationTime?: Timestamp;
    /**
     * @generated from field: gitpod.v1.PrebuildSettings prebuild_settings = 6;
     */
    prebuildSettings?: PrebuildSettings;
    /**
     * @generated from field: gitpod.v1.WorkspaceSettings workspace_settings = 7;
     */
    workspaceSettings?: WorkspaceSettings;
    constructor(data?: PartialMessage<Configuration>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.Configuration";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): Configuration;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): Configuration;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): Configuration;
    static equals(a: Configuration | PlainMessage<Configuration> | undefined, b: Configuration | PlainMessage<Configuration> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.PrebuildSettings
 */
export declare class PrebuildSettings extends Message<PrebuildSettings> {
    /**
     * @generated from field: bool enabled = 1;
     */
    enabled: boolean;
    /**
     * @generated from field: string branch_matching_pattern = 2;
     */
    branchMatchingPattern: string;
    /**
     * @generated from field: gitpod.v1.BranchMatchingStrategy branch_strategy = 3;
     */
    branchStrategy: BranchMatchingStrategy;
    /**
     * @generated from field: int32 prebuild_interval = 4;
     */
    prebuildInterval: number;
    /**
     * @generated from field: string workspace_class = 5;
     */
    workspaceClass: string;
    constructor(data?: PartialMessage<PrebuildSettings>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.PrebuildSettings";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): PrebuildSettings;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): PrebuildSettings;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): PrebuildSettings;
    static equals(a: PrebuildSettings | PlainMessage<PrebuildSettings> | undefined, b: PrebuildSettings | PlainMessage<PrebuildSettings> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.WorkspaceSettings
 */
export declare class WorkspaceSettings extends Message<WorkspaceSettings> {
    /**
     * @generated from field: string workspace_class = 1;
     */
    workspaceClass: string;
    constructor(data?: PartialMessage<WorkspaceSettings>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.WorkspaceSettings";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceSettings;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceSettings;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceSettings;
    static equals(a: WorkspaceSettings | PlainMessage<WorkspaceSettings> | undefined, b: WorkspaceSettings | PlainMessage<WorkspaceSettings> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.CreateConfigurationRequest
 */
export declare class CreateConfigurationRequest extends Message<CreateConfigurationRequest> {
    /**
     * @generated from field: string organization_id = 1;
     */
    organizationId: string;
    /**
     * @generated from field: string name = 2;
     */
    name: string;
    /**
     * @generated from field: string clone_url = 3;
     */
    cloneUrl: string;
    constructor(data?: PartialMessage<CreateConfigurationRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.CreateConfigurationRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): CreateConfigurationRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): CreateConfigurationRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): CreateConfigurationRequest;
    static equals(a: CreateConfigurationRequest | PlainMessage<CreateConfigurationRequest> | undefined, b: CreateConfigurationRequest | PlainMessage<CreateConfigurationRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.CreateConfigurationResponse
 */
export declare class CreateConfigurationResponse extends Message<CreateConfigurationResponse> {
    /**
     * @generated from field: gitpod.v1.Configuration configuration = 1;
     */
    configuration?: Configuration;
    constructor(data?: PartialMessage<CreateConfigurationResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.CreateConfigurationResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): CreateConfigurationResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): CreateConfigurationResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): CreateConfigurationResponse;
    static equals(a: CreateConfigurationResponse | PlainMessage<CreateConfigurationResponse> | undefined, b: CreateConfigurationResponse | PlainMessage<CreateConfigurationResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.GetConfigurationRequest
 */
export declare class GetConfigurationRequest extends Message<GetConfigurationRequest> {
    /**
     * @generated from field: string configuration_id = 1;
     */
    configurationId: string;
    constructor(data?: PartialMessage<GetConfigurationRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.GetConfigurationRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetConfigurationRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetConfigurationRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetConfigurationRequest;
    static equals(a: GetConfigurationRequest | PlainMessage<GetConfigurationRequest> | undefined, b: GetConfigurationRequest | PlainMessage<GetConfigurationRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.GetConfigurationResponse
 */
export declare class GetConfigurationResponse extends Message<GetConfigurationResponse> {
    /**
     * @generated from field: gitpod.v1.Configuration configuration = 1;
     */
    configuration?: Configuration;
    constructor(data?: PartialMessage<GetConfigurationResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.GetConfigurationResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetConfigurationResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetConfigurationResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetConfigurationResponse;
    static equals(a: GetConfigurationResponse | PlainMessage<GetConfigurationResponse> | undefined, b: GetConfigurationResponse | PlainMessage<GetConfigurationResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.ListConfigurationsRequest
 */
export declare class ListConfigurationsRequest extends Message<ListConfigurationsRequest> {
    /**
     * @generated from field: string organization_id = 1;
     */
    organizationId: string;
    /**
     * @generated from field: string search_term = 2;
     */
    searchTerm: string;
    /**
     * @generated from field: gitpod.v1.PaginationRequest pagination = 3;
     */
    pagination?: PaginationRequest;
    /**
     * Configurations can be sorted by "name" OR "creationTime"
     *
     * @generated from field: repeated gitpod.v1.Sort sort = 4;
     */
    sort: Sort[];
    /**
     * Will filter for configurations that have prebuilds enabled/disabled, or both if not set.
     *
     * @generated from field: optional bool prebuilds_enabled = 5;
     */
    prebuildsEnabled?: boolean;
    constructor(data?: PartialMessage<ListConfigurationsRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.ListConfigurationsRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListConfigurationsRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListConfigurationsRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListConfigurationsRequest;
    static equals(a: ListConfigurationsRequest | PlainMessage<ListConfigurationsRequest> | undefined, b: ListConfigurationsRequest | PlainMessage<ListConfigurationsRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.ListConfigurationsResponse
 */
export declare class ListConfigurationsResponse extends Message<ListConfigurationsResponse> {
    /**
     * @generated from field: repeated gitpod.v1.Configuration configurations = 1;
     */
    configurations: Configuration[];
    /**
     * @generated from field: gitpod.v1.PaginationResponse pagination = 2;
     */
    pagination?: PaginationResponse;
    constructor(data?: PartialMessage<ListConfigurationsResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.ListConfigurationsResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListConfigurationsResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListConfigurationsResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListConfigurationsResponse;
    static equals(a: ListConfigurationsResponse | PlainMessage<ListConfigurationsResponse> | undefined, b: ListConfigurationsResponse | PlainMessage<ListConfigurationsResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.UpdateConfigurationRequest
 */
export declare class UpdateConfigurationRequest extends Message<UpdateConfigurationRequest> {
    /**
     * @generated from field: string configuration_id = 1;
     */
    configurationId: string;
    /**
     * @generated from field: optional string name = 2;
     */
    name?: string;
    /**
     * @generated from field: optional gitpod.v1.UpdateConfigurationRequest.PrebuildSettings prebuild_settings = 3;
     */
    prebuildSettings?: UpdateConfigurationRequest_PrebuildSettings;
    /**
     * @generated from field: optional gitpod.v1.UpdateConfigurationRequest.WorkspaceSettings workspace_settings = 4;
     */
    workspaceSettings?: UpdateConfigurationRequest_WorkspaceSettings;
    constructor(data?: PartialMessage<UpdateConfigurationRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.UpdateConfigurationRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdateConfigurationRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdateConfigurationRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdateConfigurationRequest;
    static equals(a: UpdateConfigurationRequest | PlainMessage<UpdateConfigurationRequest> | undefined, b: UpdateConfigurationRequest | PlainMessage<UpdateConfigurationRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.UpdateConfigurationRequest.PrebuildSettings
 */
export declare class UpdateConfigurationRequest_PrebuildSettings extends Message<UpdateConfigurationRequest_PrebuildSettings> {
    /**
     * @generated from field: optional bool enabled = 1;
     */
    enabled?: boolean;
    /**
     * @generated from field: optional string branch_matching_pattern = 2;
     */
    branchMatchingPattern?: string;
    /**
     * @generated from field: optional gitpod.v1.BranchMatchingStrategy branch_strategy = 3;
     */
    branchStrategy?: BranchMatchingStrategy;
    /**
     * @generated from field: optional int32 prebuild_interval = 4;
     */
    prebuildInterval?: number;
    /**
     * @generated from field: optional string workspace_class = 5;
     */
    workspaceClass?: string;
    constructor(data?: PartialMessage<UpdateConfigurationRequest_PrebuildSettings>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.UpdateConfigurationRequest.PrebuildSettings";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdateConfigurationRequest_PrebuildSettings;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdateConfigurationRequest_PrebuildSettings;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdateConfigurationRequest_PrebuildSettings;
    static equals(a: UpdateConfigurationRequest_PrebuildSettings | PlainMessage<UpdateConfigurationRequest_PrebuildSettings> | undefined, b: UpdateConfigurationRequest_PrebuildSettings | PlainMessage<UpdateConfigurationRequest_PrebuildSettings> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.UpdateConfigurationRequest.WorkspaceSettings
 */
export declare class UpdateConfigurationRequest_WorkspaceSettings extends Message<UpdateConfigurationRequest_WorkspaceSettings> {
    /**
     * @generated from field: optional string workspace_class = 1;
     */
    workspaceClass?: string;
    constructor(data?: PartialMessage<UpdateConfigurationRequest_WorkspaceSettings>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.UpdateConfigurationRequest.WorkspaceSettings";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdateConfigurationRequest_WorkspaceSettings;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdateConfigurationRequest_WorkspaceSettings;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdateConfigurationRequest_WorkspaceSettings;
    static equals(a: UpdateConfigurationRequest_WorkspaceSettings | PlainMessage<UpdateConfigurationRequest_WorkspaceSettings> | undefined, b: UpdateConfigurationRequest_WorkspaceSettings | PlainMessage<UpdateConfigurationRequest_WorkspaceSettings> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.UpdateConfigurationResponse
 */
export declare class UpdateConfigurationResponse extends Message<UpdateConfigurationResponse> {
    /**
     * @generated from field: gitpod.v1.Configuration configuration = 1;
     */
    configuration?: Configuration;
    constructor(data?: PartialMessage<UpdateConfigurationResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.UpdateConfigurationResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdateConfigurationResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdateConfigurationResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdateConfigurationResponse;
    static equals(a: UpdateConfigurationResponse | PlainMessage<UpdateConfigurationResponse> | undefined, b: UpdateConfigurationResponse | PlainMessage<UpdateConfigurationResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.DeleteConfigurationRequest
 */
export declare class DeleteConfigurationRequest extends Message<DeleteConfigurationRequest> {
    /**
     * @generated from field: string configuration_id = 1;
     */
    configurationId: string;
    constructor(data?: PartialMessage<DeleteConfigurationRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.DeleteConfigurationRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): DeleteConfigurationRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): DeleteConfigurationRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): DeleteConfigurationRequest;
    static equals(a: DeleteConfigurationRequest | PlainMessage<DeleteConfigurationRequest> | undefined, b: DeleteConfigurationRequest | PlainMessage<DeleteConfigurationRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.DeleteConfigurationResponse
 */
export declare class DeleteConfigurationResponse extends Message<DeleteConfigurationResponse> {
    constructor(data?: PartialMessage<DeleteConfigurationResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.DeleteConfigurationResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): DeleteConfigurationResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): DeleteConfigurationResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): DeleteConfigurationResponse;
    static equals(a: DeleteConfigurationResponse | PlainMessage<DeleteConfigurationResponse> | undefined, b: DeleteConfigurationResponse | PlainMessage<DeleteConfigurationResponse> | undefined): boolean;
}
//# sourceMappingURL=configuration_pb.d.ts.map