/**
 * Copyright (c) 2024 Gitpod GmbH. All rights reserved.
 * Licensed under the GNU Affero General Public License (AGPL).
 * See License.AGPL.txt in the project root for license information.
 */
import type { BinaryReadOptions, FieldList, JsonReadOptions, JsonValue, PartialMessage, PlainMessage } from "@bufbuild/protobuf";
import { Message, proto3, Timestamp } from "@bufbuild/protobuf";
import { PaginationRequest, PaginationResponse } from "./pagination_pb.js";
import { WorkspaceClass } from "./workspace_pb.js";
/**
 * @generated from enum gitpod.v1.OrganizationRole
 */
export declare enum OrganizationRole {
    /**
     * @generated from enum value: ORGANIZATION_ROLE_UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * @generated from enum value: ORGANIZATION_ROLE_OWNER = 1;
     */
    OWNER = 1,
    /**
     * @generated from enum value: ORGANIZATION_ROLE_MEMBER = 2;
     */
    MEMBER = 2,
    /**
     * @generated from enum value: ORGANIZATION_ROLE_COLLABORATOR = 3;
     */
    COLLABORATOR = 3
}
/**
 * @generated from message gitpod.v1.Organization
 */
export declare class Organization extends Message<Organization> {
    /**
     * @generated from field: string id = 1;
     */
    id: string;
    /**
     * @generated from field: string name = 2;
     */
    name: string;
    /**
     * @generated from field: google.protobuf.Timestamp creation_time = 3;
     */
    creationTime?: Timestamp;
    /**
     * @generated from field: string slug = 4;
     */
    slug: string;
    constructor(data?: PartialMessage<Organization>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.Organization";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): Organization;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): Organization;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): Organization;
    static equals(a: Organization | PlainMessage<Organization> | undefined, b: Organization | PlainMessage<Organization> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.OrganizationMember
 */
export declare class OrganizationMember extends Message<OrganizationMember> {
    /**
     * @generated from field: string user_id = 1;
     */
    userId: string;
    /**
     * @generated from field: gitpod.v1.OrganizationRole role = 2;
     */
    role: OrganizationRole;
    /**
     * @generated from field: google.protobuf.Timestamp member_since = 3;
     */
    memberSince?: Timestamp;
    /**
     * @generated from field: string avatar_url = 4;
     */
    avatarUrl: string;
    /**
     * @generated from field: string full_name = 5;
     */
    fullName: string;
    /**
     * @generated from field: string email = 6;
     */
    email: string;
    /**
     * @generated from field: bool owned_by_organization = 7;
     */
    ownedByOrganization: boolean;
    constructor(data?: PartialMessage<OrganizationMember>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.OrganizationMember";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): OrganizationMember;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): OrganizationMember;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): OrganizationMember;
    static equals(a: OrganizationMember | PlainMessage<OrganizationMember> | undefined, b: OrganizationMember | PlainMessage<OrganizationMember> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.OrganizationSettings
 */
export declare class OrganizationSettings extends Message<OrganizationSettings> {
    /**
     * @generated from field: bool workspace_sharing_disabled = 1;
     */
    workspaceSharingDisabled: boolean;
    /**
     * @generated from field: string default_workspace_image = 2;
     */
    defaultWorkspaceImage: string;
    /**
     * @generated from field: repeated string allowed_workspace_classes = 3;
     */
    allowedWorkspaceClasses: string[];
    constructor(data?: PartialMessage<OrganizationSettings>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.OrganizationSettings";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): OrganizationSettings;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): OrganizationSettings;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): OrganizationSettings;
    static equals(a: OrganizationSettings | PlainMessage<OrganizationSettings> | undefined, b: OrganizationSettings | PlainMessage<OrganizationSettings> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.ListOrganizationWorkspaceClassesRequest
 */
export declare class ListOrganizationWorkspaceClassesRequest extends Message<ListOrganizationWorkspaceClassesRequest> {
    /**
     * @generated from field: gitpod.v1.PaginationRequest pagination = 1;
     */
    pagination?: PaginationRequest;
    /**
     * organization_id is the ID of the organization.
     *
     * @generated from field: string organization_id = 2;
     */
    organizationId: string;
    constructor(data?: PartialMessage<ListOrganizationWorkspaceClassesRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.ListOrganizationWorkspaceClassesRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListOrganizationWorkspaceClassesRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListOrganizationWorkspaceClassesRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListOrganizationWorkspaceClassesRequest;
    static equals(a: ListOrganizationWorkspaceClassesRequest | PlainMessage<ListOrganizationWorkspaceClassesRequest> | undefined, b: ListOrganizationWorkspaceClassesRequest | PlainMessage<ListOrganizationWorkspaceClassesRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.ListOrganizationWorkspaceClassesResponse
 */
export declare class ListOrganizationWorkspaceClassesResponse extends Message<ListOrganizationWorkspaceClassesResponse> {
    /**
     * @generated from field: gitpod.v1.PaginationResponse pagination = 1;
     */
    pagination?: PaginationResponse;
    /**
     * @generated from field: repeated gitpod.v1.WorkspaceClass workspace_classes = 2;
     */
    workspaceClasses: WorkspaceClass[];
    constructor(data?: PartialMessage<ListOrganizationWorkspaceClassesResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.ListOrganizationWorkspaceClassesResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListOrganizationWorkspaceClassesResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListOrganizationWorkspaceClassesResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListOrganizationWorkspaceClassesResponse;
    static equals(a: ListOrganizationWorkspaceClassesResponse | PlainMessage<ListOrganizationWorkspaceClassesResponse> | undefined, b: ListOrganizationWorkspaceClassesResponse | PlainMessage<ListOrganizationWorkspaceClassesResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.UpdateOrganizationRequest
 */
export declare class UpdateOrganizationRequest extends Message<UpdateOrganizationRequest> {
    /**
     * organization_id is the ID of the organization to update the settings for.
     *
     * @generated from field: string organization_id = 1;
     */
    organizationId: string;
    /**
     * name is the new name of the organization
     *
     * @generated from field: optional string name = 2;
     */
    name?: string;
    constructor(data?: PartialMessage<UpdateOrganizationRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.UpdateOrganizationRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdateOrganizationRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdateOrganizationRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdateOrganizationRequest;
    static equals(a: UpdateOrganizationRequest | PlainMessage<UpdateOrganizationRequest> | undefined, b: UpdateOrganizationRequest | PlainMessage<UpdateOrganizationRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.UpdateOrganizationResponse
 */
export declare class UpdateOrganizationResponse extends Message<UpdateOrganizationResponse> {
    /**
     * organization is the updated organization
     *
     * @generated from field: gitpod.v1.Organization organization = 1;
     */
    organization?: Organization;
    constructor(data?: PartialMessage<UpdateOrganizationResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.UpdateOrganizationResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdateOrganizationResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdateOrganizationResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdateOrganizationResponse;
    static equals(a: UpdateOrganizationResponse | PlainMessage<UpdateOrganizationResponse> | undefined, b: UpdateOrganizationResponse | PlainMessage<UpdateOrganizationResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.UpdateOrganizationSettingsRequest
 */
export declare class UpdateOrganizationSettingsRequest extends Message<UpdateOrganizationSettingsRequest> {
    /**
     * organization_id is the ID of the organization to update the settings for.
     *
     * @generated from field: string organization_id = 1;
     */
    organizationId: string;
    /**
     * @generated from field: optional bool workspace_sharing_disabled = 3;
     */
    workspaceSharingDisabled?: boolean;
    /**
     * pass empty string to reset to the installation default workspace image
     *
     * @generated from field: optional string default_workspace_image = 4;
     */
    defaultWorkspaceImage?: string;
    /**
     * allowed_workspace_classes are the IDs of classes, which can be used by workspaces in an organization.
     * Pass an empty array to allow all workspace classes
     *
     * @generated from field: repeated string allowed_workspace_classes = 5;
     */
    allowedWorkspaceClasses: string[];
    constructor(data?: PartialMessage<UpdateOrganizationSettingsRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.UpdateOrganizationSettingsRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdateOrganizationSettingsRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdateOrganizationSettingsRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdateOrganizationSettingsRequest;
    static equals(a: UpdateOrganizationSettingsRequest | PlainMessage<UpdateOrganizationSettingsRequest> | undefined, b: UpdateOrganizationSettingsRequest | PlainMessage<UpdateOrganizationSettingsRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.UpdateOrganizationSettingsResponse
 */
export declare class UpdateOrganizationSettingsResponse extends Message<UpdateOrganizationSettingsResponse> {
    /**
     * settings are the updated settings
     *
     * @generated from field: gitpod.v1.OrganizationSettings settings = 1;
     */
    settings?: OrganizationSettings;
    constructor(data?: PartialMessage<UpdateOrganizationSettingsResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.UpdateOrganizationSettingsResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdateOrganizationSettingsResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdateOrganizationSettingsResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdateOrganizationSettingsResponse;
    static equals(a: UpdateOrganizationSettingsResponse | PlainMessage<UpdateOrganizationSettingsResponse> | undefined, b: UpdateOrganizationSettingsResponse | PlainMessage<UpdateOrganizationSettingsResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.GetOrganizationSettingsRequest
 */
export declare class GetOrganizationSettingsRequest extends Message<GetOrganizationSettingsRequest> {
    /**
     * organization_id is the ID of the organization to retrieve the settings for.
     *
     * @generated from field: string organization_id = 1;
     */
    organizationId: string;
    constructor(data?: PartialMessage<GetOrganizationSettingsRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.GetOrganizationSettingsRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetOrganizationSettingsRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetOrganizationSettingsRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetOrganizationSettingsRequest;
    static equals(a: GetOrganizationSettingsRequest | PlainMessage<GetOrganizationSettingsRequest> | undefined, b: GetOrganizationSettingsRequest | PlainMessage<GetOrganizationSettingsRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.GetOrganizationSettingsResponse
 */
export declare class GetOrganizationSettingsResponse extends Message<GetOrganizationSettingsResponse> {
    /**
     * settings are the settings of the organization
     *
     * @generated from field: gitpod.v1.OrganizationSettings settings = 1;
     */
    settings?: OrganizationSettings;
    constructor(data?: PartialMessage<GetOrganizationSettingsResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.GetOrganizationSettingsResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetOrganizationSettingsResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetOrganizationSettingsResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetOrganizationSettingsResponse;
    static equals(a: GetOrganizationSettingsResponse | PlainMessage<GetOrganizationSettingsResponse> | undefined, b: GetOrganizationSettingsResponse | PlainMessage<GetOrganizationSettingsResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.CreateOrganizationRequest
 */
export declare class CreateOrganizationRequest extends Message<CreateOrganizationRequest> {
    /**
     * name is the organization name
     *
     * @generated from field: string name = 1;
     */
    name: string;
    constructor(data?: PartialMessage<CreateOrganizationRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.CreateOrganizationRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): CreateOrganizationRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): CreateOrganizationRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): CreateOrganizationRequest;
    static equals(a: CreateOrganizationRequest | PlainMessage<CreateOrganizationRequest> | undefined, b: CreateOrganizationRequest | PlainMessage<CreateOrganizationRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.CreateOrganizationResponse
 */
export declare class CreateOrganizationResponse extends Message<CreateOrganizationResponse> {
    /**
     * organization is the created organization
     *
     * @generated from field: gitpod.v1.Organization organization = 1;
     */
    organization?: Organization;
    constructor(data?: PartialMessage<CreateOrganizationResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.CreateOrganizationResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): CreateOrganizationResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): CreateOrganizationResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): CreateOrganizationResponse;
    static equals(a: CreateOrganizationResponse | PlainMessage<CreateOrganizationResponse> | undefined, b: CreateOrganizationResponse | PlainMessage<CreateOrganizationResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.GetOrganizationRequest
 */
export declare class GetOrganizationRequest extends Message<GetOrganizationRequest> {
    /**
     * organization_id is the unique identifier of the Organization to retreive.
     *
     * @generated from field: string organization_id = 1;
     */
    organizationId: string;
    constructor(data?: PartialMessage<GetOrganizationRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.GetOrganizationRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetOrganizationRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetOrganizationRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetOrganizationRequest;
    static equals(a: GetOrganizationRequest | PlainMessage<GetOrganizationRequest> | undefined, b: GetOrganizationRequest | PlainMessage<GetOrganizationRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.GetOrganizationResponse
 */
export declare class GetOrganizationResponse extends Message<GetOrganizationResponse> {
    /**
     * organization is the requested organization
     *
     * @generated from field: gitpod.v1.Organization organization = 1;
     */
    organization?: Organization;
    constructor(data?: PartialMessage<GetOrganizationResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.GetOrganizationResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetOrganizationResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetOrganizationResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetOrganizationResponse;
    static equals(a: GetOrganizationResponse | PlainMessage<GetOrganizationResponse> | undefined, b: GetOrganizationResponse | PlainMessage<GetOrganizationResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.ListOrganizationsRequest
 */
export declare class ListOrganizationsRequest extends Message<ListOrganizationsRequest> {
    /**
     * pagination contains the pagination options for listing organizations
     *
     * @generated from field: gitpod.v1.PaginationRequest pagination = 1;
     */
    pagination?: PaginationRequest;
    /**
     * scope is the scope of the organizations to list
     *
     * @generated from field: gitpod.v1.ListOrganizationsRequest.Scope scope = 2;
     */
    scope: ListOrganizationsRequest_Scope;
    constructor(data?: PartialMessage<ListOrganizationsRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.ListOrganizationsRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListOrganizationsRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListOrganizationsRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListOrganizationsRequest;
    static equals(a: ListOrganizationsRequest | PlainMessage<ListOrganizationsRequest> | undefined, b: ListOrganizationsRequest | PlainMessage<ListOrganizationsRequest> | undefined): boolean;
}
/**
 * @generated from enum gitpod.v1.ListOrganizationsRequest.Scope
 */
export declare enum ListOrganizationsRequest_Scope {
    /**
     * @generated from enum value: SCOPE_UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * @generated from enum value: SCOPE_MEMBER = 1;
     */
    MEMBER = 1,
    /**
     * @generated from enum value: SCOPE_ALL = 2;
     */
    ALL = 2
}
/**
 * @generated from message gitpod.v1.ListOrganizationsResponse
 */
export declare class ListOrganizationsResponse extends Message<ListOrganizationsResponse> {
    /**
     * organizations are the organizations that matched the query
     *
     * @generated from field: repeated gitpod.v1.Organization organizations = 1;
     */
    organizations: Organization[];
    /**
     * pagination contains the pagination options for listing organizations
     *
     * @generated from field: gitpod.v1.PaginationResponse pagination = 2;
     */
    pagination?: PaginationResponse;
    constructor(data?: PartialMessage<ListOrganizationsResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.ListOrganizationsResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListOrganizationsResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListOrganizationsResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListOrganizationsResponse;
    static equals(a: ListOrganizationsResponse | PlainMessage<ListOrganizationsResponse> | undefined, b: ListOrganizationsResponse | PlainMessage<ListOrganizationsResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.DeleteOrganizationRequest
 */
export declare class DeleteOrganizationRequest extends Message<DeleteOrganizationRequest> {
    /**
     * organization_id is the ID of the organization to delete
     *
     * @generated from field: string organization_id = 1;
     */
    organizationId: string;
    constructor(data?: PartialMessage<DeleteOrganizationRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.DeleteOrganizationRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): DeleteOrganizationRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): DeleteOrganizationRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): DeleteOrganizationRequest;
    static equals(a: DeleteOrganizationRequest | PlainMessage<DeleteOrganizationRequest> | undefined, b: DeleteOrganizationRequest | PlainMessage<DeleteOrganizationRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.DeleteOrganizationResponse
 */
export declare class DeleteOrganizationResponse extends Message<DeleteOrganizationResponse> {
    constructor(data?: PartialMessage<DeleteOrganizationResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.DeleteOrganizationResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): DeleteOrganizationResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): DeleteOrganizationResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): DeleteOrganizationResponse;
    static equals(a: DeleteOrganizationResponse | PlainMessage<DeleteOrganizationResponse> | undefined, b: DeleteOrganizationResponse | PlainMessage<DeleteOrganizationResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.GetOrganizationInvitationRequest
 */
export declare class GetOrganizationInvitationRequest extends Message<GetOrganizationInvitationRequest> {
    /**
     * organization_id is the ID of the organization to retrieve the invitation
     *
     * @generated from field: string organization_id = 1;
     */
    organizationId: string;
    constructor(data?: PartialMessage<GetOrganizationInvitationRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.GetOrganizationInvitationRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetOrganizationInvitationRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetOrganizationInvitationRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetOrganizationInvitationRequest;
    static equals(a: GetOrganizationInvitationRequest | PlainMessage<GetOrganizationInvitationRequest> | undefined, b: GetOrganizationInvitationRequest | PlainMessage<GetOrganizationInvitationRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.GetOrganizationInvitationResponse
 */
export declare class GetOrganizationInvitationResponse extends Message<GetOrganizationInvitationResponse> {
    /**
     * invitation_id is the invitation ID for an Organization
     *
     * @generated from field: string invitation_id = 1;
     */
    invitationId: string;
    constructor(data?: PartialMessage<GetOrganizationInvitationResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.GetOrganizationInvitationResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetOrganizationInvitationResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetOrganizationInvitationResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetOrganizationInvitationResponse;
    static equals(a: GetOrganizationInvitationResponse | PlainMessage<GetOrganizationInvitationResponse> | undefined, b: GetOrganizationInvitationResponse | PlainMessage<GetOrganizationInvitationResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.JoinOrganizationRequest
 */
export declare class JoinOrganizationRequest extends Message<JoinOrganizationRequest> {
    /**
     * invitation_id is the invitation ID for an Organization
     *
     * @generated from field: string invitation_id = 1;
     */
    invitationId: string;
    constructor(data?: PartialMessage<JoinOrganizationRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.JoinOrganizationRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): JoinOrganizationRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): JoinOrganizationRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): JoinOrganizationRequest;
    static equals(a: JoinOrganizationRequest | PlainMessage<JoinOrganizationRequest> | undefined, b: JoinOrganizationRequest | PlainMessage<JoinOrganizationRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.JoinOrganizationResponse
 */
export declare class JoinOrganizationResponse extends Message<JoinOrganizationResponse> {
    /**
     * organization_id is the id of the organization the user has just joined
     *
     * @generated from field: string organization_id = 1;
     */
    organizationId: string;
    constructor(data?: PartialMessage<JoinOrganizationResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.JoinOrganizationResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): JoinOrganizationResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): JoinOrganizationResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): JoinOrganizationResponse;
    static equals(a: JoinOrganizationResponse | PlainMessage<JoinOrganizationResponse> | undefined, b: JoinOrganizationResponse | PlainMessage<JoinOrganizationResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.ResetOrganizationInvitationRequest
 */
export declare class ResetOrganizationInvitationRequest extends Message<ResetOrganizationInvitationRequest> {
    /**
     * organization_id is the ID of the organization to reset the invitation for.
     *
     * @generated from field: string organization_id = 1;
     */
    organizationId: string;
    constructor(data?: PartialMessage<ResetOrganizationInvitationRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.ResetOrganizationInvitationRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ResetOrganizationInvitationRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ResetOrganizationInvitationRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ResetOrganizationInvitationRequest;
    static equals(a: ResetOrganizationInvitationRequest | PlainMessage<ResetOrganizationInvitationRequest> | undefined, b: ResetOrganizationInvitationRequest | PlainMessage<ResetOrganizationInvitationRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.ResetOrganizationInvitationResponse
 */
export declare class ResetOrganizationInvitationResponse extends Message<ResetOrganizationInvitationResponse> {
    /**
     * invitation_id is the new invitation id for the organization.
     *
     * @generated from field: string invitation_id = 1;
     */
    invitationId: string;
    constructor(data?: PartialMessage<ResetOrganizationInvitationResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.ResetOrganizationInvitationResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ResetOrganizationInvitationResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ResetOrganizationInvitationResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ResetOrganizationInvitationResponse;
    static equals(a: ResetOrganizationInvitationResponse | PlainMessage<ResetOrganizationInvitationResponse> | undefined, b: ResetOrganizationInvitationResponse | PlainMessage<ResetOrganizationInvitationResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.ListOrganizationMembersRequest
 */
export declare class ListOrganizationMembersRequest extends Message<ListOrganizationMembersRequest> {
    /**
     * organization_id is the ID of the organization that contains the members to
     * list
     *
     * @generated from field: string organization_id = 1;
     */
    organizationId: string;
    /**
     * @generated from field: gitpod.v1.PaginationRequest pagination = 2;
     */
    pagination?: PaginationRequest;
    constructor(data?: PartialMessage<ListOrganizationMembersRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.ListOrganizationMembersRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListOrganizationMembersRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListOrganizationMembersRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListOrganizationMembersRequest;
    static equals(a: ListOrganizationMembersRequest | PlainMessage<ListOrganizationMembersRequest> | undefined, b: ListOrganizationMembersRequest | PlainMessage<ListOrganizationMembersRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.ListOrganizationMembersResponse
 */
export declare class ListOrganizationMembersResponse extends Message<ListOrganizationMembersResponse> {
    /**
     * members are the organization members of this Organization
     *
     * @generated from field: repeated gitpod.v1.OrganizationMember members = 1;
     */
    members: OrganizationMember[];
    /**
     * @generated from field: gitpod.v1.PaginationResponse pagination = 2;
     */
    pagination?: PaginationResponse;
    constructor(data?: PartialMessage<ListOrganizationMembersResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.ListOrganizationMembersResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListOrganizationMembersResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListOrganizationMembersResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListOrganizationMembersResponse;
    static equals(a: ListOrganizationMembersResponse | PlainMessage<ListOrganizationMembersResponse> | undefined, b: ListOrganizationMembersResponse | PlainMessage<ListOrganizationMembersResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.UpdateOrganizationMemberRequest
 */
export declare class UpdateOrganizationMemberRequest extends Message<UpdateOrganizationMemberRequest> {
    /**
     * organization_id is the ID of the organization in which the role is to be
     * updated
     *
     * @generated from field: string organization_id = 1;
     */
    organizationId: string;
    /**
     * user_id is the user for which the membership shall be updated.
     *
     * @generated from field: string user_id = 2;
     */
    userId: string;
    /**
     * role is the new role for the user in the organization
     *
     * @generated from field: optional gitpod.v1.OrganizationRole role = 3;
     */
    role?: OrganizationRole;
    constructor(data?: PartialMessage<UpdateOrganizationMemberRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.UpdateOrganizationMemberRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdateOrganizationMemberRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdateOrganizationMemberRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdateOrganizationMemberRequest;
    static equals(a: UpdateOrganizationMemberRequest | PlainMessage<UpdateOrganizationMemberRequest> | undefined, b: UpdateOrganizationMemberRequest | PlainMessage<UpdateOrganizationMemberRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.UpdateOrganizationMemberResponse
 */
export declare class UpdateOrganizationMemberResponse extends Message<UpdateOrganizationMemberResponse> {
    /**
     * member is the updated organization member
     *
     * @generated from field: gitpod.v1.OrganizationMember member = 1;
     */
    member?: OrganizationMember;
    constructor(data?: PartialMessage<UpdateOrganizationMemberResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.UpdateOrganizationMemberResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdateOrganizationMemberResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdateOrganizationMemberResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdateOrganizationMemberResponse;
    static equals(a: UpdateOrganizationMemberResponse | PlainMessage<UpdateOrganizationMemberResponse> | undefined, b: UpdateOrganizationMemberResponse | PlainMessage<UpdateOrganizationMemberResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.DeleteOrganizationMemberRequest
 */
export declare class DeleteOrganizationMemberRequest extends Message<DeleteOrganizationMemberRequest> {
    /**
     * organization_id is the ID of the organization in which a member should be
     * deleted.
     *
     * @generated from field: string organization_id = 1;
     */
    organizationId: string;
    /**
     * user_id is the ID of the user that should be deleted from the organization.
     *
     * @generated from field: string user_id = 2;
     */
    userId: string;
    constructor(data?: PartialMessage<DeleteOrganizationMemberRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.DeleteOrganizationMemberRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): DeleteOrganizationMemberRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): DeleteOrganizationMemberRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): DeleteOrganizationMemberRequest;
    static equals(a: DeleteOrganizationMemberRequest | PlainMessage<DeleteOrganizationMemberRequest> | undefined, b: DeleteOrganizationMemberRequest | PlainMessage<DeleteOrganizationMemberRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.DeleteOrganizationMemberResponse
 */
export declare class DeleteOrganizationMemberResponse extends Message<DeleteOrganizationMemberResponse> {
    constructor(data?: PartialMessage<DeleteOrganizationMemberResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.DeleteOrganizationMemberResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): DeleteOrganizationMemberResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): DeleteOrganizationMemberResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): DeleteOrganizationMemberResponse;
    static equals(a: DeleteOrganizationMemberResponse | PlainMessage<DeleteOrganizationMemberResponse> | undefined, b: DeleteOrganizationMemberResponse | PlainMessage<DeleteOrganizationMemberResponse> | undefined): boolean;
}
//# sourceMappingURL=organization_pb.d.ts.map