/**
 * Copyright (c) 2024 Gitpod GmbH. All rights reserved.
 * Licensed under the GNU Affero General Public License (AGPL).
 * See License.AGPL.txt in the project root for license information.
 */
import { CreateAndStartWorkspaceRequest, CreateAndStartWorkspaceResponse, CreateWorkspaceSnapshotRequest, CreateWorkspaceSnapshotResponse, DeleteWorkspaceRequest, DeleteWorkspaceResponse, GetWorkspaceDefaultImageRequest, GetWorkspaceDefaultImageResponse, GetWorkspaceEditorCredentialsRequest, GetWorkspaceEditorCredentialsResponse, GetWorkspaceOwnerTokenRequest, GetWorkspaceOwnerTokenResponse, GetWorkspaceRequest, GetWorkspaceResponse, ListWorkspaceClassesRequest, ListWorkspaceClassesResponse, ListWorkspacesRequest, ListWorkspacesResponse, ParseContextURLRequest, ParseContextURLResponse, SendHeartBeatRequest, SendHeartBeatResponse, StartWorkspaceRequest, StartWorkspaceResponse, StopWorkspaceRequest, StopWorkspaceResponse, UpdateWorkspacePortRequest, UpdateWorkspacePortResponse, UpdateWorkspaceRequest, UpdateWorkspaceResponse, WaitForWorkspaceSnapshotRequest, WaitForWorkspaceSnapshotResponse, WatchWorkspaceStatusRequest, WatchWorkspaceStatusResponse } from "./workspace_pb.js";
import { MethodKind } from "@bufbuild/protobuf";
/**
 * @generated from service gitpod.v1.WorkspaceService
 */
export declare const WorkspaceService: {
    readonly typeName: "gitpod.v1.WorkspaceService";
    readonly methods: {
        /**
         * GetWorkspace returns a single workspace.
         *
         * +return NOT_FOUND User does not have access to a workspace with the given
         * ID +return NOT_FOUND Workspace does not exist
         *
         * @generated from rpc gitpod.v1.WorkspaceService.GetWorkspace
         */
        readonly getWorkspace: {
            readonly name: "GetWorkspace";
            readonly I: typeof GetWorkspaceRequest;
            readonly O: typeof GetWorkspaceResponse;
            readonly kind: MethodKind.Unary;
        };
        /**
         * WatchWorkspaceStatus watches the workspaces status changes
         *
         * workspace_id +return NOT_FOUND Workspace does not exist
         *
         * @generated from rpc gitpod.v1.WorkspaceService.WatchWorkspaceStatus
         */
        readonly watchWorkspaceStatus: {
            readonly name: "WatchWorkspaceStatus";
            readonly I: typeof WatchWorkspaceStatusRequest;
            readonly O: typeof WatchWorkspaceStatusResponse;
            readonly kind: MethodKind.ServerStreaming;
        };
        /**
         * ListWorkspaces returns a list of workspaces that match the query.
         *
         * @generated from rpc gitpod.v1.WorkspaceService.ListWorkspaces
         */
        readonly listWorkspaces: {
            readonly name: "ListWorkspaces";
            readonly I: typeof ListWorkspacesRequest;
            readonly O: typeof ListWorkspacesResponse;
            readonly kind: MethodKind.Unary;
        };
        /**
         * CreateAndStartWorkspace creates a new workspace and starts it.
         *
         * @generated from rpc gitpod.v1.WorkspaceService.CreateAndStartWorkspace
         */
        readonly createAndStartWorkspace: {
            readonly name: "CreateAndStartWorkspace";
            readonly I: typeof CreateAndStartWorkspaceRequest;
            readonly O: typeof CreateAndStartWorkspaceResponse;
            readonly kind: MethodKind.Unary;
        };
        /**
         * StartWorkspace starts an existing workspace.
         * If the specified workspace is not in stopped phase, this will return the workspace as is.
         *
         * @generated from rpc gitpod.v1.WorkspaceService.StartWorkspace
         */
        readonly startWorkspace: {
            readonly name: "StartWorkspace";
            readonly I: typeof StartWorkspaceRequest;
            readonly O: typeof StartWorkspaceResponse;
            readonly kind: MethodKind.Unary;
        };
        /**
         * UpdateWorkspace updates the workspace.
         *
         * @generated from rpc gitpod.v1.WorkspaceService.UpdateWorkspace
         */
        readonly updateWorkspace: {
            readonly name: "UpdateWorkspace";
            readonly I: typeof UpdateWorkspaceRequest;
            readonly O: typeof UpdateWorkspaceResponse;
            readonly kind: MethodKind.Unary;
        };
        /**
         * StopWorkspace stops a running workspace.
         *
         * @generated from rpc gitpod.v1.WorkspaceService.StopWorkspace
         */
        readonly stopWorkspace: {
            readonly name: "StopWorkspace";
            readonly I: typeof StopWorkspaceRequest;
            readonly O: typeof StopWorkspaceResponse;
            readonly kind: MethodKind.Unary;
        };
        /**
         * DeleteWorkspace deletes a workspace.
         * When the workspace is running, it will be stopped as well.
         * Deleted workspaces cannot be started again.
         *
         * @generated from rpc gitpod.v1.WorkspaceService.DeleteWorkspace
         */
        readonly deleteWorkspace: {
            readonly name: "DeleteWorkspace";
            readonly I: typeof DeleteWorkspaceRequest;
            readonly O: typeof DeleteWorkspaceResponse;
            readonly kind: MethodKind.Unary;
        };
        /**
         * ListWorkspaceClasses enumerates all available workspace classes.
         *
         * @generated from rpc gitpod.v1.WorkspaceService.ListWorkspaceClasses
         */
        readonly listWorkspaceClasses: {
            readonly name: "ListWorkspaceClasses";
            readonly I: typeof ListWorkspaceClassesRequest;
            readonly O: typeof ListWorkspaceClassesResponse;
            readonly kind: MethodKind.Unary;
        };
        /**
         * ParseContextURL parses a context URL and returns the workspace metadata and spec.
         * Not implemented yet.
         *
         * @generated from rpc gitpod.v1.WorkspaceService.ParseContextURL
         */
        readonly parseContextURL: {
            readonly name: "ParseContextURL";
            readonly I: typeof ParseContextURLRequest;
            readonly O: typeof ParseContextURLResponse;
            readonly kind: MethodKind.Unary;
        };
        /**
         * GetWorkspaceDefaultImage returns the default workspace image of specified
         * workspace.
         *
         * @generated from rpc gitpod.v1.WorkspaceService.GetWorkspaceDefaultImage
         */
        readonly getWorkspaceDefaultImage: {
            readonly name: "GetWorkspaceDefaultImage";
            readonly I: typeof GetWorkspaceDefaultImageRequest;
            readonly O: typeof GetWorkspaceDefaultImageResponse;
            readonly kind: MethodKind.Unary;
        };
        /**
         * SendHeartBeat sends a heartbeat to activate the workspace
         *
         * @generated from rpc gitpod.v1.WorkspaceService.SendHeartBeat
         */
        readonly sendHeartBeat: {
            readonly name: "SendHeartBeat";
            readonly I: typeof SendHeartBeatRequest;
            readonly O: typeof SendHeartBeatResponse;
            readonly kind: MethodKind.Unary;
        };
        /**
         * GetWorkspaceOwnerToken returns an owner token of workspace.
         *
         * @generated from rpc gitpod.v1.WorkspaceService.GetWorkspaceOwnerToken
         */
        readonly getWorkspaceOwnerToken: {
            readonly name: "GetWorkspaceOwnerToken";
            readonly I: typeof GetWorkspaceOwnerTokenRequest;
            readonly O: typeof GetWorkspaceOwnerTokenResponse;
            readonly kind: MethodKind.Unary;
        };
        /**
         * GetWorkspaceEditorCredentials returns an credentials that is used in editor
         * to encrypt and decrypt secrets
         *
         * @generated from rpc gitpod.v1.WorkspaceService.GetWorkspaceEditorCredentials
         */
        readonly getWorkspaceEditorCredentials: {
            readonly name: "GetWorkspaceEditorCredentials";
            readonly I: typeof GetWorkspaceEditorCredentialsRequest;
            readonly O: typeof GetWorkspaceEditorCredentialsResponse;
            readonly kind: MethodKind.Unary;
        };
        /**
         * CreateWorkspaceSnapshot creates a snapshot of the workspace that can be
         * shared with others.
         *
         * @generated from rpc gitpod.v1.WorkspaceService.CreateWorkspaceSnapshot
         */
        readonly createWorkspaceSnapshot: {
            readonly name: "CreateWorkspaceSnapshot";
            readonly I: typeof CreateWorkspaceSnapshotRequest;
            readonly O: typeof CreateWorkspaceSnapshotResponse;
            readonly kind: MethodKind.Unary;
        };
        /**
         * WaitWorkspaceSnapshot waits for the snapshot to be available or failed.
         *
         * @generated from rpc gitpod.v1.WorkspaceService.WaitForWorkspaceSnapshot
         */
        readonly waitForWorkspaceSnapshot: {
            readonly name: "WaitForWorkspaceSnapshot";
            readonly I: typeof WaitForWorkspaceSnapshotRequest;
            readonly O: typeof WaitForWorkspaceSnapshotResponse;
            readonly kind: MethodKind.Unary;
        };
        /**
         * UpdateWorkspacePort updates the port of workspace.
         *
         * @generated from rpc gitpod.v1.WorkspaceService.UpdateWorkspacePort
         */
        readonly updateWorkspacePort: {
            readonly name: "UpdateWorkspacePort";
            readonly I: typeof UpdateWorkspacePortRequest;
            readonly O: typeof UpdateWorkspacePortResponse;
            readonly kind: MethodKind.Unary;
        };
    };
};
//# sourceMappingURL=workspace_connect.d.ts.map