/**
 * Copyright (c) 2024 Gitpod GmbH. All rights reserved.
 * Licensed under the GNU Affero General Public License (AGPL).
 * See License.AGPL.txt in the project root for license information.
 */
import type { BinaryReadOptions, FieldList, JsonReadOptions, JsonValue, PartialMessage, PlainMessage } from "@bufbuild/protobuf";
import { Duration, Message, proto3, Timestamp } from "@bufbuild/protobuf";
import { PaginationRequest, PaginationResponse } from "./pagination_pb.js";
import { EditorReference } from "./editor_pb.js";
import { EnvironmentVariable } from "./envvar_pb.js";
/**
 * Admission level describes who can access a workspace instance and its ports.
 *
 * @generated from enum gitpod.v1.AdmissionLevel
 */
export declare enum AdmissionLevel {
    /**
     * @generated from enum value: ADMISSION_LEVEL_UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * ADMISSION_LEVEL_OWNER_ONLY means the workspace can only be accessed using
     * the owner token
     *
     * @generated from enum value: ADMISSION_LEVEL_OWNER_ONLY = 1;
     */
    OWNER_ONLY = 1,
    /**
     * ADMISSION_LEVEL_EVERYONE means the workspace (including ports) can be
     * accessed by everyone.
     *
     * @generated from enum value: ADMISSION_LEVEL_EVERYONE = 2;
     */
    EVERYONE = 2
}
/**
 * @generated from message gitpod.v1.UpdateWorkspacePortRequest
 */
export declare class UpdateWorkspacePortRequest extends Message<UpdateWorkspacePortRequest> {
    /**
     * workspace_id specifies the workspace to update port
     *
     * +required
     *
     * @generated from field: string workspace_id = 1;
     */
    workspaceId: string;
    /**
     * port number
     *
     * +required
     *
     * @generated from field: uint64 port = 2;
     */
    port: bigint;
    /**
     * admission controls the policy of this port
     *
     * @generated from field: optional gitpod.v1.AdmissionLevel admission = 3;
     */
    admission?: AdmissionLevel;
    /**
     * backend protocol of this port
     *
     * @generated from field: optional gitpod.v1.WorkspacePort.Protocol protocol = 4;
     */
    protocol?: WorkspacePort_Protocol;
    constructor(data?: PartialMessage<UpdateWorkspacePortRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.UpdateWorkspacePortRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdateWorkspacePortRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdateWorkspacePortRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdateWorkspacePortRequest;
    static equals(a: UpdateWorkspacePortRequest | PlainMessage<UpdateWorkspacePortRequest> | undefined, b: UpdateWorkspacePortRequest | PlainMessage<UpdateWorkspacePortRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.UpdateWorkspacePortResponse
 */
export declare class UpdateWorkspacePortResponse extends Message<UpdateWorkspacePortResponse> {
    constructor(data?: PartialMessage<UpdateWorkspacePortResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.UpdateWorkspacePortResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdateWorkspacePortResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdateWorkspacePortResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdateWorkspacePortResponse;
    static equals(a: UpdateWorkspacePortResponse | PlainMessage<UpdateWorkspacePortResponse> | undefined, b: UpdateWorkspacePortResponse | PlainMessage<UpdateWorkspacePortResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.GetWorkspaceRequest
 */
export declare class GetWorkspaceRequest extends Message<GetWorkspaceRequest> {
    /**
     * workspace_id specifies the workspace to get
     *
     * +required
     *
     * @generated from field: string workspace_id = 1;
     */
    workspaceId: string;
    constructor(data?: PartialMessage<GetWorkspaceRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.GetWorkspaceRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetWorkspaceRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetWorkspaceRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetWorkspaceRequest;
    static equals(a: GetWorkspaceRequest | PlainMessage<GetWorkspaceRequest> | undefined, b: GetWorkspaceRequest | PlainMessage<GetWorkspaceRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.GetWorkspaceResponse
 */
export declare class GetWorkspaceResponse extends Message<GetWorkspaceResponse> {
    /**
     * @generated from field: gitpod.v1.Workspace workspace = 1;
     */
    workspace?: Workspace;
    constructor(data?: PartialMessage<GetWorkspaceResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.GetWorkspaceResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetWorkspaceResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetWorkspaceResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetWorkspaceResponse;
    static equals(a: GetWorkspaceResponse | PlainMessage<GetWorkspaceResponse> | undefined, b: GetWorkspaceResponse | PlainMessage<GetWorkspaceResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.WatchWorkspaceStatusRequest
 */
export declare class WatchWorkspaceStatusRequest extends Message<WatchWorkspaceStatusRequest> {
    /**
     * workspace_id specifies the workspace to watch
     *
     * +optional if empty then watch all workspaces
     *
     * @generated from field: string workspace_id = 1;
     */
    workspaceId: string;
    constructor(data?: PartialMessage<WatchWorkspaceStatusRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.WatchWorkspaceStatusRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WatchWorkspaceStatusRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WatchWorkspaceStatusRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WatchWorkspaceStatusRequest;
    static equals(a: WatchWorkspaceStatusRequest | PlainMessage<WatchWorkspaceStatusRequest> | undefined, b: WatchWorkspaceStatusRequest | PlainMessage<WatchWorkspaceStatusRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.WatchWorkspaceStatusResponse
 */
export declare class WatchWorkspaceStatusResponse extends Message<WatchWorkspaceStatusResponse> {
    /**
     * workspace_id is the ID of the workspace that has status updated
     *
     * @generated from field: string workspace_id = 1;
     */
    workspaceId: string;
    /**
     * status is the updated status of workspace
     *
     * @generated from field: gitpod.v1.WorkspaceStatus status = 2;
     */
    status?: WorkspaceStatus;
    constructor(data?: PartialMessage<WatchWorkspaceStatusResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.WatchWorkspaceStatusResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WatchWorkspaceStatusResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WatchWorkspaceStatusResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WatchWorkspaceStatusResponse;
    static equals(a: WatchWorkspaceStatusResponse | PlainMessage<WatchWorkspaceStatusResponse> | undefined, b: WatchWorkspaceStatusResponse | PlainMessage<WatchWorkspaceStatusResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.ListWorkspacesRequest
 */
export declare class ListWorkspacesRequest extends Message<ListWorkspacesRequest> {
    /**
     * pagination contains the pagination options for listing workspaces
     *
     * @generated from field: gitpod.v1.PaginationRequest pagination = 1;
     */
    pagination?: PaginationRequest;
    /**
     * organization_id is the ID of the organization that contains the workspaces
     *
     * +required
     *
     * @generated from field: string organization_id = 2;
     */
    organizationId: string;
    /**
     * pinned indicates whether to list only pinned workspaces
     *
     * @generated from field: bool pinned = 3;
     */
    pinned: boolean;
    /**
     * search_term is a search term to filter workspaces by name
     *
     * @generated from field: string search_term = 4;
     */
    searchTerm: string;
    constructor(data?: PartialMessage<ListWorkspacesRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.ListWorkspacesRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListWorkspacesRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListWorkspacesRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListWorkspacesRequest;
    static equals(a: ListWorkspacesRequest | PlainMessage<ListWorkspacesRequest> | undefined, b: ListWorkspacesRequest | PlainMessage<ListWorkspacesRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.ListWorkspacesResponse
 */
export declare class ListWorkspacesResponse extends Message<ListWorkspacesResponse> {
    /**
     * pagination contains the pagination options for listing workspaces
     *
     * @generated from field: gitpod.v1.PaginationResponse pagination = 1;
     */
    pagination?: PaginationResponse;
    /**
     * workspaces are the workspaces that matched the query
     *
     * @generated from field: repeated gitpod.v1.Workspace workspaces = 2;
     */
    workspaces: Workspace[];
    constructor(data?: PartialMessage<ListWorkspacesResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.ListWorkspacesResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListWorkspacesResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListWorkspacesResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListWorkspacesResponse;
    static equals(a: ListWorkspacesResponse | PlainMessage<ListWorkspacesResponse> | undefined, b: ListWorkspacesResponse | PlainMessage<ListWorkspacesResponse> | undefined): boolean;
}
/**
 * Required fields:
 * - metadata.organization_id
 * - metadata.configuration_id
 *
 * @generated from message gitpod.v1.CreateAndStartWorkspaceRequest
 */
export declare class CreateAndStartWorkspaceRequest extends Message<CreateAndStartWorkspaceRequest> {
    /**
     * metadata is data associated with this workspace that's required for other parts of Gitpod to function
     *
     * @generated from field: gitpod.v1.WorkspaceMetadata metadata = 1;
     */
    metadata?: WorkspaceMetadata;
    /**
     * @generated from oneof gitpod.v1.CreateAndStartWorkspaceRequest.source
     */
    source: {
        /**
         * context_url is the URL from which the workspace is created
         *
         * @generated from field: gitpod.v1.CreateAndStartWorkspaceRequest.ContextURL context_url = 2;
         */
        value: CreateAndStartWorkspaceRequest_ContextURL;
        case: "contextUrl";
    } | {
        /**
         * spec is the configuration of the workspace that's required for the to start the workspace
         *
         * @generated from field: gitpod.v1.WorkspaceSpec spec = 3;
         */
        value: WorkspaceSpec;
        case: "spec";
    } | {
        case: undefined;
        value?: undefined;
    };
    /**
     * force_default_config indicates that the workspace should be created with
     * the default configuration instead of the configuration provided in
     * `.gitpod.yml` file
     *
     * @generated from field: bool force_default_config = 4 [deprecated = true];
     * @deprecated
     */
    forceDefaultConfig: boolean;
    constructor(data?: PartialMessage<CreateAndStartWorkspaceRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.CreateAndStartWorkspaceRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): CreateAndStartWorkspaceRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): CreateAndStartWorkspaceRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): CreateAndStartWorkspaceRequest;
    static equals(a: CreateAndStartWorkspaceRequest | PlainMessage<CreateAndStartWorkspaceRequest> | undefined, b: CreateAndStartWorkspaceRequest | PlainMessage<CreateAndStartWorkspaceRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.CreateAndStartWorkspaceRequest.ContextURL
 */
export declare class CreateAndStartWorkspaceRequest_ContextURL extends Message<CreateAndStartWorkspaceRequest_ContextURL> {
    /**
     * url is the URL from which the workspace is created
     *
     * @generated from field: string url = 1;
     */
    url: string;
    /**
     * workspace_class is the class of the workspace we ought to start
     *
     * @generated from field: string workspace_class = 2;
     */
    workspaceClass: string;
    /**
     * editor specifies the editor that will be used with this workspace.
     *
     * @generated from field: gitpod.v1.EditorReference editor = 3;
     */
    editor?: EditorReference;
    constructor(data?: PartialMessage<CreateAndStartWorkspaceRequest_ContextURL>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.CreateAndStartWorkspaceRequest.ContextURL";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): CreateAndStartWorkspaceRequest_ContextURL;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): CreateAndStartWorkspaceRequest_ContextURL;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): CreateAndStartWorkspaceRequest_ContextURL;
    static equals(a: CreateAndStartWorkspaceRequest_ContextURL | PlainMessage<CreateAndStartWorkspaceRequest_ContextURL> | undefined, b: CreateAndStartWorkspaceRequest_ContextURL | PlainMessage<CreateAndStartWorkspaceRequest_ContextURL> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.CreateAndStartWorkspaceResponse
 */
export declare class CreateAndStartWorkspaceResponse extends Message<CreateAndStartWorkspaceResponse> {
    /**
     * @generated from field: gitpod.v1.Workspace workspace = 1;
     */
    workspace?: Workspace;
    constructor(data?: PartialMessage<CreateAndStartWorkspaceResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.CreateAndStartWorkspaceResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): CreateAndStartWorkspaceResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): CreateAndStartWorkspaceResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): CreateAndStartWorkspaceResponse;
    static equals(a: CreateAndStartWorkspaceResponse | PlainMessage<CreateAndStartWorkspaceResponse> | undefined, b: CreateAndStartWorkspaceResponse | PlainMessage<CreateAndStartWorkspaceResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.StartWorkspaceRequest
 */
export declare class StartWorkspaceRequest extends Message<StartWorkspaceRequest> {
    /**
     * workspace_id specifies the workspace that is going to start
     *
     * +required
     *
     * @generated from field: string workspace_id = 1;
     */
    workspaceId: string;
    /**
     * @generated from field: bool force_default_config = 2 [deprecated = true];
     * @deprecated
     */
    forceDefaultConfig: boolean;
    constructor(data?: PartialMessage<StartWorkspaceRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.StartWorkspaceRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): StartWorkspaceRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): StartWorkspaceRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): StartWorkspaceRequest;
    static equals(a: StartWorkspaceRequest | PlainMessage<StartWorkspaceRequest> | undefined, b: StartWorkspaceRequest | PlainMessage<StartWorkspaceRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.StartWorkspaceResponse
 */
export declare class StartWorkspaceResponse extends Message<StartWorkspaceResponse> {
    /**
     * @generated from field: gitpod.v1.Workspace workspace = 1;
     */
    workspace?: Workspace;
    constructor(data?: PartialMessage<StartWorkspaceResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.StartWorkspaceResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): StartWorkspaceResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): StartWorkspaceResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): StartWorkspaceResponse;
    static equals(a: StartWorkspaceResponse | PlainMessage<StartWorkspaceResponse> | undefined, b: StartWorkspaceResponse | PlainMessage<StartWorkspaceResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.GetWorkspaceDefaultImageRequest
 */
export declare class GetWorkspaceDefaultImageRequest extends Message<GetWorkspaceDefaultImageRequest> {
    /**
     * workspace_id specifies the workspace to get default image
     *
     * @generated from field: string workspace_id = 1;
     */
    workspaceId: string;
    constructor(data?: PartialMessage<GetWorkspaceDefaultImageRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.GetWorkspaceDefaultImageRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetWorkspaceDefaultImageRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetWorkspaceDefaultImageRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetWorkspaceDefaultImageRequest;
    static equals(a: GetWorkspaceDefaultImageRequest | PlainMessage<GetWorkspaceDefaultImageRequest> | undefined, b: GetWorkspaceDefaultImageRequest | PlainMessage<GetWorkspaceDefaultImageRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.GetWorkspaceDefaultImageResponse
 */
export declare class GetWorkspaceDefaultImageResponse extends Message<GetWorkspaceDefaultImageResponse> {
    /**
     * @generated from field: string default_workspace_image = 1;
     */
    defaultWorkspaceImage: string;
    /**
     * @generated from field: gitpod.v1.GetWorkspaceDefaultImageResponse.Source source = 2;
     */
    source: GetWorkspaceDefaultImageResponse_Source;
    constructor(data?: PartialMessage<GetWorkspaceDefaultImageResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.GetWorkspaceDefaultImageResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetWorkspaceDefaultImageResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetWorkspaceDefaultImageResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetWorkspaceDefaultImageResponse;
    static equals(a: GetWorkspaceDefaultImageResponse | PlainMessage<GetWorkspaceDefaultImageResponse> | undefined, b: GetWorkspaceDefaultImageResponse | PlainMessage<GetWorkspaceDefaultImageResponse> | undefined): boolean;
}
/**
 * @generated from enum gitpod.v1.GetWorkspaceDefaultImageResponse.Source
 */
export declare enum GetWorkspaceDefaultImageResponse_Source {
    /**
     * @generated from enum value: SOURCE_UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * @generated from enum value: SOURCE_INSTALLATION = 1;
     */
    INSTALLATION = 1,
    /**
     * @generated from enum value: SOURCE_ORGANIZATION = 2;
     */
    ORGANIZATION = 2
}
/**
 * @generated from message gitpod.v1.SendHeartBeatRequest
 */
export declare class SendHeartBeatRequest extends Message<SendHeartBeatRequest> {
    /**
     * workspace_id specifies the workspace to send heartbeat
     *
     * +required
     *
     * @generated from field: string workspace_id = 1;
     */
    workspaceId: string;
    /**
     * disconnected indicates if the editor connection is disconnected.
     * If set to true, the workspace will be stopped after Timeout.disconnected.
     *
     * @generated from field: bool disconnected = 2;
     */
    disconnected: boolean;
    constructor(data?: PartialMessage<SendHeartBeatRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.SendHeartBeatRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): SendHeartBeatRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): SendHeartBeatRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): SendHeartBeatRequest;
    static equals(a: SendHeartBeatRequest | PlainMessage<SendHeartBeatRequest> | undefined, b: SendHeartBeatRequest | PlainMessage<SendHeartBeatRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.SendHeartBeatResponse
 */
export declare class SendHeartBeatResponse extends Message<SendHeartBeatResponse> {
    constructor(data?: PartialMessage<SendHeartBeatResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.SendHeartBeatResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): SendHeartBeatResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): SendHeartBeatResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): SendHeartBeatResponse;
    static equals(a: SendHeartBeatResponse | PlainMessage<SendHeartBeatResponse> | undefined, b: SendHeartBeatResponse | PlainMessage<SendHeartBeatResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.GetWorkspaceOwnerTokenRequest
 */
export declare class GetWorkspaceOwnerTokenRequest extends Message<GetWorkspaceOwnerTokenRequest> {
    /**
     * @generated from field: string workspace_id = 1;
     */
    workspaceId: string;
    constructor(data?: PartialMessage<GetWorkspaceOwnerTokenRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.GetWorkspaceOwnerTokenRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetWorkspaceOwnerTokenRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetWorkspaceOwnerTokenRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetWorkspaceOwnerTokenRequest;
    static equals(a: GetWorkspaceOwnerTokenRequest | PlainMessage<GetWorkspaceOwnerTokenRequest> | undefined, b: GetWorkspaceOwnerTokenRequest | PlainMessage<GetWorkspaceOwnerTokenRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.GetWorkspaceOwnerTokenResponse
 */
export declare class GetWorkspaceOwnerTokenResponse extends Message<GetWorkspaceOwnerTokenResponse> {
    /**
     * @generated from field: string owner_token = 1;
     */
    ownerToken: string;
    constructor(data?: PartialMessage<GetWorkspaceOwnerTokenResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.GetWorkspaceOwnerTokenResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetWorkspaceOwnerTokenResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetWorkspaceOwnerTokenResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetWorkspaceOwnerTokenResponse;
    static equals(a: GetWorkspaceOwnerTokenResponse | PlainMessage<GetWorkspaceOwnerTokenResponse> | undefined, b: GetWorkspaceOwnerTokenResponse | PlainMessage<GetWorkspaceOwnerTokenResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.GetWorkspaceEditorCredentialsRequest
 */
export declare class GetWorkspaceEditorCredentialsRequest extends Message<GetWorkspaceEditorCredentialsRequest> {
    /**
     * @generated from field: string workspace_id = 1;
     */
    workspaceId: string;
    constructor(data?: PartialMessage<GetWorkspaceEditorCredentialsRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.GetWorkspaceEditorCredentialsRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetWorkspaceEditorCredentialsRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetWorkspaceEditorCredentialsRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetWorkspaceEditorCredentialsRequest;
    static equals(a: GetWorkspaceEditorCredentialsRequest | PlainMessage<GetWorkspaceEditorCredentialsRequest> | undefined, b: GetWorkspaceEditorCredentialsRequest | PlainMessage<GetWorkspaceEditorCredentialsRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.GetWorkspaceEditorCredentialsResponse
 */
export declare class GetWorkspaceEditorCredentialsResponse extends Message<GetWorkspaceEditorCredentialsResponse> {
    /**
     * @generated from field: string editor_credentials = 1;
     */
    editorCredentials: string;
    constructor(data?: PartialMessage<GetWorkspaceEditorCredentialsResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.GetWorkspaceEditorCredentialsResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GetWorkspaceEditorCredentialsResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GetWorkspaceEditorCredentialsResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GetWorkspaceEditorCredentialsResponse;
    static equals(a: GetWorkspaceEditorCredentialsResponse | PlainMessage<GetWorkspaceEditorCredentialsResponse> | undefined, b: GetWorkspaceEditorCredentialsResponse | PlainMessage<GetWorkspaceEditorCredentialsResponse> | undefined): boolean;
}
/**
 * +resource get workspace
 *
 * @generated from message gitpod.v1.Workspace
 */
export declare class Workspace extends Message<Workspace> {
    /**
     * ID is a unique identifier of this workspace. No other workspace with the same name must be managed by this workspace manager
     *
     * @generated from field: string id = 1;
     */
    id: string;
    /**
     * Metadata is data associated with this workspace that's required for other parts of Gitpod to function
     *
     * @generated from field: gitpod.v1.WorkspaceMetadata metadata = 2;
     */
    metadata?: WorkspaceMetadata;
    /**
     * Spec is the configuration of the workspace that's required for the ws-manager to start the workspace
     *
     * @generated from field: gitpod.v1.WorkspaceSpec spec = 3;
     */
    spec?: WorkspaceSpec;
    /**
     * Status is the current status of the workspace
     *
     * @generated from field: gitpod.v1.WorkspaceStatus status = 4;
     */
    status?: WorkspaceStatus;
    constructor(data?: PartialMessage<Workspace>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.Workspace";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): Workspace;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): Workspace;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): Workspace;
    static equals(a: Workspace | PlainMessage<Workspace> | undefined, b: Workspace | PlainMessage<Workspace> | undefined): boolean;
}
/**
 * WorkspaceMetadata is data associated with a workspace that's required for other parts of the system to function
 *
 * @generated from message gitpod.v1.WorkspaceMetadata
 */
export declare class WorkspaceMetadata extends Message<WorkspaceMetadata> {
    /**
     * owner_id is the ID of the Gitpod user to whom we'll bill this workspace and who we consider responsible for its content
     *
     * @generated from field: string owner_id = 1;
     */
    ownerId: string;
    /**
     * organization_id is the ID of the organization that contains the workspace
     *
     * @generated from field: string organization_id = 2;
     */
    organizationId: string;
    /**
     * configuration_id is the ID of the configuration used by this workspace
     *
     * @generated from field: string configuration_id = 3;
     */
    configurationId: string;
    /**
     * annotations are key/value pairs that gets attached to the workspace.
     * +internal - not yet implemented
     *
     * @generated from field: map<string, string> annotations = 4;
     */
    annotations: {
        [key: string]: string;
    };
    /**
     * name is the name of the workspace as specified by the user
     *
     * @generated from field: string name = 5;
     */
    name: string;
    /**
     * pinned indicates whether the workspace is pinned
     *
     * @generated from field: bool pinned = 6;
     */
    pinned: boolean;
    /**
     * original_context_url is the normalized URL from which the workspace was created
     *
     * @generated from field: string original_context_url = 7;
     */
    originalContextUrl: string;
    constructor(data?: PartialMessage<WorkspaceMetadata>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.WorkspaceMetadata";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceMetadata;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceMetadata;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceMetadata;
    static equals(a: WorkspaceMetadata | PlainMessage<WorkspaceMetadata> | undefined, b: WorkspaceMetadata | PlainMessage<WorkspaceMetadata> | undefined): boolean;
}
/**
 * WorkspaceSpec specifies the configuration of a workspace for a workspace start
 *
 * @generated from message gitpod.v1.WorkspaceSpec
 */
export declare class WorkspaceSpec extends Message<WorkspaceSpec> {
    /**
     * initializer configures how the workspace is to be initialized
     *
     * @generated from field: gitpod.v1.WorkspaceInitializer initializer = 1;
     */
    initializer?: WorkspaceInitializer;
    /**
     * Type denots the kind of workspace we ought to start
     *
     * @generated from field: gitpod.v1.WorkspaceSpec.WorkspaceType type = 2;
     */
    type: WorkspaceSpec_WorkspaceType;
    /**
     * ports is the set of ports which ought to be exposed to the internet
     *
     * @generated from field: repeated gitpod.v1.WorkspacePort ports = 3;
     */
    ports: WorkspacePort[];
    /**
     * envvars are user-defined environment variables which ought to be available in the workspace (shim'ed environment)
     *
     * @generated from field: repeated gitpod.v1.EnvironmentVariable environment_variables = 4;
     */
    environmentVariables: EnvironmentVariable[];
    /**
     * Git configures the Git user in the workspace
     *
     * @generated from field: gitpod.v1.WorkspaceSpec.GitSpec git = 5;
     */
    git?: WorkspaceSpec_GitSpec;
    /**
     * Timeout configures the workspace timeout
     *
     * @generated from field: gitpod.v1.WorkspaceSpec.Timeout timeout = 6;
     */
    timeout?: WorkspaceSpec_Timeout;
    /**
     * admission controlls who can access the workspace and its ports.
     *
     * @generated from field: gitpod.v1.AdmissionLevel admission = 7;
     */
    admission: AdmissionLevel;
    /**
     * Class denotes the class of the workspace we ought to start
     *
     * @generated from field: string class = 8;
     */
    class: string;
    /**
     * ssh_public_keys is user's uploaded ssh public keys
     *
     * @generated from field: repeated string ssh_public_keys = 9;
     */
    sshPublicKeys: string[];
    /**
     * subassembly_references is a list of workspace IDs that this workspace depends on.
     * For example:
     *   index.docker.io/gitpod-io/subassmeblies/code:latest
     *
     * @generated from field: repeated string subassembly_references = 10;
     */
    subassemblyReferences: string[];
    /**
     * last_user_activity is the time when the user last interacted with the workspace
     *
     * @generated from field: google.protobuf.Timestamp last_user_activity = 11;
     */
    lastUserActivity?: Timestamp;
    /**
     * log_url is the URL where we stream the workspace's logs to.
     * Can be changed when the workspace is PENDING or STOPPED.
     *
     * @generated from field: string log_url = 12;
     */
    logUrl: string;
    /**
     * @generated from field: gitpod.v1.EditorReference editor = 13;
     */
    editor?: EditorReference;
    constructor(data?: PartialMessage<WorkspaceSpec>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.WorkspaceSpec";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceSpec;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceSpec;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceSpec;
    static equals(a: WorkspaceSpec | PlainMessage<WorkspaceSpec> | undefined, b: WorkspaceSpec | PlainMessage<WorkspaceSpec> | undefined): boolean;
}
/**
 * WorkspaceType specifies the purpose/use of a workspace. Different workspace types are handled differently by all parts of the system.
 *
 * @generated from enum gitpod.v1.WorkspaceSpec.WorkspaceType
 */
export declare enum WorkspaceSpec_WorkspaceType {
    /**
     * @generated from enum value: WORKSPACE_TYPE_UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * Regular workspaces are your off-the-mill workspaces intended for users. They are directly user-facing and hence are most important.
     *
     * @generated from enum value: WORKSPACE_TYPE_REGULAR = 1;
     */
    REGULAR = 1,
    /**
     * Prebuild workspaces are workspaces used to pre-build the content of other workspaces. They run headless and have no direct user-interaction.
     *
     * @generated from enum value: WORKSPACE_TYPE_PREBUILD = 2;
     */
    PREBUILD = 2
}
/**
 * Timeout configures the workspace timeout
 *
 * @generated from message gitpod.v1.WorkspaceSpec.Timeout
 */
export declare class WorkspaceSpec_Timeout extends Message<WorkspaceSpec_Timeout> {
    /**
     * inacitivity is the maximum time of inactivity before the workspace is stopped or paused
     *
     * @generated from field: google.protobuf.Duration inactivity = 1;
     */
    inactivity?: Duration;
    /**
     * inacitivity is the maximum time of disconnection before the workspace is stopped or paused
     * set to zero to disable.
     *
     * @generated from field: google.protobuf.Duration disconnected = 2;
     */
    disconnected?: Duration;
    /**
     * maximum lifetime of the workspace
     *
     * @generated from field: google.protobuf.Duration maximum_lifetime = 3;
     */
    maximumLifetime?: Duration;
    constructor(data?: PartialMessage<WorkspaceSpec_Timeout>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.WorkspaceSpec.Timeout";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceSpec_Timeout;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceSpec_Timeout;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceSpec_Timeout;
    static equals(a: WorkspaceSpec_Timeout | PlainMessage<WorkspaceSpec_Timeout> | undefined, b: WorkspaceSpec_Timeout | PlainMessage<WorkspaceSpec_Timeout> | undefined): boolean;
}
/**
 * GitSpec configures the Git available within the workspace
 *
 * @generated from message gitpod.v1.WorkspaceSpec.GitSpec
 */
export declare class WorkspaceSpec_GitSpec extends Message<WorkspaceSpec_GitSpec> {
    /**
     * The Git username
     *
     * @generated from field: string username = 1;
     */
    username: string;
    /**
     * The Git email address
     *
     * @generated from field: string email = 2;
     */
    email: string;
    constructor(data?: PartialMessage<WorkspaceSpec_GitSpec>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.WorkspaceSpec.GitSpec";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceSpec_GitSpec;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceSpec_GitSpec;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceSpec_GitSpec;
    static equals(a: WorkspaceSpec_GitSpec | PlainMessage<WorkspaceSpec_GitSpec> | undefined, b: WorkspaceSpec_GitSpec | PlainMessage<WorkspaceSpec_GitSpec> | undefined): boolean;
}
/**
 * WorkspaceStatus describes a workspace status
 *
 * @generated from message gitpod.v1.WorkspaceStatus
 */
export declare class WorkspaceStatus extends Message<WorkspaceStatus> {
    /**
     * version of the status update. Workspace instances themselves are unversioned,
     * but their statuus has different versions.
     * The value of this field has no semantic meaning (e.g. don't interpret it as
     * as a timestemp), but it can be used to impose a partial order.
     * If a.status_version < b.status_version then a was the status before b.
     *
     * @generated from field: uint64 status_version = 1;
     */
    statusVersion: bigint;
    /**
     * the phase of a workspace is a simple, high-level summary of where the workspace is in its lifecycle
     *
     * @generated from field: gitpod.v1.WorkspacePhase phase = 2;
     */
    phase?: WorkspacePhase;
    /**
     * workspace_url contains the URL at which the workspace can be accessed.
     * This field is only set if the workspace is running.
     *
     * @generated from field: string workspace_url = 3;
     */
    workspaceUrl: string;
    /**
     * conditions detail the current state of the workspace
     *
     * @generated from field: gitpod.v1.WorkspaceStatus.WorkspaceConditions conditions = 4;
     */
    conditions?: WorkspaceStatus_WorkspaceConditions;
    /**
     * prebuild_result contains the result of a prebuild. Only if the workspace is
     *
     * @generated from field: gitpod.v1.WorkspaceStatus.PrebuildResult prebuild_result = 5;
     */
    prebuildResult?: WorkspaceStatus_PrebuildResult;
    /**
     * git_status details the Git working copy status of the workspace.
     * Note: this is a best-effort field and more often than not will not be present. Its absence does not
     * indicate the absence of a working copy.
     *
     * @generated from field: gitpod.v1.WorkspaceGitStatus git_status = 6;
     */
    gitStatus?: WorkspaceGitStatus;
    /**
     * instance_id is the ID of the workspace instance - do not use, interpret or rely on this field
     * unless you know what you're doing.
     *
     * @generated from field: string instance_id = 7 [deprecated = true];
     * @deprecated
     */
    instanceId: string;
    constructor(data?: PartialMessage<WorkspaceStatus>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.WorkspaceStatus";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceStatus;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceStatus;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceStatus;
    static equals(a: WorkspaceStatus | PlainMessage<WorkspaceStatus> | undefined, b: WorkspaceStatus | PlainMessage<WorkspaceStatus> | undefined): boolean;
}
/**
 * WorkspaceCondition gives more detailed information as to the state of the workspace. Which condition actually
 * has a value depends on the phase the workspace is in.
 *
 * @generated from message gitpod.v1.WorkspaceStatus.WorkspaceConditions
 */
export declare class WorkspaceStatus_WorkspaceConditions extends Message<WorkspaceStatus_WorkspaceConditions> {
    /**
     * failed contains the reason the workspace failed to operate. If this field is empty, the workspace has not failed.
     *
     * @generated from field: string failed = 1;
     */
    failed: string;
    /**
     * failed_reason contains the reason the workspace failed to operate.
     * This field is only set if the workspace has failed.
     *
     * @generated from field: gitpod.v1.WorkspaceStatus.WorkspaceConditions.FailedReason failed_reason = 2;
     */
    failedReason: WorkspaceStatus_WorkspaceConditions_FailedReason;
    /**
     * timeout contains the reason the workspace has timed out. If this field is empty, the workspace has not timed out.
     *
     * @generated from field: string timeout = 3;
     */
    timeout: string;
    constructor(data?: PartialMessage<WorkspaceStatus_WorkspaceConditions>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.WorkspaceStatus.WorkspaceConditions";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceStatus_WorkspaceConditions;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceStatus_WorkspaceConditions;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceStatus_WorkspaceConditions;
    static equals(a: WorkspaceStatus_WorkspaceConditions | PlainMessage<WorkspaceStatus_WorkspaceConditions> | undefined, b: WorkspaceStatus_WorkspaceConditions | PlainMessage<WorkspaceStatus_WorkspaceConditions> | undefined): boolean;
}
/**
 * @generated from enum gitpod.v1.WorkspaceStatus.WorkspaceConditions.FailedReason
 */
export declare enum WorkspaceStatus_WorkspaceConditions_FailedReason {
    /**
     * @generated from enum value: FAILED_REASON_UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * @generated from enum value: FAILED_REASON_CONTENT_INITIALIZATION_FAILED = 1;
     */
    CONTENT_INITIALIZATION_FAILED = 1,
    /**
     * @generated from enum value: FAILED_REASON_BACKUP_FAILED = 2;
     */
    BACKUP_FAILED = 2,
    /**
     * @generated from enum value: FAILED_REASON_IMAGE_PULL_FAILURE = 3;
     */
    IMAGE_PULL_FAILURE = 3,
    /**
     * @generated from enum value: FAILED_REASON_UNEXPECTED_TERMINATION = 4;
     */
    UNEXPECTED_TERMINATION = 4
}
/**
 * @generated from message gitpod.v1.WorkspaceStatus.PrebuildResult
 */
export declare class WorkspaceStatus_PrebuildResult extends Message<WorkspaceStatus_PrebuildResult> {
    /**
     * Snapshot points to the content of the prebuild. This string is opaque to the cluster manager,
     * and must be returned unaltered.
     *
     * @generated from field: string snapshot = 1;
     */
    snapshot: string;
    /**
     * The prebuild's error message
     *
     * @generated from field: string error_message = 2;
     */
    errorMessage: string;
    constructor(data?: PartialMessage<WorkspaceStatus_PrebuildResult>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.WorkspaceStatus.PrebuildResult";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceStatus_PrebuildResult;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceStatus_PrebuildResult;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceStatus_PrebuildResult;
    static equals(a: WorkspaceStatus_PrebuildResult | PlainMessage<WorkspaceStatus_PrebuildResult> | undefined, b: WorkspaceStatus_PrebuildResult | PlainMessage<WorkspaceStatus_PrebuildResult> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.WorkspacePort
 */
export declare class WorkspacePort extends Message<WorkspacePort> {
    /**
     * port number
     *
     * @generated from field: uint64 port = 1;
     */
    port: bigint;
    /**
     * policy of this port
     *
     * @generated from field: gitpod.v1.AdmissionLevel admission = 2;
     */
    admission: AdmissionLevel;
    /**
     * url that can be used to access the port
     *
     * @generated from field: string url = 3;
     */
    url: string;
    /**
     * backend protocol of this port
     *
     * @generated from field: gitpod.v1.WorkspacePort.Protocol protocol = 4;
     */
    protocol: WorkspacePort_Protocol;
    constructor(data?: PartialMessage<WorkspacePort>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.WorkspacePort";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspacePort;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspacePort;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspacePort;
    static equals(a: WorkspacePort | PlainMessage<WorkspacePort> | undefined, b: WorkspacePort | PlainMessage<WorkspacePort> | undefined): boolean;
}
/**
 * Protocol defines the backend protocol of port
 *
 * @generated from enum gitpod.v1.WorkspacePort.Protocol
 */
export declare enum WorkspacePort_Protocol {
    /**
     * @generated from enum value: PROTOCOL_UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * Http means the port backend is http
     *
     * @generated from enum value: PROTOCOL_HTTP = 1;
     */
    HTTP = 1,
    /**
     * Https means the port backend is https
     *
     * @generated from enum value: PROTOCOL_HTTPS = 2;
     */
    HTTPS = 2
}
/**
 * @generated from message gitpod.v1.WorkspaceGitStatus
 */
export declare class WorkspaceGitStatus extends Message<WorkspaceGitStatus> {
    /**
     * clone_url is the repository url as you would pass it to "git clone".
     * Only HTTPS clone URLs are supported.
     *
     * @generated from field: string clone_url = 1;
     */
    cloneUrl: string;
    /**
     * branch is branch we're currently on
     *
     * @generated from field: string branch = 2;
     */
    branch: string;
    /**
     * latest_commit is the most recent commit on the current branch
     *
     * @generated from field: string latest_commit = 3;
     */
    latestCommit: string;
    /**
     * uncommited_files is an array of uncommitted files, possibly truncated
     *
     * @generated from field: repeated string uncommited_files = 4;
     */
    uncommitedFiles: string[];
    /**
     * the total number of uncommited files
     *
     * @generated from field: int32 total_uncommited_files = 5;
     */
    totalUncommitedFiles: number;
    /**
     * untracked_files is an array of untracked files in the workspace, possibly
     * truncated
     *
     * @generated from field: repeated string untracked_files = 6;
     */
    untrackedFiles: string[];
    /**
     * the total number of untracked files
     *
     * @generated from field: int32 total_untracked_files = 7;
     */
    totalUntrackedFiles: number;
    /**
     * unpushed_commits is an array of unpushed changes in the workspace, possibly
     * truncated
     *
     * @generated from field: repeated string unpushed_commits = 8;
     */
    unpushedCommits: string[];
    /**
     * the total number of unpushed changes
     *
     * @generated from field: int32 total_unpushed_commits = 9;
     */
    totalUnpushedCommits: number;
    constructor(data?: PartialMessage<WorkspaceGitStatus>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.WorkspaceGitStatus";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceGitStatus;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceGitStatus;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceGitStatus;
    static equals(a: WorkspaceGitStatus | PlainMessage<WorkspaceGitStatus> | undefined, b: WorkspaceGitStatus | PlainMessage<WorkspaceGitStatus> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.WorkspacePhase
 */
export declare class WorkspacePhase extends Message<WorkspacePhase> {
    /**
     * @generated from field: gitpod.v1.WorkspacePhase.Phase name = 1;
     */
    name: WorkspacePhase_Phase;
    /**
     * @generated from field: google.protobuf.Timestamp last_transition_time = 2;
     */
    lastTransitionTime?: Timestamp;
    constructor(data?: PartialMessage<WorkspacePhase>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.WorkspacePhase";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspacePhase;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspacePhase;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspacePhase;
    static equals(a: WorkspacePhase | PlainMessage<WorkspacePhase> | undefined, b: WorkspacePhase | PlainMessage<WorkspacePhase> | undefined): boolean;
}
/**
 * @generated from enum gitpod.v1.WorkspacePhase.Phase
 */
export declare enum WorkspacePhase_Phase {
    /**
     * Unknown indicates an issue within the workspace manager in that it cannot
     * determine the actual phase of a workspace. This phase is usually
     * accompanied by an error.
     *
     * @generated from enum value: PHASE_UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * Preparing means that we haven't actually started the workspace instance
     * just yet, but rather are still preparing for launch.
     *
     * @generated from enum value: PHASE_PREPARING = 1;
     */
    PREPARING = 1,
    /**
     * ImageBuild indicates that there's an image build running for this
     * workspace.
     *
     * @generated from enum value: PHASE_IMAGEBUILD = 2;
     */
    IMAGEBUILD = 2,
    /**
     * Pending means the workspace does not yet consume resources in the
     * cluster, but rather is looking for some space within the cluster. If for
     * example the cluster needs to scale up to accomodate the workspace, the
     * workspace will be in Pending state until that happened.
     *
     * @generated from enum value: PHASE_PENDING = 3;
     */
    PENDING = 3,
    /**
     * Creating means the workspace is currently being created. That includes
     * downloading the images required to run the workspace over the network.
     * The time spent in this phase varies widely and depends on the current
     * network speed, image size and cache states.
     *
     * @generated from enum value: PHASE_CREATING = 4;
     */
    CREATING = 4,
    /**
     * Initializing is the phase in which the workspace is executing the
     * appropriate workspace initializer (e.g. Git clone or backup download).
     * After this phase one can expect the workspace to either be Running or
     * Failed.
     *
     * @generated from enum value: PHASE_INITIALIZING = 5;
     */
    INITIALIZING = 5,
    /**
     * Running means the workspace is able to actively perform work, either by
     * serving a user through Theia, or as a headless workspace.
     *
     * @generated from enum value: PHASE_RUNNING = 6;
     */
    RUNNING = 6,
    /**
     * Interrupted is an exceptional state where the container should be running
     * but is temporarily unavailable. When in this state, we expect it to
     * become running or stopping anytime soon.
     *
     * @generated from enum value: PHASE_INTERRUPTED = 7;
     */
    INTERRUPTED = 7,
    /**
     * Paused means the workspace is currently unavailable, akin to stopped,
     * but faster to wake up.
     *
     * @generated from enum value: PHASE_PAUSED = 8;
     */
    PAUSED = 8,
    /**
     * Stopping means that the workspace is currently shutting down. It could go
     * to stopped every moment.
     *
     * @generated from enum value: PHASE_STOPPING = 9;
     */
    STOPPING = 9,
    /**
     * Stopped means the workspace ended regularly because it was shut down.
     *
     * @generated from enum value: PHASE_STOPPED = 10;
     */
    STOPPED = 10
}
/**
 * WorkspaceInitializer specifies how a workspace is to be initialized
 *
 * @generated from message gitpod.v1.WorkspaceInitializer
 */
export declare class WorkspaceInitializer extends Message<WorkspaceInitializer> {
    /**
     * @generated from field: repeated gitpod.v1.WorkspaceInitializer.Spec specs = 1;
     */
    specs: WorkspaceInitializer_Spec[];
    constructor(data?: PartialMessage<WorkspaceInitializer>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.WorkspaceInitializer";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceInitializer;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceInitializer;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceInitializer;
    static equals(a: WorkspaceInitializer | PlainMessage<WorkspaceInitializer> | undefined, b: WorkspaceInitializer | PlainMessage<WorkspaceInitializer> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.WorkspaceInitializer.Spec
 */
export declare class WorkspaceInitializer_Spec extends Message<WorkspaceInitializer_Spec> {
    /**
     * @generated from oneof gitpod.v1.WorkspaceInitializer.Spec.spec
     */
    spec: {
        /**
         * @generated from field: gitpod.v1.GitInitializer git = 1;
         */
        value: GitInitializer;
        case: "git";
    } | {
        /**
         * @generated from field: gitpod.v1.SnapshotInitializer snapshot = 2;
         */
        value: SnapshotInitializer;
        case: "snapshot";
    } | {
        /**
         * @generated from field: gitpod.v1.PrebuildInitializer prebuild = 3;
         */
        value: PrebuildInitializer;
        case: "prebuild";
    } | {
        /**
         * @generated from field: gitpod.v1.FileDownloadInitializer download = 4;
         */
        value: FileDownloadInitializer;
        case: "download";
    } | {
        case: undefined;
        value?: undefined;
    };
    constructor(data?: PartialMessage<WorkspaceInitializer_Spec>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.WorkspaceInitializer.Spec";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceInitializer_Spec;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceInitializer_Spec;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceInitializer_Spec;
    static equals(a: WorkspaceInitializer_Spec | PlainMessage<WorkspaceInitializer_Spec> | undefined, b: WorkspaceInitializer_Spec | PlainMessage<WorkspaceInitializer_Spec> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.GitInitializer
 */
export declare class GitInitializer extends Message<GitInitializer> {
    /**
     * remote_uri is the Git remote origin
     *
     * @generated from field: string remote_uri = 1;
     */
    remoteUri: string;
    /**
     * upstream_Remote_uri is the fork upstream of a repository
     *
     * @generated from field: string upstream_remote_uri = 2;
     */
    upstreamRemoteUri: string;
    /**
     * the target mode determines what gets checked out
     *
     * @generated from field: gitpod.v1.GitInitializer.CloneTargetMode target_mode = 3;
     */
    targetMode: GitInitializer_CloneTargetMode;
    /**
     * the value for the clone target mode - use depends on the target mode
     *
     * @generated from field: string clone_target = 4;
     */
    cloneTarget: string;
    /**
     * a path relative to the workspace root in which the code will be checked out to
     *
     * @generated from field: string checkout_location = 5;
     */
    checkoutLocation: string;
    /**
     * config specifies the Git configuration for this workspace
     *
     * @generated from field: gitpod.v1.GitInitializer.GitConfig config = 6;
     */
    config?: GitInitializer_GitConfig;
    constructor(data?: PartialMessage<GitInitializer>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.GitInitializer";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GitInitializer;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GitInitializer;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GitInitializer;
    static equals(a: GitInitializer | PlainMessage<GitInitializer> | undefined, b: GitInitializer | PlainMessage<GitInitializer> | undefined): boolean;
}
/**
 * CloneTargetMode is the target state in which we want to leave a GitWorkspace
 *
 * @generated from enum gitpod.v1.GitInitializer.CloneTargetMode
 */
export declare enum GitInitializer_CloneTargetMode {
    /**
     * @generated from enum value: CLONE_TARGET_MODE_UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * REMOTE_HEAD has the local WS point at the remote branch head
     *
     * @generated from enum value: CLONE_TARGET_MODE_REMOTE_HEAD = 1;
     */
    REMOTE_HEAD = 1,
    /**
     * REMOTE_COMMIT has the local WS point at a specific commit
     *
     * @generated from enum value: CLONE_TARGET_MODE_REMOTE_COMMIT = 2;
     */
    REMOTE_COMMIT = 2,
    /**
     * REMOTE_BRANCH has the local WS point at a remote branch
     *
     * @generated from enum value: CLONE_TARGET_MODE_REMOTE_BRANCH = 3;
     */
    REMOTE_BRANCH = 3,
    /**
     * LOCAL_BRANCH creates a local branch in the workspace
     *
     * @generated from enum value: CLONE_TARGET_MODE_LOCAL_BRANCH = 4;
     */
    LOCAL_BRANCH = 4
}
/**
 * AuthMethod is the means of authentication used during clone
 *
 * @generated from enum gitpod.v1.GitInitializer.AuthMethod
 */
export declare enum GitInitializer_AuthMethod {
    /**
     * NO_AUTH disables authentication during clone
     *
     * @generated from enum value: AUTH_METHOD_UNSPECIFIED = 0;
     */
    UNSPECIFIED = 0,
    /**
     * BASIC_AUTH uses HTTP basic auth during clone (fails if repo is not cloned through http)
     *
     * @generated from enum value: AUTH_METHOD_BASIC_AUTH = 1;
     */
    BASIC_AUTH = 1,
    /**
     * BASIC_AUTH_OTS uses HTTP basic auth during the clone with the secrets coming from the OTS URL.
     * Fails if either the OTS download or the clone fail.
     *
     * @generated from enum value: AUTH_METHOD_BASIC_AUTH_OTS = 2;
     */
    BASIC_AUTH_OTS = 2
}
/**
 * @generated from message gitpod.v1.GitInitializer.GitConfig
 */
export declare class GitInitializer_GitConfig extends Message<GitInitializer_GitConfig> {
    /**
     * custom config values to be set on clone provided through `.gitpod.yml`
     *
     * @generated from field: map<string, string> custom_config = 1;
     */
    customConfig: {
        [key: string]: string;
    };
    /**
     * authentication method
     *
     * @generated from field: gitpod.v1.GitInitializer.AuthMethod authentication = 2;
     */
    authentication: GitInitializer_AuthMethod;
    /**
     * auth_user is the username used to authenticate the clone
     *
     * @generated from field: string auth_user = 3;
     */
    authUser: string;
    /**
     * auth_password is the password used to authenticate the clone (can also be an API token)
     *
     * @generated from field: string auth_password = 4;
     */
    authPassword: string;
    /**
     * auth_ots is a URL where one can download the authentication secret (<username>:<password>)
     * using a GET request.
     *
     * @generated from field: string auth_ots = 5;
     */
    authOts: string;
    constructor(data?: PartialMessage<GitInitializer_GitConfig>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.GitInitializer.GitConfig";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GitInitializer_GitConfig;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GitInitializer_GitConfig;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GitInitializer_GitConfig;
    static equals(a: GitInitializer_GitConfig | PlainMessage<GitInitializer_GitConfig> | undefined, b: GitInitializer_GitConfig | PlainMessage<GitInitializer_GitConfig> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.SnapshotInitializer
 */
export declare class SnapshotInitializer extends Message<SnapshotInitializer> {
    /**
     * reference of the snapshot to restore
     *
     * @generated from field: string snapshot_id = 1;
     */
    snapshotId: string;
    constructor(data?: PartialMessage<SnapshotInitializer>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.SnapshotInitializer";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): SnapshotInitializer;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): SnapshotInitializer;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): SnapshotInitializer;
    static equals(a: SnapshotInitializer | PlainMessage<SnapshotInitializer> | undefined, b: SnapshotInitializer | PlainMessage<SnapshotInitializer> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.PrebuildInitializer
 */
export declare class PrebuildInitializer extends Message<PrebuildInitializer> {
    /**
     * reference of the prebuild to restore
     *
     * @generated from field: string prebuild_id = 1;
     */
    prebuildId: string;
    constructor(data?: PartialMessage<PrebuildInitializer>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.PrebuildInitializer";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): PrebuildInitializer;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): PrebuildInitializer;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): PrebuildInitializer;
    static equals(a: PrebuildInitializer | PlainMessage<PrebuildInitializer> | undefined, b: PrebuildInitializer | PlainMessage<PrebuildInitializer> | undefined): boolean;
}
/**
 * FileDownloadInitializer downloads files and uses them as workspace content.
 *
 * @generated from message gitpod.v1.FileDownloadInitializer
 */
export declare class FileDownloadInitializer extends Message<FileDownloadInitializer> {
    /**
     * @generated from field: repeated gitpod.v1.FileDownloadInitializer.FileInfo files = 1;
     */
    files: FileDownloadInitializer_FileInfo[];
    /**
     * @generated from field: string target_location = 2;
     */
    targetLocation: string;
    constructor(data?: PartialMessage<FileDownloadInitializer>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.FileDownloadInitializer";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): FileDownloadInitializer;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): FileDownloadInitializer;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): FileDownloadInitializer;
    static equals(a: FileDownloadInitializer | PlainMessage<FileDownloadInitializer> | undefined, b: FileDownloadInitializer | PlainMessage<FileDownloadInitializer> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.FileDownloadInitializer.FileInfo
 */
export declare class FileDownloadInitializer_FileInfo extends Message<FileDownloadInitializer_FileInfo> {
    /**
     * @generated from field: string url = 1;
     */
    url: string;
    /**
     * file_path is relative to the target_location, e.g. if target_location is in `/workspace/myrepo`
     * a file_path of `foobar/file` would produce a file in `/workspace/myrepo/foobar/file`.
     * file_path must include the filename. The FileDownloadInitializer will create any parent directories
     * necessary to place the file.
     *
     * @generated from field: string file_path = 2;
     */
    filePath: string;
    /**
     * digest is a hash of the file content in the OCI digest format (see https://github.com/opencontainers/image-spec/blob/master/descriptor.md#digests).
     * This information is used to compute subsequent
     * content versions, and to validate the file content was downloaded correctly.
     *
     * @generated from field: string digest = 3;
     */
    digest: string;
    constructor(data?: PartialMessage<FileDownloadInitializer_FileInfo>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.FileDownloadInitializer.FileInfo";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): FileDownloadInitializer_FileInfo;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): FileDownloadInitializer_FileInfo;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): FileDownloadInitializer_FileInfo;
    static equals(a: FileDownloadInitializer_FileInfo | PlainMessage<FileDownloadInitializer_FileInfo> | undefined, b: FileDownloadInitializer_FileInfo | PlainMessage<FileDownloadInitializer_FileInfo> | undefined): boolean;
}
/**
 * GitStatus describes the current Git working copy status, akin to a combination of "git status" and "git branch"
 *
 * @generated from message gitpod.v1.GitStatus
 */
export declare class GitStatus extends Message<GitStatus> {
    /**
     * branch is branch we're currently on
     *
     * @generated from field: string branch = 1;
     */
    branch: string;
    /**
     * latest_commit is the most recent commit on the current branch
     *
     * @generated from field: string latest_commit = 2;
     */
    latestCommit: string;
    /**
     * uncommited_files is the number of uncommitted files, possibly truncated
     *
     * @generated from field: repeated string uncommited_files = 3;
     */
    uncommitedFiles: string[];
    /**
     * the total number of uncommited files
     *
     * @generated from field: int64 total_uncommited_files = 6;
     */
    totalUncommitedFiles: bigint;
    /**
     * untracked_files is the number of untracked files in the workspace, possibly truncated
     *
     * @generated from field: repeated string untracked_files = 4;
     */
    untrackedFiles: string[];
    /**
     * the total number of untracked files
     *
     * @generated from field: int64 total_untracked_files = 7;
     */
    totalUntrackedFiles: bigint;
    /**
     * unpushed_commits is the number of unpushed changes in the workspace, possibly truncated
     *
     * @generated from field: repeated string unpushed_commits = 5;
     */
    unpushedCommits: string[];
    /**
     * the total number of unpushed changes
     *
     * @generated from field: int64 total_unpushed_commits = 8;
     */
    totalUnpushedCommits: bigint;
    constructor(data?: PartialMessage<GitStatus>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.GitStatus";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): GitStatus;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): GitStatus;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): GitStatus;
    static equals(a: GitStatus | PlainMessage<GitStatus> | undefined, b: GitStatus | PlainMessage<GitStatus> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.UpdateWorkspaceRequest
 */
export declare class UpdateWorkspaceRequest extends Message<UpdateWorkspaceRequest> {
    /**
     * workspace_id specifies the workspace to update
     *
     * +required
     *
     * @generated from field: string workspace_id = 1;
     */
    workspaceId: string;
    /**
     * metadata is data associated with this workspace that's required for other parts of Gitpod to function
     *
     * @generated from field: optional gitpod.v1.UpdateWorkspaceRequest.UpdateWorkspaceMetadata metadata = 2;
     */
    metadata?: UpdateWorkspaceRequest_UpdateWorkspaceMetadata;
    /**
     * spec is the configuration of the workspace that's required for the ws-manager to start the workspace
     *
     * @generated from field: optional gitpod.v1.UpdateWorkspaceRequest.UpdateWorkspaceSpec spec = 3;
     */
    spec?: UpdateWorkspaceRequest_UpdateWorkspaceSpec;
    /**
     * git_status updates the git status of the workspace - this is only here during the migration
     *
     * @generated from field: optional gitpod.v1.WorkspaceGitStatus git_status = 4 [deprecated = true];
     * @deprecated
     */
    gitStatus?: WorkspaceGitStatus;
    constructor(data?: PartialMessage<UpdateWorkspaceRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.UpdateWorkspaceRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdateWorkspaceRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdateWorkspaceRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdateWorkspaceRequest;
    static equals(a: UpdateWorkspaceRequest | PlainMessage<UpdateWorkspaceRequest> | undefined, b: UpdateWorkspaceRequest | PlainMessage<UpdateWorkspaceRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.UpdateWorkspaceRequest.UpdateWorkspaceMetadata
 */
export declare class UpdateWorkspaceRequest_UpdateWorkspaceMetadata extends Message<UpdateWorkspaceRequest_UpdateWorkspaceMetadata> {
    /**
     * name is the name of the workspace as specified by the user
     *
     * @generated from field: optional string name = 1;
     */
    name?: string;
    /**
     * pinned indicates whether the workspace is pinned
     *
     * @generated from field: optional bool pinned = 2;
     */
    pinned?: boolean;
    constructor(data?: PartialMessage<UpdateWorkspaceRequest_UpdateWorkspaceMetadata>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.UpdateWorkspaceRequest.UpdateWorkspaceMetadata";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdateWorkspaceRequest_UpdateWorkspaceMetadata;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdateWorkspaceRequest_UpdateWorkspaceMetadata;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdateWorkspaceRequest_UpdateWorkspaceMetadata;
    static equals(a: UpdateWorkspaceRequest_UpdateWorkspaceMetadata | PlainMessage<UpdateWorkspaceRequest_UpdateWorkspaceMetadata> | undefined, b: UpdateWorkspaceRequest_UpdateWorkspaceMetadata | PlainMessage<UpdateWorkspaceRequest_UpdateWorkspaceMetadata> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.UpdateWorkspaceRequest.UpdateTimeout
 */
export declare class UpdateWorkspaceRequest_UpdateTimeout extends Message<UpdateWorkspaceRequest_UpdateTimeout> {
    /**
     * inacitivity is the maximum time of inactivity before the workspace is stopped or paused
     *
     * @generated from field: optional google.protobuf.Duration inactivity = 1;
     */
    inactivity?: Duration;
    /**
     * inacitivity is the maximum time of disconnection before the workspace is stopped or paused
     *
     * @generated from field: optional google.protobuf.Duration disconnected = 2;
     */
    disconnected?: Duration;
    constructor(data?: PartialMessage<UpdateWorkspaceRequest_UpdateTimeout>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.UpdateWorkspaceRequest.UpdateTimeout";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdateWorkspaceRequest_UpdateTimeout;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdateWorkspaceRequest_UpdateTimeout;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdateWorkspaceRequest_UpdateTimeout;
    static equals(a: UpdateWorkspaceRequest_UpdateTimeout | PlainMessage<UpdateWorkspaceRequest_UpdateTimeout> | undefined, b: UpdateWorkspaceRequest_UpdateTimeout | PlainMessage<UpdateWorkspaceRequest_UpdateTimeout> | undefined): boolean;
}
/**
 * Note(cw): Ports cannot be updated here in favour of UpdateWorkspacePorts call which exists so that
 * we can update individual ports.
 *
 * @generated from message gitpod.v1.UpdateWorkspaceRequest.UpdateWorkspaceSpec
 */
export declare class UpdateWorkspaceRequest_UpdateWorkspaceSpec extends Message<UpdateWorkspaceRequest_UpdateWorkspaceSpec> {
    /**
     * timeout configures the workspace timeout
     *
     * @generated from field: optional gitpod.v1.UpdateWorkspaceRequest.UpdateTimeout timeout = 1;
     */
    timeout?: UpdateWorkspaceRequest_UpdateTimeout;
    /**
     * admission controlls who can access the workspace and its ports.
     *
     * @generated from field: optional gitpod.v1.AdmissionLevel admission = 2;
     */
    admission?: AdmissionLevel;
    /**
     * Note(cw): repeated fields have implicit presence. There's a difference between passing an empty list or nothing.
     *
     * @generated from field: repeated string ssh_public_keys = 3;
     */
    sshPublicKeys: string[];
    constructor(data?: PartialMessage<UpdateWorkspaceRequest_UpdateWorkspaceSpec>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.UpdateWorkspaceRequest.UpdateWorkspaceSpec";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdateWorkspaceRequest_UpdateWorkspaceSpec;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdateWorkspaceRequest_UpdateWorkspaceSpec;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdateWorkspaceRequest_UpdateWorkspaceSpec;
    static equals(a: UpdateWorkspaceRequest_UpdateWorkspaceSpec | PlainMessage<UpdateWorkspaceRequest_UpdateWorkspaceSpec> | undefined, b: UpdateWorkspaceRequest_UpdateWorkspaceSpec | PlainMessage<UpdateWorkspaceRequest_UpdateWorkspaceSpec> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.UpdateWorkspaceResponse
 */
export declare class UpdateWorkspaceResponse extends Message<UpdateWorkspaceResponse> {
    /**
     * @generated from field: gitpod.v1.Workspace workspace = 1;
     */
    workspace?: Workspace;
    constructor(data?: PartialMessage<UpdateWorkspaceResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.UpdateWorkspaceResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): UpdateWorkspaceResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): UpdateWorkspaceResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): UpdateWorkspaceResponse;
    static equals(a: UpdateWorkspaceResponse | PlainMessage<UpdateWorkspaceResponse> | undefined, b: UpdateWorkspaceResponse | PlainMessage<UpdateWorkspaceResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.StopWorkspaceRequest
 */
export declare class StopWorkspaceRequest extends Message<StopWorkspaceRequest> {
    /**
     * workspace_id specifies which workspace should be stopped.
     *
     * +required
     *
     * @generated from field: string workspace_id = 1;
     */
    workspaceId: string;
    constructor(data?: PartialMessage<StopWorkspaceRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.StopWorkspaceRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): StopWorkspaceRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): StopWorkspaceRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): StopWorkspaceRequest;
    static equals(a: StopWorkspaceRequest | PlainMessage<StopWorkspaceRequest> | undefined, b: StopWorkspaceRequest | PlainMessage<StopWorkspaceRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.StopWorkspaceResponse
 */
export declare class StopWorkspaceResponse extends Message<StopWorkspaceResponse> {
    constructor(data?: PartialMessage<StopWorkspaceResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.StopWorkspaceResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): StopWorkspaceResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): StopWorkspaceResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): StopWorkspaceResponse;
    static equals(a: StopWorkspaceResponse | PlainMessage<StopWorkspaceResponse> | undefined, b: StopWorkspaceResponse | PlainMessage<StopWorkspaceResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.DeleteWorkspaceRequest
 */
export declare class DeleteWorkspaceRequest extends Message<DeleteWorkspaceRequest> {
    /**
     * workspace_id specifies the workspace that is going to delete.
     *
     * +required
     *
     * @generated from field: string workspace_id = 1;
     */
    workspaceId: string;
    constructor(data?: PartialMessage<DeleteWorkspaceRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.DeleteWorkspaceRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): DeleteWorkspaceRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): DeleteWorkspaceRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): DeleteWorkspaceRequest;
    static equals(a: DeleteWorkspaceRequest | PlainMessage<DeleteWorkspaceRequest> | undefined, b: DeleteWorkspaceRequest | PlainMessage<DeleteWorkspaceRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.DeleteWorkspaceResponse
 */
export declare class DeleteWorkspaceResponse extends Message<DeleteWorkspaceResponse> {
    constructor(data?: PartialMessage<DeleteWorkspaceResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.DeleteWorkspaceResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): DeleteWorkspaceResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): DeleteWorkspaceResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): DeleteWorkspaceResponse;
    static equals(a: DeleteWorkspaceResponse | PlainMessage<DeleteWorkspaceResponse> | undefined, b: DeleteWorkspaceResponse | PlainMessage<DeleteWorkspaceResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.ListWorkspaceClassesRequest
 */
export declare class ListWorkspaceClassesRequest extends Message<ListWorkspaceClassesRequest> {
    /**
     * @generated from field: gitpod.v1.PaginationRequest pagination = 1;
     */
    pagination?: PaginationRequest;
    constructor(data?: PartialMessage<ListWorkspaceClassesRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.ListWorkspaceClassesRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListWorkspaceClassesRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListWorkspaceClassesRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListWorkspaceClassesRequest;
    static equals(a: ListWorkspaceClassesRequest | PlainMessage<ListWorkspaceClassesRequest> | undefined, b: ListWorkspaceClassesRequest | PlainMessage<ListWorkspaceClassesRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.ListWorkspaceClassesResponse
 */
export declare class ListWorkspaceClassesResponse extends Message<ListWorkspaceClassesResponse> {
    /**
     * @generated from field: gitpod.v1.PaginationResponse pagination = 1;
     */
    pagination?: PaginationResponse;
    /**
     * @generated from field: repeated gitpod.v1.WorkspaceClass workspace_classes = 2;
     */
    workspaceClasses: WorkspaceClass[];
    constructor(data?: PartialMessage<ListWorkspaceClassesResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.ListWorkspaceClassesResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ListWorkspaceClassesResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ListWorkspaceClassesResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ListWorkspaceClassesResponse;
    static equals(a: ListWorkspaceClassesResponse | PlainMessage<ListWorkspaceClassesResponse> | undefined, b: ListWorkspaceClassesResponse | PlainMessage<ListWorkspaceClassesResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.ParseContextURLRequest
 */
export declare class ParseContextURLRequest extends Message<ParseContextURLRequest> {
    /**
     * context_url is the URL to parse
     *
     * @generated from field: string context_url = 1;
     */
    contextUrl: string;
    /**
     * configuration_id is the ID of the configuration to use
     *
     * @generated from field: string configuration_id = 2;
     */
    configurationId: string;
    constructor(data?: PartialMessage<ParseContextURLRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.ParseContextURLRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ParseContextURLRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ParseContextURLRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ParseContextURLRequest;
    static equals(a: ParseContextURLRequest | PlainMessage<ParseContextURLRequest> | undefined, b: ParseContextURLRequest | PlainMessage<ParseContextURLRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.ParseContextURLResponse
 */
export declare class ParseContextURLResponse extends Message<ParseContextURLResponse> {
    /**
     * @generated from field: gitpod.v1.WorkspaceMetadata metadata = 1;
     */
    metadata?: WorkspaceMetadata;
    /**
     * @generated from field: gitpod.v1.WorkspaceSpec spec = 2;
     */
    spec?: WorkspaceSpec;
    constructor(data?: PartialMessage<ParseContextURLResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.ParseContextURLResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): ParseContextURLResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): ParseContextURLResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): ParseContextURLResponse;
    static equals(a: ParseContextURLResponse | PlainMessage<ParseContextURLResponse> | undefined, b: ParseContextURLResponse | PlainMessage<ParseContextURLResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.WorkspaceClass
 */
export declare class WorkspaceClass extends Message<WorkspaceClass> {
    /**
     * id is the unique identifier of the workspace class
     *
     * @generated from field: string id = 1;
     */
    id: string;
    /**
     * display_name is the human readable name of the workspace class
     *
     * @generated from field: string display_name = 2;
     */
    displayName: string;
    /**
     * description is a human readable description of the workspace class
     *
     * @generated from field: string description = 3;
     */
    description: string;
    /**
     * is_default indicates if this workspace class is the default one
     *
     * @generated from field: bool is_default = 4;
     */
    isDefault: boolean;
    constructor(data?: PartialMessage<WorkspaceClass>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.WorkspaceClass";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceClass;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceClass;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceClass;
    static equals(a: WorkspaceClass | PlainMessage<WorkspaceClass> | undefined, b: WorkspaceClass | PlainMessage<WorkspaceClass> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.CreateWorkspaceSnapshotRequest
 */
export declare class CreateWorkspaceSnapshotRequest extends Message<CreateWorkspaceSnapshotRequest> {
    /**
     * workspace_id specifies the workspace to create snapshot
     *
     * +required
     *
     * @generated from field: string workspace_id = 1;
     */
    workspaceId: string;
    constructor(data?: PartialMessage<CreateWorkspaceSnapshotRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.CreateWorkspaceSnapshotRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): CreateWorkspaceSnapshotRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): CreateWorkspaceSnapshotRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): CreateWorkspaceSnapshotRequest;
    static equals(a: CreateWorkspaceSnapshotRequest | PlainMessage<CreateWorkspaceSnapshotRequest> | undefined, b: CreateWorkspaceSnapshotRequest | PlainMessage<CreateWorkspaceSnapshotRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.CreateWorkspaceSnapshotResponse
 */
export declare class CreateWorkspaceSnapshotResponse extends Message<CreateWorkspaceSnapshotResponse> {
    /**
     * @generated from field: gitpod.v1.WorkspaceSnapshot snapshot = 1;
     */
    snapshot?: WorkspaceSnapshot;
    constructor(data?: PartialMessage<CreateWorkspaceSnapshotResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.CreateWorkspaceSnapshotResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): CreateWorkspaceSnapshotResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): CreateWorkspaceSnapshotResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): CreateWorkspaceSnapshotResponse;
    static equals(a: CreateWorkspaceSnapshotResponse | PlainMessage<CreateWorkspaceSnapshotResponse> | undefined, b: CreateWorkspaceSnapshotResponse | PlainMessage<CreateWorkspaceSnapshotResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.WaitForWorkspaceSnapshotRequest
 */
export declare class WaitForWorkspaceSnapshotRequest extends Message<WaitForWorkspaceSnapshotRequest> {
    /**
     * snapshot_id specifies the snapshot to wait for
     *
     * +required
     *
     * @generated from field: string snapshot_id = 1;
     */
    snapshotId: string;
    constructor(data?: PartialMessage<WaitForWorkspaceSnapshotRequest>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.WaitForWorkspaceSnapshotRequest";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WaitForWorkspaceSnapshotRequest;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WaitForWorkspaceSnapshotRequest;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WaitForWorkspaceSnapshotRequest;
    static equals(a: WaitForWorkspaceSnapshotRequest | PlainMessage<WaitForWorkspaceSnapshotRequest> | undefined, b: WaitForWorkspaceSnapshotRequest | PlainMessage<WaitForWorkspaceSnapshotRequest> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.WaitForWorkspaceSnapshotResponse
 */
export declare class WaitForWorkspaceSnapshotResponse extends Message<WaitForWorkspaceSnapshotResponse> {
    constructor(data?: PartialMessage<WaitForWorkspaceSnapshotResponse>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.WaitForWorkspaceSnapshotResponse";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WaitForWorkspaceSnapshotResponse;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WaitForWorkspaceSnapshotResponse;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WaitForWorkspaceSnapshotResponse;
    static equals(a: WaitForWorkspaceSnapshotResponse | PlainMessage<WaitForWorkspaceSnapshotResponse> | undefined, b: WaitForWorkspaceSnapshotResponse | PlainMessage<WaitForWorkspaceSnapshotResponse> | undefined): boolean;
}
/**
 * @generated from message gitpod.v1.WorkspaceSnapshot
 */
export declare class WorkspaceSnapshot extends Message<WorkspaceSnapshot> {
    /**
     * id is the unique identifier of the snapshot
     *
     * @generated from field: string id = 1;
     */
    id: string;
    /**
     * workspace_id is the source workspace id of snapshot
     *
     * @generated from field: string workspace_id = 2;
     */
    workspaceId: string;
    /**
     * @generated from field: google.protobuf.Timestamp creation_time = 3;
     */
    creationTime?: Timestamp;
    constructor(data?: PartialMessage<WorkspaceSnapshot>);
    static readonly runtime: typeof proto3;
    static readonly typeName = "gitpod.v1.WorkspaceSnapshot";
    static readonly fields: FieldList;
    static fromBinary(bytes: Uint8Array, options?: Partial<BinaryReadOptions>): WorkspaceSnapshot;
    static fromJson(jsonValue: JsonValue, options?: Partial<JsonReadOptions>): WorkspaceSnapshot;
    static fromJsonString(jsonString: string, options?: Partial<JsonReadOptions>): WorkspaceSnapshot;
    static equals(a: WorkspaceSnapshot | PlainMessage<WorkspaceSnapshot> | undefined, b: WorkspaceSnapshot | PlainMessage<WorkspaceSnapshot> | undefined): boolean;
}
//# sourceMappingURL=workspace_pb.d.ts.map